﻿using System.Collections.Generic;
// ReSharper disable StringLiteralTypo

namespace NHSE.Core
{
    public class EventFlagPlayer : INamedValue
    {
        // these are actually unsigned
        public readonly short DefaultValue;
        public readonly short MaxValue;

        public ushort Index { get; }
        public string Name { get; }

        public EventFlagPlayer(short init, short max, ushort index, string name)
        {
            Name = name;
            Index = index;
            DefaultValue = init;
            MaxValue = max;
        }

        public static readonly IReadOnlyDictionary<ushort, EventFlagPlayer> List = new Dictionary<ushort, EventFlagPlayer>
        {
            {0x002, new EventFlagPlayer(0 , 9   , 0002, "PrologueNpcHintCount"                       )}, // NPCの序盤ヒントをいくつまで聞いたか
            {0x003, new EventFlagPlayer(0 , 31  , 0003, "TotakekeLiveCount"                          )}, // とたけけライブを聴いた回数
            {0x008, new EventFlagPlayer(0 , 1   , 0008, "JohnnyQuestStartFlag"                       )}, // ジョニークエスト開始フラグ(海賊ジョニーは別フラグ)
            {0x009, new EventFlagPlayer(0 , 1   , 0009, "JohnnyQuestFinishFlag"                      )}, // ジョニークエスト完了フラグ(海賊ジョニーは別フラグ)
            {0x00A, new EventFlagPlayer(0 , 8   , 0010, "JonnyTalkCount"                             )}, // 寝ているジョニーに話しかけた回数(海賊ジョニー共用)
            {0x00B, new EventFlagPlayer(0 , 1   , 0011, "HasPlayedTreasureHunt"                      )}, // 宝探しクエストをした事がある
            {0x00D, new EventFlagPlayer(0 , 1   , 0013, "ShizueCmnExplanationTowntune"               )}, // しずえ|メロ説明聞いたか？
            {0x00E, new EventFlagPlayer(0 , 1   , 0014, "ShizueCmnExplanationTownflag"               )}, // しずえ|村の旗説明聞いたか？
            {0x00F, new EventFlagPlayer(0 , 1   , 0015, "ShizueCmnExplanationComplaint"              )}, // しずえ|『村民のこと』の説明聞いたか？
            {0x011, new EventFlagPlayer(0 , 1   , 0017, "FutaTalkedWhenAsleep"                       )}, // フータ|寝てる時に話かけたことがある？
            {0x012, new EventFlagPlayer(0 , 1   , 0018, "FutaExplanationDonationComp"                )}, // フータ|博物館コンプの報告を受けたか？
            {0x013, new EventFlagPlayer(0 , 1   , 0019, "FutaTalkedInMuseumToday"                    )}, // フータ|博物館内で今日会話した？
            {0x014, new EventFlagPlayer(0 , 1   , 0020, "FutaHeardCommentary"                        )}, // フータ|コレってなに？で解説聞いた？
            {0x015, new EventFlagPlayer(0 , 1   , 0021, "FutaReadyForMuseum"                         )}, // フータ|博物館建設条件達成の報告聞いた？
            {0x016, new EventFlagPlayer(0 , 1   , 0022, "FutaReadyForMuseumToday"                    )}, // フータ|今日博物館の条件達成した当日か？
            {0x017, new EventFlagPlayer(0 , 1   , 0023, "KaburibaTalkTodayFlag"                      )}, // ウリ|今日すでに会話した？
            {0x018, new EventFlagPlayer(0 , 1   , 0024, "KaburibaTalkBeforeFlag"                     )}, // ウリ|今までに会話したことある？
            {0x019, new EventFlagPlayer(0 , 1   , 0025, "KaburibaBuyKabuTodayFlag"                   )}, // ウリ|今日カブ買った？
            {0x01A, new EventFlagPlayer(0 , 1   , 0026, "KinuyoTalkBoforeFlag"                       )}, // きぬよ|今までに会話したことある？
            {0x01B, new EventFlagPlayer(0 , 1   , 0027, "KinuyoTalkTodayFlag"                        )}, // きぬよ|今日すでに会話した？(来訪用)
            {0x01D, new EventFlagPlayer(0 , 1   , 0029, "SkkTalkBeforeFlag"                          )}, // シャンク|今までに会話したことある？
            {0x01F, new EventFlagPlayer(0 , 1   , 0031, "ReijiTalkBeforeFlag"                        )}, // レイジ|今までに会話したことある？（面識ある？）
            {0x021, new EventFlagPlayer(0 , 1   , 0033, "RollanTalkTodayFlag"                        )}, // ローラン|今日すでに会話した？
            {0x022, new EventFlagPlayer(0 , 3   , 0034, "RollanBuyLargeCount"                        )}, // ローラン|今日ラグ大を買った枚数
            {0x023, new EventFlagPlayer(0 , 3   , 0035, "RollanBuyMediumCount"                       )}, // ローラン|今日ラグ中を買った枚数
            {0x024, new EventFlagPlayer(0 , 3   , 0036, "RollanBuySmallCount"                        )}, // ローラン|今日ラグ小を買った枚数
            {0x025, new EventFlagPlayer(0 , 1   , 0037, "RcmTalkBeforeFlag"                          )}, // まめきち|店内で会話したことある？
            {0x026, new EventFlagPlayer(0 , 1   , 0038, "RcmTookReqMarket"                           )}, // まめきち|商店設置場所決め依頼された
            {0x027, new EventFlagPlayer(0 , 1   , 0039, "RcmDeclinedMarketReq"                       )}, // まめきち|商店設置場所決め依頼を断ったことある
            {0x028, new EventFlagPlayer(0 , 1   , 0040, "DoneCharacterCreation"                      )}, // キャラメイク完了
            {0x029, new EventFlagPlayer(0 , 1   , 0041, "RcmNoTurnipSellToday"                       )}, // まめきち|カブ買取不可の説明今日受けた？
            {0x02C, new EventFlagPlayer(0 , 1   , 0044, "ValidatePlayerSaveFlag"                     )}, // プレイヤーセーブデータが有効化された
            {0x02D, new EventFlagPlayer(0 , 1   , 0045, "MakeVillagePlayerFlag"                      )}, // 村民代表か？
            {0x02E, new EventFlagPlayer(0 , 1   , 0046, "PrologueDone1stTalkAtPlaza"                 )}, // 1P序盤|広場での最初の会話終わった？
            {0x02F, new EventFlagPlayer(0 , 1   , 0047, "HighAndLowPlayed"                           )}, // ミニゲームのハイ＆ローをプレイした事がある
            {0x030, new EventFlagPlayer(0 , 1   , 0048, "HappyHomeMission1"                          )}, // HHA/ハッピーホームでミッション１をクリヤーした
            {0x033, new EventFlagPlayer(0 , 1   , 0051, "OccurrenceCoinStone"                        )}, // コイン岩を発生させたか
            {0x034, new EventFlagPlayer(0 , 1   , 0052, "HappyHomeMission2"                          )}, // HHA/ハッピーホームでミッション２をクリヤーした
            {0x035, new EventFlagPlayer(0 , 1   , 0053, "SeoRejectFlag"                              )}, // ラコスケ|ホタテ渡すの断った？
            {0x036, new EventFlagPlayer(0 , 1   , 0054, "HappyHomeMission3"                          )}, // HHA/ハッピーホームでミッション３をクリヤーした
            {0x03B, new EventFlagPlayer(0 , 999 , 0059, "CatchFishFesCount"                          )}, // つり大会|保持している大会ポイント
            {0x03C, new EventFlagPlayer(0 , 999 , 0060, "CatchInsectFesCount"                        )}, // ムシとり大会|保持している大会ポイント
            {0x03D, new EventFlagPlayer(0 , 1   , 0061, "PlayerPocketUIEnable"                       )}, // プレイヤー|ポケットUI解禁
            {0x03E, new EventFlagPlayer(0 , 1   , 0062, "PlayerMainUImenuEnable"                     )}, // プレイヤー|メイン(スマホ)UI解禁
            {0x03F, new EventFlagPlayer(0 , 1   , 0063, "Prologue4AfterBuiltPcTent"                  )}, // たぬきち|自宅テント設営後に話した？
            {0x040, new EventFlagPlayer(0 , 1   , 0064, "RcoHearedWhatShouldIAsk"                    )}, // たぬきち|『何聞けばいい？』を聞いた
            {0x042, new EventFlagPlayer(0 , 1   , 0066, "Prologue4OwlNoMuseum"                       )}, // フータ|博物館設営前に話した？
            {0x043, new EventFlagPlayer(0 , 1   , 0067, "Prologue4OwlGetTent"                        )}, // フータ|テントを受け取ったか？
            {0x044, new EventFlagPlayer(0 , 1   , 0068, "Prologue4OwlBuiltMuseum"                    )}, // フータ|のテント設営後に話した？
            {0x045, new EventFlagPlayer(0 , 1   , 0069, "Prologue4RcmNoShop"                         )}, // まめきち|商店設営前に話した？
            {0x046, new EventFlagPlayer(0 , 1   , 0070, "Prologue4RcmGetTent"                        )}, // まめきち|お店の工事看板を受け取ったか？
            {0x047, new EventFlagPlayer(0 , 1   , 0071, "Prologue4RcmBuiltShop"                      )}, // まめきち|お店の工事看板設営後に話した？
            {0x048, new EventFlagPlayer(0 , 1   , 0072, "Prologue4HaNoTent"                          )}, // 初期HA|テント設営前に話した？
            {0x049, new EventFlagPlayer(0 , 1   , 0073, "Prologue4HaGetTent"                         )}, // 初期HA|テントを受け取ったか？
            {0x04A, new EventFlagPlayer(0 , 1   , 0074, "Prologue4HaBuiltTent"                       )}, // 初期HA|テント設営後に話した？
            {0x04B, new EventFlagPlayer(0 , 1   , 0075, "Prologue4AnNoTent"                          )}, // 初期AN|テント設営前に話した？
            {0x04C, new EventFlagPlayer(0 , 1   , 0076, "Prologue4AnGetTent"                         )}, // 初期AN|テントを受け取ったか？
            {0x04D, new EventFlagPlayer(0 , 1   , 0077, "Prologue4AnBuiltTent"                       )}, // 初期AN|テント設営後に話した？
            {0x04E, new EventFlagPlayer(0 , 1   , 0078, "BirthdayNGavePresentFlag"                   )}, // NPC誕生日|ホストにプレゼントを渡した？
            {0x04F, new EventFlagPlayer(0 , 1   , 0079, "BirthdayPCandleFlag"                        )}, // プレイヤー誕生日|ローソク吹き消した？
            {0x050, new EventFlagPlayer(0 , 1   , 0080, "BirthdayPNotPresentFlag"                    )}, // プレイヤー誕生日|プレゼントもらえなかった？
            {0x052, new EventFlagPlayer(0 , 1   , 0082, "SickQuestFirst"                             )}, // 病気クエストをクリアしたことがあるか？
            {0x053, new EventFlagPlayer(0 , 1   , 0083, "TotakekeTalkBeforeFlag"                     )}, // とたけけ|今までに会話したことある？
            {0x054, new EventFlagPlayer(0 , 1   , 0084, "JohnnyTalkBeforeFlag"                       )}, // ジョニー|今までに会話したことある？(海賊ジョニーは別フラグ)
            {0x055, new EventFlagPlayer(0 , 1   , 0085, "KotonoTalkBeforeFlag"                       )}, // ことの|今までに会話したことある？
            {0x056, new EventFlagPlayer(0 , 1   , 0086, "RollanTalkBeforeFlag"                       )}, // ローラン|今までに会話したことある？
            {0x058, new EventFlagPlayer(0 , 1   , 0088, "TunekichiTalkBefore"                        )}, // つねきち|今までに会話したことある？
            {0x059, new EventFlagPlayer(0 , 128 , 0089, "KotonoQuestCount"                           )}, // ことの|ことのとの親密度
            {0x05A, new EventFlagPlayer(0 , 1   , 0090, "KotonoQuestStartFlag"                       )}, // ことの|クエスト開始
            {0x05B, new EventFlagPlayer(0 , 1   , 0091, "KotonoQuestClearFlag"                       )}, // ことの|クエスト完了
            {0x05C, new EventFlagPlayer(0 , 1   , 0092, "KotonoQuestRefuseFlag"                      )}, // ことの|クエスト断った？
            {0x05D, new EventFlagPlayer(0 , 1   , 0093, "MainmenuEncyclopedia"                       )}, // スマホUI|図鑑解禁
            {0x05E, new EventFlagPlayer(0 , 1   , 0094, "MainmenuMap"                                )}, // スマホUI|マップ解禁
            {0x05F, new EventFlagPlayer(0 , 1   , 0095, "MainmenuMydesign"                           )}, // スマホUI|マイデザイン解禁
            {0x060, new EventFlagPlayer(0 , 1   , 0096, "MainmenuBank"                               )}, // スマホUI|モバイルバンク解禁
            {0x061, new EventFlagPlayer(0 , 1   , 0097, "RcmTalked1P1stday"                          )}, // まめきち|1Pが初日にテントで会話した？
            {0x062, new EventFlagPlayer(0 , 1   , 0098, "HappyHomeMission4"                          )}, // HHA/ハッピーホームでミッション４をクリヤーした
            {0x063, new EventFlagPlayer(0 , 1   , 0099, "RcoHeardDetailDIYtrial"                     )}, // たぬきち|DIY体験の材料の説明聞いた？
            {0x064, new EventFlagPlayer(0 , 1   , 0100, "SzaTaled1stTime"                            )}, // しずえ|役場内で会話したことがあるか？
            {0x065, new EventFlagPlayer(0 , 1   , 0101, "HappyHomeMission5"                          )}, // HHA/ハッピーホームでミッション５をクリヤーした
            {0x066, new EventFlagPlayer(0 , 1   , 0102, "HappyHomeMission6"                          )}, // HHA/ハッピーホームでミッション６をクリヤーした
            {0x06B, new EventFlagPlayer(0 , 1   , 0107, "OdekakeTutorial"                            )}, // 空港|モーリー|おでかけ初回説明済？
            {0x06C, new EventFlagPlayer(0 , 1   , 0108, "OdekakeTutorialKeyword"                     )}, // 空港|モーリー|おでかけあいことばマッチメイク初回説明済？
            {0x06E, new EventFlagPlayer(0 , 1   , 0110, "RcoGotWorkingwear"                          )}, // たぬきち|アルバイトの服もらった？
            {0x06F, new EventFlagPlayer(0 , 1   , 0111, "RcoHeardWorkExplain1"                       )}, // たぬきち|1つ目の仕事内容聞いた？
            {0x070, new EventFlagPlayer(0 , 1   , 0112, "RcoHeardWorkExplain2"                       )}, // たぬきち|2つ目の仕事内容聞いた？
            {0x071, new EventFlagPlayer(0 , 1   , 0113, "RcoFinishMakingAxe"                         )}, // たぬきち|チュートリアル斧作り終えた？
            {0x072, new EventFlagPlayer(0 , 1   , 0114, "OdekakeFirstTalk"                           )}, // 空港|モーリー|おでかけ初めて話しかけた？
            {0x073, new EventFlagPlayer(0 , 1   , 0115, "OdekakeFirstOpenGate"                       )}, // 空港|モーリー|おでかけ始めて改札を開けた説明済？
            {0x07E, new EventFlagPlayer(0 , 1   , 0126, "SzaGotDiyRecipe001"                         )}, // しずえ|しずえDIYレシピ1もらった？
            {0x07F, new EventFlagPlayer(0 , 1   , 0127, "OwlGotDiyRecipe001"                         )}, // フータ|フータDIYレシピ1もらった？
            {0x080, new EventFlagPlayer(0 , 1   , 0128, "TownNewsHeard1st"                           )}, // 村内放送|村内放送を聞いた事がある？
            {0x083, new EventFlagPlayer(0 , 1   , 0131, "GyroidPlazaTalk1st"                         )}, // 募金ハニワくん|広場募金ハニワくんと話した？
            {0x084, new EventFlagPlayer(0 , 1   , 0132, "PlayerLoanRepaying"                         )}, // ローン返済中？
            {0x085, new EventFlagPlayer(0 , 1   , 0133, "PlayerLoanFinish1st"                        )}, // ローン完済した？
            {0x086, new EventFlagPlayer(0 , 1   , 0134, "RcoHeardRemodel1"                           )}, // 増築提案受けた？
            {0x087, new EventFlagPlayer(0 , 1   , 0135, "UsedCoinStone"                              )}, // コイン岩を使ったか
            {0x088, new EventFlagPlayer(0 , 1   , 0136, "OwlFinished1stTalk"                         )}, // フータ|初対面挨拶したか？
            {0x089, new EventFlagPlayer(0 , 1   , 0137, "OwlTalkDuringConst1"                        )}, // フータ|テント→博物館工事中に会話したか？
            {0x08A, new EventFlagPlayer(0 , 1   , 0138, "OwlDonationDone"                            )}, // フータ|博物館(テント)で寄贈したことある？
            {0x08B, new EventFlagPlayer(0 , 1   , 0139, "Owl1stTalkMuseum1"                          )}, // フータ|博物館①完成後の挨拶した？
            {0x08C, new EventFlagPlayer(0 , 1   , 0140, "EnableEmoticonUI"                           )}, // 漫符UI解禁
            {0x08D, new EventFlagPlayer(0 , 1   , 0141, "RcoDoneDIYmyself"                           )}, // たぬきち|たぬきちテント内で自分でDIYしたことがある？
            {0x08E, new EventFlagPlayer(0 , 1   , 0142, "RcoOrderedHouseBuilt"                       )}, // たぬきち|家建築申し込み当日？
            {0x08F, new EventFlagPlayer(0 , 1   , 0143, "RcmHeardAboutRenual"                        )}, // まめきち|改装告知聞いた？
            {0x090, new EventFlagPlayer(0 , 1   , 0144, "RcmHeardAboutNewOpen1"                      )}, // まめきち|新装開店の案内聞いた？(商店・小)
            {0x091, new EventFlagPlayer(0 , 1   , 0145, "RcmHeardAboutNewOpen2"                      )}, // まめきち|新装開店の案内聞いた？(商店・大)
            {0x096, new EventFlagPlayer(0 , 1   , 0150, "ChmTalkRuleFirst"                           )}, // [大会]レックス|初回ルール説明聞いたか？
            {0x097, new EventFlagPlayer(0 , 1   , 0151, "ChmQuestFinish"                             )}, // [大会]レックス|結果発表あるか？
            {0x099, new EventFlagPlayer(0 , 1   , 0153, "ChmTalkPoint_BeforeEv"                      )}, // [大会]レックス|受付前、ポイント交換のお誘い聞いた?
            {0x09A, new EventFlagPlayer(0 , 1   , 0154, "ChmTalkFirst_EvQuestFinish"                 )}, // [大会]レックス|今日大会クエストしたか？
            {0x09B, new EventFlagPlayer(0 , 1   , 0155, "ChmTalkFirst_AfterEv"                       )}, // [大会]レックス|受付終了後、初回会話聞いた？
            {0x09C, new EventFlagPlayer(0 , 1   , 0156, "RcoGotDonationRewardFlower"                 )}, // たぬきち|虫魚提供報酬の花をもらった当日？
            {0x09F, new EventFlagPlayer(0 , 1   , 0159, "TownNewsHeardTownHallOpenFlag"              )}, // 村内放送|案内所が建った告知（しずえ引継ぎ）を聞いた？
            {0x0A0, new EventFlagPlayer(0 , 1   , 0160, "TownNewsHeardShopOpen1Flag"                 )}, // 村内放送|商店の新装開店告知を聞いた？(商店・小)
            {0x0A1, new EventFlagPlayer(0 , 1   , 0161, "TownNewsHeardShopOpen2Flag"                 )}, // 村内放送|商店の新装開店告知を聞いた？(商店・大)
            {0x0A3, new EventFlagPlayer(0 , 1   , 0163, "TownNewsHeardMuseumOpenFlag"                )}, // 村内放送|博物館建物が建った告知を聞いた？
            {0x0A5, new EventFlagPlayer(0 , 1   , 0165, "TownNewsHeardMuseumCafeOpenFlag"            )}, // 村内放送|ミュージアムカフェのオープン告知を聞いた？
            {0x0A6, new EventFlagPlayer(0 , 1   , 0166, "MarvelAtCockroarchToday"                    )}, // ゴキブリに驚いた
            {0x0A7, new EventFlagPlayer(0 , 1   , 0167, "GstTalkBefore"                              )}, // ゆうたろう|今までに会話したことある？
            {0x0A8, new EventFlagPlayer(0 , 1   , 0168, "GstQuestStartFlag"                          )}, // ゆうたろう|クエスト発生中？
            {0x0A9, new EventFlagPlayer(0 , 1   , 0169, "GstQuestClearFlag"                          )}, // ゆうたろう|今日クエストクリアした？
            {0x0AA, new EventFlagPlayer(0 , 1   , 0170, "GstQuestBreakFlag"                          )}, // ゆうたろう|一度クエスト発生させてゲーム終了した？
            {0x0AB, new EventFlagPlayer(0 , 1   , 0171, "MainmenuRecipe"                             )}, // スマホUI|レシピ解禁
            {0x0AC, new EventFlagPlayer(0 , 1   , 0172, "PurchaseBoxUseTodayFlag"                    )}, // 時間外買取BOX|今日すでに利用した？
            {0x0B1, new EventFlagPlayer(0 , 1   , 0177, "TownNewsHeardEventOpen"                     )}, // 村内放送|イベント開始時の村内放送を聞いたことがある？
            {0x0B2, new EventFlagPlayer(0 , 1   , 0178, "PostHasNewMessage"                          )}, // ポスト|新着メッセージカードがある？
            {0x0B4, new EventFlagPlayer(0 , 1   , 0180, "EnablePcTownDecoration"                     )}, // フィールド家具配置解禁
            {0x0B5, new EventFlagPlayer(1 , 1   , 0181, "KaburibaConditionFlag"                      )}, // ウリ|プレイヤーが住む前から来訪していた？
            {0x0B6, new EventFlagPlayer(0 , 1   , 0182, "SzaHeardSonkatsuExplain"                    )}, // しずえ|村活のことの説明聞いた？
            {0x0B7, new EventFlagPlayer(0 , 1   , 0183, "SzaHeardMuraokoshiExplain"                  )}, // しずえ|村おこしのことの説明聞いた？
            {0x0B8, new EventFlagPlayer(0 , 1   , 0184, "SzaHeardAboutHousingKit"                    )}, // たぬきち|土地確保解禁の説明聞いた？
            {0x0BA, new EventFlagPlayer(0 , 1   , 0186, "SeoFirstFlag"                               )}, // ラコスケ|ホタテを渡したことある？
            {0x0BF, new EventFlagPlayer(0 , 1   , 0191, "FoxTalkTodayFlag"                           )}, // つねきち|今日本島に来訪したつねきちと会話した？
            {0x0C0, new EventFlagPlayer(0 , 1   , 0192, "FoxBuyTodayFlag"                            )}, // つねきち|今日いなりマーケットで買い物した？
            {0x0C1, new EventFlagPlayer(0 , 1   , 0193, "FoxBuyArtTodayFlag"                         )}, // つねきち|今日いなりマーケットで美術品買った？
            {0x0C2, new EventFlagPlayer(0 , 1   , 0194, "TownNewsHeardEventSpaceOpenFlag"            )}, // 村内放送|村内放送でイベント広場が完成した告知を聞いた？
            {0x0C3, new EventFlagPlayer(0 , 1   , 0195, "PcDidNotKnowKK"                             )}, // プレイヤー|序盤にとたけけ知らないと答えた
            {0x0C4, new EventFlagPlayer(0 , 1   , 0196, "RcoAfterHouseRemodel"                       )}, // たぬきち｜家増築後の説明発生する？
            {0x0C6, new EventFlagPlayer(0 , 1   , 0198, "HeardAboutBuildingTownOffice"               )}, // しずえ|役場建設開始の説明聞いた？
            {0x0C7, new EventFlagPlayer(0 , 1   , 0199, "PgeTalkTodayFlag"                           )}, // マスター|今日すでに会話した？
            {0x0C8, new EventFlagPlayer(0 , 1   , 0200, "PgeItemGetFirstFlag"                        )}, // マスター|今日アイテムもらった？
            {0x0C9, new EventFlagPlayer(0 , 50  , 0201, "PgeRegularCount"                            )}, // マスター|常連度
            {0x0CA, new EventFlagPlayer(0 , 1   , 0202, "PgeTalkValentineFlag"                       )}, // マスター|今日バレンタインでコーヒー飲んだ？
            {0x0CB, new EventFlagPlayer(0 , 1   , 0203, "PgeTalkBirthdayFlag"                        )}, // マスター|今日誕生日などイベント系の会話した？
            {0x0CD, new EventFlagPlayer(0 , 1   , 0205, "RcoFenceShoppingExplain"                    )}, // たぬきち|柵購入の説明を受けたことがある？
            {0x0CE, new EventFlagPlayer(0 , 1   , 0206, "Ttl1stmet"                                  )}, // コトブキ|初対面会話済か？
            {0x0CF, new EventFlagPlayer(1 , 5   , 0207, "PcTownmakeLv"                               )}, // プレイヤーの村づくりライセンスレベル
            {0x0D0, new EventFlagPlayer(0 , 1   , 0208, "PcUpgradeTownmakeToday"                     )}, // 今日上級村づくりライセンスを入手したか？
            {0x0D1, new EventFlagPlayer(0 , 1   , 0209, "PcHousingLoanFinish"                        )}, // 住宅ローン完全終了
            {0x0D2, new EventFlagPlayer(0 , 1   , 0210, "PgeCoffeeTodayFlag"                         )}, // マスター|今日コーヒーかホットチョコレート注文した？
            {0x0D3, new EventFlagPlayer(0 , 1   , 0211, "RcoGetTvForCongratsHouse"                   )}, // たぬきち|新築祝いもらった？
            {0x0D4, new EventFlagPlayer(0 , 1   , 0212, "RcoItemFullForTv"                           )}, // たぬきち|新築祝いもらう時アイテムいっぱいだった
            {0x0D7, new EventFlagPlayer(0 , 1   , 0215, "PlayerEnableEating"                         )}, // プレイヤー|『食べる』解禁
            {0x0D8, new EventFlagPlayer(0 , 1   , 0216, "PlayerStungByBee"                           )}, // プレイヤー|ハチにさされたか？
            {0x0D9, new EventFlagPlayer(0 , 1   , 0217, "GetEmoticonTodayFlag"                       )}, // 今日すでに漫符を入手した？
            {0x0DA, new EventFlagPlayer(0 , 1   , 0218, "BevTalkRuleFirst"                           )}, // [大会]ジャスティン|初回ルール説明聞いたか？
            {0x0DB, new EventFlagPlayer(0 , 1   , 0219, "BevQuestFinish"                             )}, // [大会]ジャスティン|結果発表あるか？
            {0x0DD, new EventFlagPlayer(0 , 1   , 0221, "BevTalkPoint_BeforeEv"                      )}, // [大会]ジャスティン|受付前ポイント交換のお誘い聞いた?
            {0x0DE, new EventFlagPlayer(0 , 1   , 0222, "BevTalkFirst_EvQuestFinish"                 )}, // [大会]ジャスティン|今日クエストしたか？
            {0x0DF, new EventFlagPlayer(0 , 1   , 0223, "BevTalkFirst_AfterEv"                       )}, // [大会]ジャスティン|受付終了後、初回会話聞いた？
            {0x0E9, new EventFlagPlayer(0 , 1   , 0233, "TutorialFinishAndPast1day"                  )}, // 序盤シーケンス終了後１日以上経過
            {0x0EA, new EventFlagPlayer(0 , 1   , 0234, "HasGottenToolChangeStick"                   )}, // 変身ステッキを入手したことがあるか？
            {0x0EB, new EventFlagPlayer(0 , 1   , 0235, "GetBirthdayTable"                           )}, // 今年バースデーテーブルを貰った
            {0x0EC, new EventFlagPlayer(0 , 1   , 0236, "GetBirthdayCandle"                          )}, // 今年バースデーキャンドルを貰った
            {0x0ED, new EventFlagPlayer(0 , 1   , 0237, "GetBirthdayHat"                             )}, // 今年バースデーハットを貰った
            {0x0EE, new EventFlagPlayer(0 , 1   , 0238, "GetBirthdayBoard"                           )}, // 今年バースデーボードを貰った
            {0x0EF, new EventFlagPlayer(0 , 1   , 0239, "GetBirthdaySunglasses"                      )}, // 今年バースデーサングラスを貰った
            {0x0F6, new EventFlagPlayer(0 , 1   , 0246, "MainUiClockEnable"                          )}, // SYS|時計表示ON
            {0x0F7, new EventFlagPlayer(0 , 1   , 0247, "PrologueAfterBuiltTentTalk"                 )}, // 序盤|テント設営後の広場会話終わった
            {0x0F8, new EventFlagPlayer(0 , 1   , 0248, "PrologueForCampfire1"                       )}, // 序盤|キャンプ材料集めの話聞いた(1)
            {0x0F9, new EventFlagPlayer(0 , 1   , 0249, "PlayerPickupEnable"                         )}, // SYS|プレイヤー|拾う(Y)解禁
            {0x0FA, new EventFlagPlayer(0 , 1   , 0250, "HaveTownFruit4CampFire"                     )}, // 序盤|特産果物揃った状態でたぬきちに話しかけた
            {0x0FB, new EventFlagPlayer(0 , 1   , 0251, "PrologueForCampfire2"                       )}, // 序盤|キャンプ材料集めの話聞いた(2)
            {0x0FC, new EventFlagPlayer(0 , 1   , 0252, "SzaTalkBeforeCountdown"                     )}, // しずえ|年越し前に話した？
            {0x0FD, new EventFlagPlayer(0 , 1   , 0253, "SzaTalkAfterCountdown"                      )}, // しずえ|年越し後に話した？
            {0x0FE, new EventFlagPlayer(0 , 1   , 0254, "SzaGotNewYearHat"                           )}, // しずえ|スティックライトもらった？
            {0x0FF, new EventFlagPlayer(0 , 1   , 0255, "SzaGotCracker"                              )}, // たぬきち|クラッカーもらった？
            {0x100, new EventFlagPlayer(0 , 1   , 0256, "PrologueStartedCampfire"                    )}, // プロローグ|キャンプファイヤー開始
            {0x101, new EventFlagPlayer(0 , 1   , 0257, "AllowPcTentEntering"                        )}, // 〔序盤〕プレイヤー自宅テント入場解禁
            {0x102, new EventFlagPlayer(0 , 1   , 0258, "TkkTalkToday"                               )}, // とたけけ|今日すでに会話した？
            {0x103, new EventFlagPlayer(0 , 1   , 0259, "TkkLiveToday"                               )}, // とたけけ|今日ライブを聴いた？
            {0x104, new EventFlagPlayer(0 , 1   , 0260, "PcMaingameStart"                            )}, // プロローグ終了～本番ゲーム開始～
            {0x105, new EventFlagPlayer(0 , 1   , 0261, "TkkGetMusicToday"                           )}, // とたけけ|今日ミュージックをもらった？
            {0x106, new EventFlagPlayer(0 , 100 , 0262, "MoveNpcTradeSkipCount"                      )}, // 引越交換処理スキップカウント
            {0x107, new EventFlagPlayer(0 , 1   , 0263, "RcoTalked1stAfterPrologue"                  )}, // たぬきち|序盤終了後初会話した？
            {0x108, new EventFlagPlayer(0 , 1   , 0264, "RcmTalked1stAfterPrologue"                  )}, // まめきち|序盤終了後初会話した？
            {0x109, new EventFlagPlayer(0 , 1   , 0265, "RcoTentAdviceCanceled"                      )}, // たぬきち|テントのアドバイスキャンセルしたことある
            {0x10A, new EventFlagPlayer(0 , 1   , 0266, "RcoHeardAboutMyhome"                        )}, // たぬきち|『お家のこと』初めて聞いた？
            {0x10B, new EventFlagPlayer(0 , 1   , 0267, "PlayerFirstShootDownBalloon"                )}, // 風船を初めて撃ち落とした？
            {0x10C, new EventFlagPlayer(0 , 1   , 0268, "PrologueFinishTkkDream"                     )}, // 序盤|とたけけの夢終了
            {0x10D, new EventFlagPlayer(0 , 1   , 0269, "RcoPaid1stCharge"                           )}, // たぬきち|移住費用支払い完了
            {0x10E, new EventFlagPlayer(0 , 1   , 0270, "RcoTentEnableDIYtrial"                      )}, // たぬきち|DIY体験選択肢解禁
            {0x10F, new EventFlagPlayer(0 , 1   , 0271, "RcoDIYtrialOngoing"                         )}, // たぬきち|DIY体験中
            {0x110, new EventFlagPlayer(0 , 1   , 0272, "RcoDIYtrialGetMaterial"                     )}, // たぬきち|DIY体験中に材料揃った状態でたぬきちに話しかけた
            {0x111, new EventFlagPlayer(0 , 1   , 0273, "RcoTentDonation"                            )}, // たぬきち|たぬきちに虫魚預けたことある
            {0x112, new EventFlagPlayer(0 , 1   , 0274, "RcoTentDonatinDeclined"                     )}, // たぬきち|たぬきちに虫魚預けるのを断ったことある
            {0x113, new EventFlagPlayer(0 , 1   , 0275, "EnableBuildMuseumTent"                      )}, // 博物館テント設置条件満たした
            {0x114, new EventFlagPlayer(0 , 1   , 0276, "RcoTookRequestMuseum"                       )}, // たぬきち|博物館テント設置場所決め依頼された
            {0x115, new EventFlagPlayer(0 , 1   , 0277, "DecidedMuseumTentPlace"                     )}, // 博物館テント設営場所確定した
            {0x116, new EventFlagPlayer(0 , 1   , 0278, "RcoDeclinedMuseumReq"                       )}, // たぬきち|博物館設置場所決め依頼を断ったことある
            {0x11C, new EventFlagPlayer(0 , 1   , 0284, "RcmDeclinedQuestReq"                        )}, // まめきち|商店建築の材料集め依頼を断ったことがある
            {0x11D, new EventFlagPlayer(0 , 1   , 0285, "RcmTookQuestReq"                            )}, // まめきち|商店建築の材料集め依頼された
            {0x11E, new EventFlagPlayer(0 , 1   , 0286, "JohnnyAnotherPlayerClearFlag"               )}, // ジョニー|クエスト発生後に他のプレイヤーがクリアした？(海賊ジョニーは別フラグ)
            {0x124, new EventFlagPlayer(0 , 1   , 0292, "NnpcFinishHintTalk"                         )}, // NPCの序盤ヒント会話を聞き終えた
            {0x12A, new EventFlagPlayer(0 , 11  , 0298, "HgsCloseness"                               )}, // あさみ|あさみとの親密度
            {0x12B, new EventFlagPlayer(0 , 1   , 0299, "HgsTalkTodayFlag"                           )}, // あさみ|今日すでに会話した？
            {0x12C, new EventFlagPlayer(0 , 3   , 0300, "NnpcApproachNoEmoticonCount"                )}, // アプローチ会話｜漫符入手会話を見ないまま経過したプレイ日数
            {0x12D, new EventFlagPlayer(0 , 1   , 0301, "HgsAllowAddFriendship"                      )}, // あさみ|親密度加算許可
            {0x12F, new EventFlagPlayer(0 , 1   , 0303, "MainmenuCall"                               )}, // スマホUI|住人呼び出し解禁
            {0x130, new EventFlagPlayer(0 , 1   , 0304, "EmergencyEscapeExplain"                     )}, // 緊急脱出|説明聞いた
            {0x132, new EventFlagPlayer(0 , 1   , 0306, "HHAGradeMailFlag"                           )}, // HHA|評価の手紙送付ON?
            {0x133, new EventFlagPlayer(0 , 1   , 0307, "EnableSmatDeviceNortification"              )}, // スマホUI|通知機能有効化
            {0x134, new EventFlagPlayer(0 , 1   , 0308, "CatchFishFes_Bonus"                         )}, // つり大会｜到達ボーナスある？
            {0x135, new EventFlagPlayer(0 , 1   , 0309, "CatchFishFes_CooperativeBonus"              )}, // つり大会｜通信ボーナスある？
            {0x136, new EventFlagPlayer(0 , 1   , 0310, "CatchInsectFes_Bonus"                       )}, // ムシとり大会｜到達ボーナスある？
            {0x137, new EventFlagPlayer(0 , 1   , 0311, "CatchInsectFes_CooperativeBonus"            )}, // ムシとり大会｜通信ボーナスある？
            {0x138, new EventFlagPlayer(0 , 1   , 0312, "LookNpcHouseVisitNpc"                       )}, // 他のNPCの家に訪問中のNPCを見た
            {0x139, new EventFlagPlayer(0 , 1   , 0313, "MainmenuFriendList"                         )}, // スマホUI|フレンドリスト解禁
            {0x13A, new EventFlagPlayer(1 , 1   , 0314, "FriendListMainSwitch"                       )}, // フレンドリストUI|メインスイッチ
            {0x13B, new EventFlagPlayer(0 , 1   , 0315, "SnowmanGotDay1Flag"                         )}, // ゆきだるま|今日すでに１日目の報酬もらった？
            {0x13C, new EventFlagPlayer(0 , 1   , 0316, "SnowmanGotDay2Flag"                         )}, // ゆきだるま|今日すでに２日目の報酬もらった？
            {0x13D, new EventFlagPlayer(0 , 1   , 0317, "SnowmanGotDay3Flag"                         )}, // ゆきだるま|今日すでに３日目の報酬もらった？
            {0x13E, new EventFlagPlayer(0 , 1   , 0318, "SnowmanGotDay4Flag"                         )}, // ゆきだるま|今日すでに４日目の報酬もらった？
            {0x13F, new EventFlagPlayer(0 , 1   , 0319, "MainmenuOnlineShopping"                     )}, // スマホUI|カタログショッピング解禁
            {0x140, new EventFlagPlayer(0 , 1   , 0320, "MainmenuRndDailyQuest"                      )}, // スマホUI|マイレージ＋解禁
            {0x141, new EventFlagPlayer(0 , 1   , 0321, "MainmenuAchievement"                        )}, // スマホUI|実績(たぬきマイル)解禁
            {0x143, new EventFlagPlayer(0 , 1   , 0323, "SnowmanBuildFlag"                           )}, // ゆきだるま|作ったことある？
            {0x144, new EventFlagPlayer(0 , 1   , 0324, "SnowmanFirstBuildTodayFlag"                 )}, // ゆきだるま|今日初めてゆきだるまを作った？
            {0x146, new EventFlagPlayer(0 , 1   , 0326, "ObjRcoMachineCheck1st"                      )}, // OBJ|たぬポートにアクセスしたことがある？
            {0x148, new EventFlagPlayer(0 , 100 , 0328, "ReservedNpcGroupActivityMorning"            )}, // 朝の時間帯にNPCの集団行動が予約されているか
            {0x149, new EventFlagPlayer(0 , 100 , 0329, "ReservedNpcGroupActivityNoon"               )}, // 昼の時間帯にNPCの集団行動が予約されているか
            {0x14A, new EventFlagPlayer(0 , 100 , 0330, "ReservedNpcGroupActivityEvening"            )}, // 夕方の時間帯にNPCの集団行動が予約されているか
            {0x14B, new EventFlagPlayer(0 , 100 , 0331, "ReservedNpcGroupActivityNignt"              )}, // 夜の時間帯にNPCの集団行動が予約されているか
            {0x14D, new EventFlagPlayer(0 , 1   , 0333, "RcoMoveHouseReserved"                       )}, // たぬきち|プレイヤ家の引越しを予約しているか
            {0x14E, new EventFlagPlayer(0 , 1   , 0334, "RcoChangeHouseDesignReserved"               )}, // たぬきち|家外観変更の予約をしているか
            {0x14F, new EventFlagPlayer(0 , 1   , 0335, "RcoMoveNpcHouseFacilityReserved"            )}, // たぬきち|NPC家か施設の移設を予約しているか
            {0x151, new EventFlagPlayer(0 , 1   , 0337, "PlayerSonkatsuQuestEnable"                  )}, // SYS|マイレージ＋のカウント処理解禁
            {0x152, new EventFlagPlayer(0 , 1   , 0338, "RcoMoveShopReserved"                        )}, // たぬきち|お店の移設を予約している
            {0x153, new EventFlagPlayer(0 , 1   , 0339, "RcoMoveMuseumReserved"                      )}, // たぬきち|博物館の移設を予約している
            {0x154, new EventFlagPlayer(0 , 1   , 0340, "RcoMoveTailorReserved"                      )}, // たぬきち|仕立て屋の移設を予約している
            {0x155, new EventFlagPlayer(0 , 1   , 0341, "ChyDaily_TalkFirst"                         )}, // レックス|面識ある？（大会、来訪共通）
            {0x157, new EventFlagPlayer(0 , 1   , 0343, "BeyDaily_TalkFirst"                         )}, // ジャスティン|面識ある？（大会、来訪共通）
            {0x158, new EventFlagPlayer(0 , 1   , 0344, "BeyDaily_QuestClear"                        )}, // ジャスティン|来訪クエスト達成会話聞いた？
            {0x159, new EventFlagPlayer(0 , 1   , 0345, "AccessLostPropertyBox1st"                   )}, // 落とし物BOX|アクセスしたことがあるか？
            {0x15A, new EventFlagPlayer(0 , 1   , 0346, "Mobile1stBoot_Camera"                       )}, // スマホアプリ初起動|カメラ
            {0x15B, new EventFlagPlayer(0 , 1   , 0347, "Mobile1stBoot_MilageProgram"                )}, // スマホアプリ初起動|たぬきマイレージ
            {0x15C, new EventFlagPlayer(0 , 1   , 0348, "Mobile1stBoot_MilagePlus"                   )}, // スマホアプリ初起動|マイレージプラス
            {0x15D, new EventFlagPlayer(0 , 1   , 0349, "Mobile1stBoot_Encyclopedia"                 )}, // スマホアプリ初起動|いきもの図鑑
            {0x15E, new EventFlagPlayer(0 , 1   , 0350, "Mobile1stBoot_DIYrecipe"                    )}, // スマホアプリ初起動|DIYレシピ
            {0x15F, new EventFlagPlayer(0 , 1   , 0351, "Mobile1stBoot_OnlineShopping"               )}, // スマホアプリ初起動|たぬきショッピング
            {0x161, new EventFlagPlayer(0 , 1   , 0353, "Mobile1stBoot_Mydesign"                     )}, // スマホアプリ初起動|マイデザイン
            {0x162, new EventFlagPlayer(0 , 1   , 0354, "Mobile1stBoot_SharePlay"                    )}, // スマホアプリ初起動|住人呼び出し
            {0x163, new EventFlagPlayer(0 , 1   , 0355, "Mobile1stBoot_BestFriend"                   )}, // スマホアプリ初起動|ベストフレンド
            {0x164, new EventFlagPlayer(0 , 1   , 0356, "Mobile1stBoot_Passport"                     )}, // スマホアプリ初起動|パスポート
            {0x165, new EventFlagPlayer(0 , 1   , 0357, "Mobile1stBoot_Map"                          )}, // スマホアプリ初起動|マップ
            {0x167, new EventFlagPlayer(0 , 1   , 0359, "Mobile1stBoot_SOS"                          )}, // スマホアプリ初起動|SOS
            {0x168, new EventFlagPlayer(0 , 1   , 0360, "RctTalkBeforeFalg"                          )}, // つぶきち|オートセーブ解禁以降、会話したことあるか？
            {0x169, new EventFlagPlayer(0 , 255 , 0361, "AmountHeardPublicAnnouncement"              )}, // 島内放送を聞いた回数
            {0x16A, new EventFlagPlayer(0 , 1   , 0362, "SzaTalkAboutOfficeService"                  )}, // しずえ|案内所で工事ライセンスの説明聞いた？
            {0x16B, new EventFlagPlayer(0 , 1   , 0363, "SzaFlowerQuestClear"                        )}, // しずえ|花を渡すおつかいをクリアした？
            {0x16C, new EventFlagPlayer(0 , 1   , 0364, "RcoTalkAboutBuildBridge"                    )}, // xたぬきち|橋建設について説明受けた
            {0x16D, new EventFlagPlayer(0 , 1   , 0365, "RcoTalkAboutBuildSlope"                     )}, // xたぬきち|坂建設について説明受けた
            {0x16E, new EventFlagPlayer(0 , 1   , 0366, "RcoTalkAboutDeleteBridgeSlope"              )}, // たぬきち|橋坂撤去について説明受けた
            {0x16F, new EventFlagPlayer(0 , 1   , 0367, "RcoBuildBridgeReserved"                     )}, // xたぬきち|今日、橋建設を予約済み
            {0x170, new EventFlagPlayer(0 , 1   , 0368, "RcoBuildSlopeReserved"                      )}, // xたぬきち|今日、坂建設を予約済み
            {0x171, new EventFlagPlayer(0 , 1   , 0369, "RcoDeleteBridgeSlopeReserved"               )}, // xたぬきち|今日、橋撤去を予約済み
            {0x172, new EventFlagPlayer(0 , 1   , 0370, "RcoDeleteSlopeReserved"                     )}, // xたぬきち|今日、坂撤去を予約済み
            {0x173, new EventFlagPlayer(0 , 1   , 0371, "OwlShowFossilMyself"                        )}, // フータ|化石発見の報告を受けた
            {0x174, new EventFlagPlayer(0 , 1   , 0372, "RcmShowHardWood"                            )}, // まめきち|かたいもくざいを見せた
            {0x175, new EventFlagPlayer(0 , 1   , 0373, "RcoTalkAfterMuseumTent"                     )}, // たぬきち|博物館テント設置場所決め後会話発動させる？
            {0x176, new EventFlagPlayer(0 , 1   , 0374, "PlayerGotHardWood"                          )}, // プレイヤー|かたいもくざいを拾ったことがある
            {0x177, new EventFlagPlayer(0 , 1   , 0375, "RcmSellCampingStuffReaction"                )}, // まめきち|序盤に支給品を売却しようとした反応発生
            {0x178, new EventFlagPlayer(0 , 1   , 0376, "OBJRcoMachineChkPlusEnable"                 )}, // OBJ|たぬポートにプラス会員になった後話しかけた
            {0x179, new EventFlagPlayer(0 , 8   , 0377, "SysCountOpenedToolManual"                   )}, // 道具の説明の解禁数カウント
            {0x17A, new EventFlagPlayer(0 , 1   , 0378, "RcoHeardThanksForBuiltOwlTent"              )}, // たぬきち|ヒントでフータテント設営お礼聞いた
            {0x17C, new EventFlagPlayer(0 , 1   , 0380, "AnnouncementOwlMovedIn"                     )}, // 島内放送|フータ移住開始のアナウンス聞いた？
            {0x17D, new EventFlagPlayer(0 , 1   , 0381, "RcmTalkAboutCupboard"                       )}, // まめきち|戸棚を調べて説明を受けた
            {0x17E, new EventFlagPlayer(0 , 2   , 0382, "RcoDonateStatus"                            )}, // ×たぬきち|テント内フロー分岐用 0:DIY～ 1:生き物～ 2:（なし）
            {0x17F, new EventFlagPlayer(0 , 1   , 0383, "RcoGotLoginBonusToday"                      )}, // タヌポート|今日ログインボーナス獲得済？
            {0x180, new EventFlagPlayer(0 , 7   , 0384, "RcoMachineDailyLoginDays"                   )}, // タヌポート|連続ログインカウント
            {0x181, new EventFlagPlayer(0 , 1   , 0385, "RcoMachineDailyLoginCheck"                  )}, // タヌポート|連続ログインチェック
            {0x182, new EventFlagPlayer(0 , 1   , 0386, "RcoMachineEnableExchange"                   )}, // タヌポート|マイル交換開始の説明聞いた？
            {0x183, new EventFlagPlayer(0 , 16  , 0387, "JohnnyPartsCount"                           )}, // ジョニー｜渡したパーツの個数(海賊ジョニーは別フラグ)
            {0x184, new EventFlagPlayer(0 , 9   , 0388, "BeyDaily_QuestCount"                        )}, // ジャスティン|指定サイズの魚を釣り上げた回数
            {0x185, new EventFlagPlayer(0 , 1   , 0389, "TalkRumorPActionTodayAnyone"                )}, // 今日RumorP_Action（現在プレイヤー）を聞いたか？
            {0x186, new EventFlagPlayer(0 , 1   , 0390, "TalkRumorPFavoriteTodayAnyone"              )}, // 今日誰かにRumorP_Favoriteを聞いたか？
            {0x188, new EventFlagPlayer(0 , 1   , 0392, "IsToolShortcutManualOpen"                   )}, // 道具ショートカット説明解禁済か？
            {0x189, new EventFlagPlayer(0 , 1   , 0393, "RcoMachineExplainAboutPlaneTicket"          )}, // タヌポート|マイル航空券の説明聞いた？
            {0x18A, new EventFlagPlayer(0 , 1   , 0394, "DodExplainAboutMysteryTour"                 )}, // モーリー|ミステリーツアーの説明聞いた？
            {0x18E, new EventFlagPlayer(0 , 1   , 0398, "IsGetMessageBottle"                         )}, // プレイヤ｜今日メッセージボトルを拾った
            {0x18F, new EventFlagPlayer(0 , 1   , 0399, "DodFirstTalkAfterPlusEnable"                )}, // モーリー|初会話したのはマイレージ+解禁後？
            {0x190, new EventFlagPlayer(0 , 1   , 0400, "ImmQHousingKitGetFirst"                     )}, // たぬきち|ハウジングキット初めてもらった
            {0x191, new EventFlagPlayer(0 , 1   , 0401, "ImmQFirstExplain"                           )}, // たぬきち|移住クエストの最初の説明聞いた
            {0x192, new EventFlagPlayer(0 , 1   , 0402, "ImmQRunningForPlayer"                       )}, // たぬきち|自身が移住クエスト実施中か
            {0x193, new EventFlagPlayer(0 , 1   , 0403, "DodUseFirstFreeTour"                        )}, // モーリー|ミステリーツアーの初回無料権使った？
            {0x194, new EventFlagPlayer(0 , 1   , 0404, "AppUrgentEscapeUseToday"                    )}, // 緊急脱出|本日利用した
            {0x195, new EventFlagPlayer(0 , 1   , 0405, "AppUrgentEscapeNoPayment"                   )}, // 緊急脱出|前回、マイル支払ってない
            {0x196, new EventFlagPlayer(0 , 1   , 0406, "ImmQSetHousingAbyMySelf"                    )}, // たぬきち|移住クエスト自分でハウジングA置いた
            {0x197, new EventFlagPlayer(0 , 1   , 0407, "ImmQSetHousingBbyMySelf"                    )}, // たぬきち|移住クエスト自分でハウジングB置いた
            {0x198, new EventFlagPlayer(0 , 1   , 0408, "ImmQSetHousingCbyMySelf"                    )}, // たぬきち|移住クエスト自分でハウジングC置いた
            {0x199, new EventFlagPlayer(0 , 1   , 0409, "ImmQSetOutdoorAbyMySelf"                    )}, // たぬきち|移住クエスト自分で外置き家具A置いた
            {0x19A, new EventFlagPlayer(0 , 1   , 0410, "ImmQSetOutdoorBbyMySelf"                    )}, // たぬきち|移住クエスト自分で外置き家具B置いた
            {0x19B, new EventFlagPlayer(0 , 1   , 0411, "ImmQSetOutdoorCbyMySelf"                    )}, // たぬきち|移住クエスト自分で外置き家具C置いた
            {0x19C, new EventFlagPlayer(0 , 1   , 0412, "RcoHeardNoticeOfficeBuild"                  )}, // たぬきち|案内所建物建築予告聞いた
            {0x19F, new EventFlagPlayer(0 , 1   , 0415, "RcoTalkBeforeCountdown"                     )}, // たぬきち|年越し前に話した？
            {0x1A0, new EventFlagPlayer(0 , 1   , 0416, "RcoTalkAfterCountdown"                      )}, // たぬきち|年越し後に話した？
            {0x1A1, new EventFlagPlayer(0 , 1   , 0417, "ChyDaily_TalkFirstDay"                      )}, // レックス|今回の来訪中に話したか？
            {0x1A2, new EventFlagPlayer(0 , 1   , 0418, "ChyDaily_SellCount"                         )}, // レックス|買取総数（今回計算含む）/未使用
            {0x1A3, new EventFlagPlayer(0 , 1   , 0419, "ChyDaily_SellFirst"                         )}, // レックス|今日買取した？
            {0x1A6, new EventFlagPlayer(0 , 1   , 0422, "NetIsRegistHomeLand"                        )}, // 通信|独自サーバに島登録したか？
            {0x1A7, new EventFlagPlayer(0 , 1   , 0423, "FriendListNotifyUpdate"                     )}, // フレンドリスト|更新要求通知
            {0x1A8, new EventFlagPlayer(0 , 1   , 0424, "FriendListNotifyLook"                       )}, // スマホUI|ベストフレンドリストアイコン用更新通知
            {0x1A9, new EventFlagPlayer(0 , 100 , 0425, "CatchFishContinueCount"                     )}, // つり|逃げられずに釣り上げた回数
            {0x1AA, new EventFlagPlayer(0 , 1   , 0426, "FriendMailSendEnable"                       )}, // メッセージカード|フレンドへの送信解禁
            {0x1AC, new EventFlagPlayer(0 , 1   , 0428, "BeyDaily_TalkFirstDay"                      )}, // ジャスティン|今回の来訪中に話した？
            {0x1AE, new EventFlagPlayer(0 , 20  , 0430, "PrayStarToday"                              )}, // 今日祈った回数
            {0x1AF, new EventFlagPlayer(0 , 40  , 0431, "StarPieceGrowCount"                         )}, // 星素材発生カウンタ
            {0x1B0, new EventFlagPlayer(0 , 1   , 0432, "BeyDaily_QuestStart"                        )}, // ジャスティン|クエスト申し込みした？
            {0x1B1, new EventFlagPlayer(0 , 1   , 0433, "KinuyoChkMydesginFlag"                      )}, // きぬよ|仕立て屋のマイデザインチェックしたことある？
            {0x1B3, new EventFlagPlayer(0 , 1   , 0435, "HgsGotCloth"                                )}, // あさみ|汎用布地もらったことある？
            {0x1B4, new EventFlagPlayer(0 , 100 , 0436, "RcmDeliver_00"                              )}, // まめきち|商店建設クエストでかたいもくざいを渡した数
            {0x1B6, new EventFlagPlayer(0 , 1   , 0438, "HasTalkedAllVillagerToday"                  )}, // 今日全ての住民NPCと話したか？
            {0x1B7, new EventFlagPlayer(0 , 1   , 0439, "AmiiboPhoneTalkFirst"                       )}, // amiiboフォン＋と話したことがあるか？
            {0x1B8, new EventFlagPlayer(0 , 1   , 0440, "PrintServiceExplain"                        )}, // タヌポートでポスター販売開始の案内聞いたか？
            {0x1B9, new EventFlagPlayer(0 , 3   , 0441, "SendPuromaidoCount"                         )}, // 今日プリントしたブロマイドの数
            {0x1BA, new EventFlagPlayer(0 , 1   , 0442, "KinuyoTalkInTailorFlag"                     )}, // きぬよ|仕立て屋で会話したことある？
            {0x1BB, new EventFlagPlayer(0 , 1   , 0443, "KinuyoForcesTalkTodayFlag"                  )}, // きぬよ|今日仕立て屋で入店時の強制会話した？
            {0x1BC, new EventFlagPlayer(0 , 1   , 0444, "KinuyoForcedTalk2TodayFlag"                 )}, // きぬよ|今日仕立て屋で退店時の強制会話した？
            {0x1BD, new EventFlagPlayer(0 , 999 , 0445, "ChyEvent_TotalPoint"                        )}, // [大会]レックス|ムシとり大会累計ポイント
            {0x1BE, new EventFlagPlayer(0 , 999 , 0446, "BeyEvent_TotalPoint"                        )}, // [大会]ジャスティン|つり大会累計ポイント
            {0x1BF, new EventFlagPlayer(0 , 1   , 0447, "ChyEvent_GetTrophyGold"                     )}, // [大会]レックス|トロフィ金もらったか？
            {0x1C0, new EventFlagPlayer(0 , 1   , 0448, "ChyEvent_GetTrophySilver"                   )}, // [大会]レックス|トロフィ銀もらったか？
            {0x1C1, new EventFlagPlayer(0 , 1   , 0449, "ChyEvent_GetTrophyCopper"                   )}, // [大会]レックス|トロフィ銅もらったか？
            {0x1C2, new EventFlagPlayer(0 , 1   , 0450, "BeyEvent_GetTrophyGold"                     )}, // [大会]ジャスティン|トロフィ金もらったか？
            {0x1C3, new EventFlagPlayer(0 , 1   , 0451, "BeyEvent_GetTrophySilver"                   )}, // [大会]ジャスティン|トロフィ銀もらったか？
            {0x1C4, new EventFlagPlayer(0 , 1   , 0452, "BeyEvent_GetTrophyCopper"                   )}, // [大会]ジャスティン|トロフィ銅もらったか？
            {0x1C5, new EventFlagPlayer(0 , 1   , 0453, "PurchaseBoxUseOnceFlag"                     )}, // 時間外買取BOX|自分の島で調べたことがある？
            {0x1C6, new EventFlagPlayer(0 , 1   , 0454, "BeyDaily_ReqObj"                            )}, // ジャスティン|サカナOBJ申込した？
            {0x1C7, new EventFlagPlayer(0 , 1   , 0455, "ChyDaily_ReqObj"                            )}, // レックス|ムシOBJ申込した？
            {0x1C8, new EventFlagPlayer(0 , 1   , 0456, "BeyDaily_ExplainReqObj_First"               )}, // ジャスティン|サカナOBJ初回説明聞いた？
            {0x1C9, new EventFlagPlayer(0 , 1   , 0457, "ChyDaily_ExplainReqObj_First"               )}, // レックス|ムシOBJ初回説明聞いた？
            {0x1CB, new EventFlagPlayer(0 , 1   , 0459, "KinuyoTailorBuildFlag"                      )}, // きぬよ|仕立て屋の場所決めたプレイヤー？
            {0x1CC, new EventFlagPlayer(0 , 1   , 0460, "BirthdayPToldlPartySharePlay"               )}, // プレイヤー誕生日|NPCから誕生会の案内聞いた？
            {0x1CD, new EventFlagPlayer(0 , 1   , 0461, "TalkSnpcTodayAnyone"                        )}, // 今日誰かにSnpcを聞いたか？
            {0x1CE, new EventFlagPlayer(0 , 1   , 0462, "RcmForcedTalkTodayFlag"                     )}, // まめきち|今日お店で入店時の強制会話した？
            {0x1CF, new EventFlagPlayer(0 , 1   , 0463, "RcmForcedTalk2TodayFlag"                    )}, // まめきち|今日お店で退店時の強制会話した？
            {0x1D0, new EventFlagPlayer(0 , 1   , 0464, "KinuyoMetShopFlag"                          )}, // きぬよ|商店で会った？
            {0x1D1, new EventFlagPlayer(0 , 1   , 0465, "ImmQGetHousingFullItem"                     )}, // たぬきち|ハウジングキットもらうとき、持ち物いっぱいだった
            {0x1D2, new EventFlagPlayer(0 , 1   , 0466, "TownNewsReserve"                            )}, // 村内放送|村内放送予約フラグ
            {0x1D3, new EventFlagPlayer(0 , 1   , 0467, "BeyDaily_ExolainQ_First"                    )}, // ジャスティン|初回クエスト説明聞いた？
            {0x1D4, new EventFlagPlayer(0 , 1   , 0468, "ImmQHeardClearInfoA"                        )}, // たぬきち|移住クエストAをクリアした旨を聞いたことがある
            {0x1D5, new EventFlagPlayer(0 , 1   , 0469, "ImmQHeardClearInfoB"                        )}, // たぬきち|移住クエストBをクリアした旨を聞いたことがある
            {0x1D6, new EventFlagPlayer(0 , 1   , 0470, "ImmQHeardClearInfoC"                        )}, // たぬきち|移住クエストCをクリアした旨を聞いたことがある
            {0x1D7, new EventFlagPlayer(0 , 1   , 0471, "ImmQHeardNoticeRemoveFtr"                   )}, // たぬきち|聞いていない移住クエストクリアの告知がある？
            {0x1D8, new EventFlagPlayer(0 , 1   , 0472, "RcoImmQClear1QuestToday"                    )}, // たぬきち|今日、移住クエストの１工程を既にクリアしてる
            {0x1D9, new EventFlagPlayer(0 , 1   , 0473, "ImmQTalkRcoHaveBridgeKit"                   )}, // たぬきち|まるたのはしキット持った状態で会話した
            {0x1DA, new EventFlagPlayer(0 , 1   , 0474, "ImmQTalkRcoBridgeKitSet"                    )}, // たぬきち|まるたのはしキットを設置したお礼会話発動させる？
            {0x1DB, new EventFlagPlayer(0 , 1   , 0475, "ImmQSetBridgeKitMySelf"                     )}, // たぬきち|まるたのはしキットを自分自身が設置した
            {0x1DC, new EventFlagPlayer(0 , 1   , 0476, "ImmQTalkRcoBridgeComplete"                  )}, // たぬきち|まるたのはしが完成してから会話した
            {0x1DD, new EventFlagPlayer(0 , 1   , 0477, "ImmQTalkAboutPrize"                         )}, // たぬきち|移住クエスト報酬会話した
            {0x1DE, new EventFlagPlayer(0 , 1   , 0478, "ImmQGetQuestPrize"                          )}, // たぬきち|移住クエストの報酬もらった
            {0x1DF, new EventFlagPlayer(0 , 1   , 0479, "ChyDaily_AnnounceEvent"                     )}, // レックス|ムシとり大会予告聞いた？
            {0x1E0, new EventFlagPlayer(0 , 1   , 0480, "BeyDaily_AnnounceEvent"                     )}, // ジャスティン|つり大会予告聞いた？
            {0x1E1, new EventFlagPlayer(0 , 1   , 0481, "CampInvite"                                 )}, // キャンプ場に誘った
            {0x1E2, new EventFlagPlayer(0 , 1   , 0482, "CampFirstTalk"                              )}, // キャンパーNPCとの初回会話を済ませた
            {0x1E3, new EventFlagPlayer(0 , 1   , 0483, "CampQuestAccept"                            )}, // キャンプ家具クエストを受注した
            {0x1E4, new EventFlagPlayer(0 , 1   , 0484, "CampQuestRecipiFailed"                      )}, // キャンプ家具クエストのレシピを受け取れなかった
            {0x1E5, new EventFlagPlayer(0 , 1   , 0485, "CampQuestRejected"                          )}, // キャンプ家具クエストを断った
            {0x1E6, new EventFlagPlayer(0 , 1   , 0486, "CampGameGetRare"                            )}, // キャンプゲームでレア枠アイテムを入手した
            {0x1E8, new EventFlagPlayer(0 , 1   , 0488, "Camp_InduceFailFlag"                        )}, // キャンプ|勧誘失敗フラグ
            {0x1EA, new EventFlagPlayer(0 , 1   , 0490, "Camp_InduceFailSameNpcLiving"               )}, // キャンプ|勧誘失敗理由|同名NPCが村に住んでいる
            {0x1EB, new EventFlagPlayer(0 , 1   , 0491, "Camp_InduceFailSameNpcMoveIn"               )}, // キャンプ|勧誘失敗理由|同名NPCが転入確定状態
            {0x1EC, new EventFlagPlayer(0 , 1   , 0492, "Camp_InduceFailVillagerMax"                 )}, // キャンプ|勧誘失敗理由|住人数が既に上限
            {0x1ED, new EventFlagPlayer(0 , 1   , 0493, "Camp_InduceFailSellPlaceNothing"            )}, // キャンプ|勧誘失敗理由|売り土地が無い
            {0x1EE, new EventFlagPlayer(0 , 1   , 0494, "CalendarEventAchievementFinish"             )}, // カレンダーイベントの実績を今日カウントした
            {0x1EF, new EventFlagPlayer(0 , 1   , 0495, "RollanGotWallpaperFlag"                     )}, // ローラン|今日かべがみひきかえた？
            {0x1F0, new EventFlagPlayer(0 , 1   , 0496, "RollanGotCarpetFlag"                        )}, // ローラン|今日ゆかひきかえた？
            {0x1F7, new EventFlagPlayer(0 , 1   , 0503, "ImmQTakeFruit"                              )}, // たぬきち|移住クエストで今日果物もらった
            {0x1F8, new EventFlagPlayer(0 , 1   , 0504, "ImmQTakeRemakeKit"                          )}, // xたぬきち|移住クエストで今日リメイクキットもらった
            {0x1F9, new EventFlagPlayer(0 , 1   , 0505, "ImmQBridgeMadeinRcoTent"                    )}, // たぬきち|はしキットをたぬきちテントで作った
            {0x1FA, new EventFlagPlayer(0 , 1   , 0506, "IslandDevQuestShowCampKit"                  )}, // たぬきち|キャンプ場よていちキットをたぬきちに見せた
            {0x1FB, new EventFlagPlayer(0 , 1   , 0507, "IslandDevQuestCampMadeRcotent"              )}, // たぬきち|キャンプ場よていちキットを案内所で作った
            {0x1FC, new EventFlagPlayer(0 , 1   , 0508, "IslandDevQuestTalkAfterCampSet"             )}, // たぬきち|キャンプ場よていちキットをセットしてから会話した
            {0x1FD, new EventFlagPlayer(0 , 1   , 0509, "IslandDevQuestCampSetMySelf"                )}, // たぬきち|キャンプ場よていちキットを自身で設置した
            {0x1FF, new EventFlagPlayer(0 , 1   , 0511, "IslandDevQuestGetRecipeCampKit"             )}, // たぬきち|キャンプ場よていちキットのレシピを受け取った
            {0x200, new EventFlagPlayer(0 , 1   , 0512, "IslandDevQuestOrderFirstCamperMyself"       )}, // たぬきち|１人目のキャンプ客から移住の相談を自身が受けた
            {0x201, new EventFlagPlayer(0 , 1   , 0513, "MainmenuConstructLicense"                   )}, // スマホUI|造成ライセンスアプリ解禁
            {0x202, new EventFlagPlayer(0 , 1   , 0514, "FirstPlayAfterOfficeBuiltFlag"              )}, // 案内所の建物が完成したあとのプレイ初日？
            {0x203, new EventFlagPlayer(0 , 1   , 0515, "FirstPlayAfterShopBuiltFlag"                )}, // 商店が完成したあとのプレイ初日？
            {0x204, new EventFlagPlayer(0 , 1   , 0516, "FirstPlayAfterShopBuilt2Flag"               )}, // 商店を拡張したあとのプレイ初日？
            {0x205, new EventFlagPlayer(0 , 1   , 0517, "FirstPlayAfterMuseumTentFlag"               )}, // フータのテントが完成したあとのプレイ初日？
            {0x206, new EventFlagPlayer(0 , 1   , 0518, "FirstPlayAfterMuseumBuiltFlag"              )}, // 博物館が完成したあとのプレイ初日？
            {0x207, new EventFlagPlayer(0 , 1   , 0519, "FirstPlayAfterTailorBuiltFlag"              )}, // 仕立て屋が完成したあとのプレイ初日？
            {0x208, new EventFlagPlayer(0 , 1   , 0520, "SzaHeardTodayIslandEvaluation"              )}, // しずえ|今日の島の評価を聞いた
            {0x209, new EventFlagPlayer(0 , 1   , 0521, "IslandEvaluationUnlockMyself"               )}, // しずえ|自分自身が島の評価を解禁した
            {0x20A, new EventFlagPlayer(0 , 1   , 0522, "SzaHeardAboutIslandEvaluation"              )}, // しずえ|島の評価に関する説明を聞いた
            {0x20B, new EventFlagPlayer(0 , 1   , 0523, "ConstructionWorkToday"                      )}, // 工事ライセンス|説明を見た
            {0x20C, new EventFlagPlayer(0 , 1   , 0524, "PlayToday"                                  )}, // 今日プレイした
            {0x20D, new EventFlagPlayer(0 , 1   , 0525, "TalkFreeIPresentTodayAnyone"                )}, // 今日誰かにFreeI_Presentを聞いたか？
            {0x20E, new EventFlagPlayer(0 , 1   , 0526, "IslandDevQuestTalkAfterBuildCamp"           )}, // たぬきち|キャンプ場が完成してから会話した
            {0x20F, new EventFlagPlayer(0 , 1   , 0527, "IslandDevQuestTalkAboutFirstCamper"         )}, // たぬきち|１人目のキャンプ客に会いに行く依頼を自身が受けた
            {0x210, new EventFlagPlayer(0 , 1   , 0528, "GetHousingKitForFirstCamper"                )}, // たぬきち|１人目のキャンプ客用のハウジングキット受け取った
            {0x211, new EventFlagPlayer(0 , 1   , 0529, "ItemFullHousingKitForFirstCamper"           )}, // たぬきち|１人目のキャンプ客用のキット、持ち物いっぱいで受取失敗した
            {0x212, new EventFlagPlayer(0 , 1   , 0530, "SetHousingKitForFirstCamper"                )}, // たぬきち|１人目のキャンプ客用のハウジングキットを、自らセットした
            {0x214, new EventFlagPlayer(0 , 6   , 0532, "ChyDaily_InsectSellNum"                     )}, // レックス|今回の来訪中に買取した数
            {0x216, new EventFlagPlayer(0 , 1   , 0534, "SharePlayGuideDone"                         )}, // おすそわけプレイの解説ダイアログを見た
            {0x217, new EventFlagPlayer(0 , 1   , 0535, "CommuneIslandAvailable"                     )}, // パニエル|コミューン島に招待された
            {0x218, new EventFlagPlayer(0 , 1   , 0536, "VisitedCommune"                             )}, // コミューン島に上陸したことがある
            {0x21A, new EventFlagPlayer(0 , 1   , 0538, "ChyEvent_TalkTrophyGold"                    )}, // [大会]レックス|金トロフィ会話した？
            {0x21B, new EventFlagPlayer(0 , 1   , 0539, "ChyEvent_TalkTrophySilver"                  )}, // [大会]レックス|銀トロフィ会話した？
            {0x21C, new EventFlagPlayer(0 , 1   , 0540, "ChyEvent_TalkTrophyCopper"                  )}, // [大会]レックス|銅トロフィ会話した？
            {0x21D, new EventFlagPlayer(0 , 1   , 0541, "BeyEvent_TalkTrophyGold"                    )}, // [大会]ジャスティン|金トロフィ会話した？
            {0x21E, new EventFlagPlayer(0 , 1   , 0542, "BeyEvent_TalkTrophySilver"                  )}, // [大会]ジャスティン|銀トロフィ会話した？
            {0x21F, new EventFlagPlayer(0 , 1   , 0543, "BeyEvent_TalkTrophyCopper"                  )}, // [大会]ジャスティン|銅トロフィ会話した？
            {0x220, new EventFlagPlayer(0 , 1   , 0544, "SpnFirstTalkedAtCommuneIsland"              )}, // パニエル|コミューン島で初回会話した？
            {0x222, new EventFlagPlayer(0 , 1   , 0546, "AppUrgentEscapeCallToday"                   )}, // 緊急脱出|本日電話した
            {0x223, new EventFlagPlayer(0 , 1   , 0547, "KotonoGotSampleFlag"                        )}, // ことの|サンプルもらった？
            {0x224, new EventFlagPlayer(0 , 1   , 0548, "KotonoGotTicketFlag"                        )}, // ことの|ひきかえけんもらったことある？
            {0x225, new EventFlagPlayer(0 , 1   , 0549, "OwsFirstTalk"                               )}, // フーコ|面識ある？
            {0x226, new EventFlagPlayer(0 , 1   , 0550, "OwsTalkedToday"                             )}, // フーコ|今日会話した？
            {0x22A, new EventFlagPlayer(0 , 1   , 0554, "OwsPresentFirstRecipe"                      )}, // フーコ|最初のレシピもらった？
            {0x22B, new EventFlagPlayer(0 , 1   , 0555, "SpnPhotoStudioGuideDone"                    )}, // パニエル|撮影スタジオの説明を聞いた
            {0x22C, new EventFlagPlayer(0 , 1   , 0556, "GetBirthdayCake"                            )}, // 今年バースデーケーキをもらった
            {0x22D, new EventFlagPlayer(0 , 1   , 0557, "GetBirthdayFloorParty"                      )}, // 今年パーティのゆかをもらった
            {0x22E, new EventFlagPlayer(0 , 1   , 0558, "GetBirthdayWallParty"                       )}, // 今年パーティのかべがみをもらった
            {0x22F, new EventFlagPlayer(0 , 1   , 0559, "AddHairStyle1"                              )}, // 『ポップなヘアアレンジ』解禁
            {0x230, new EventFlagPlayer(0 , 1   , 0560, "AddHairStyle2"                              )}, // 『クールなヘアアレンジ』解禁
            {0x231, new EventFlagPlayer(0 , 1   , 0561, "AddHairStyle3"                              )}, // 寝ぐせ解禁
            {0x232, new EventFlagPlayer(0 , 1   , 0562, "TanuportAmiiboBromideUnlock"                )}, // タヌポート|amiibo ブロマイド機能を解禁
            {0x233, new EventFlagPlayer(0 , 1   , 0563, "AddHairColor"                               )}, // タヌポート|追加ヘアカラー解禁
            {0x234, new EventFlagPlayer(0 , 1   , 0564, "EnableDiyRemake"                            )}, // DIY作業台|リメイク解禁
            {0x235, new EventFlagPlayer(0 , 1   , 0565, "GetLicenseGrdStone"                         )}, // 工事ライセンス|道路工事：石だたみ解禁
            {0x236, new EventFlagPlayer(0 , 1   , 0566, "GetLicenseGrdBrick"                         )}, // 工事ライセンス|道路工事：レンガの道解禁
            {0x237, new EventFlagPlayer(0 , 1   , 0567, "GetLicenseGrdDarkSoil"                      )}, // 工事ライセンス|道路工事：畑の道解禁
            {0x238, new EventFlagPlayer(0 , 1   , 0568, "GetLicenseGrdStonePattern"                  )}, // 工事ライセンス|道路工事：おうぎの石だたみ解禁
            {0x239, new EventFlagPlayer(0 , 1   , 0569, "GetLicenseGrdSand"                          )}, // 工事ライセンス|道路工事：すなの道解禁
            {0x23A, new EventFlagPlayer(0 , 1   , 0570, "GetLicenseGrdTile"                          )}, // 工事ライセンス|道路工事：テラコッタタイル解禁
            {0x23B, new EventFlagPlayer(0 , 1   , 0571, "GetLicenseGrdWood"                          )}, // 工事ライセンス|道路工事：くみ木の道解禁
            {0x23C, new EventFlagPlayer(0 , 1   , 0572, "GetLicenseRiver"                            )}, // 工事ライセンス|河川工事解禁
            {0x23D, new EventFlagPlayer(0 , 1   , 0573, "GetLicenseCliff"                            )}, // 工事ライセンス|崖工事解禁
            {0x23E, new EventFlagPlayer(0 , 1   , 0574, "EquipLicenseHelmet"                         )}, // 工事ライセンス|装備状態
            {0x240, new EventFlagPlayer(0 , 1   , 0576, "OwsPresentTodayRecipe"                      )}, // フーコ|今日レシピ（または素材）もらった？
            {0x241, new EventFlagPlayer(0 , 1   , 0577, "OwsPresentThisZodiacRecipe"                 )}, // フーコ|今月の星座レシピもらった
            {0x242, new EventFlagPlayer(1 , 12  , 0578, "OwsThisZodiac"                              )}, // フーコ|最後に遊んだ日の星座
            {0x243, new EventFlagPlayer(0 , 1   , 0579, "NewYearPlayReportSend"                      )}, // カウントダウンのプレイレポートを送った
            {0x244, new EventFlagPlayer(0 , 1   , 0580, "RctOutsideHintToday"                        )}, // 今日、屋外ヒントつぶきちと会話した
            {0x245, new EventFlagPlayer(0 , 1   , 0581, "DecideShopArea"                             )}, // お店の建設場所を決定した
            {0x246, new EventFlagPlayer(0 , 1   , 0582, "HeardEatingHintAtShop"                      )}, // お店で「食べる」ヒント聞いた
            {0x248, new EventFlagPlayer(0 , 1   , 0584, "KinuyoExplainFittingRoomFlag"               )}, // きぬよ|試着室の説明聞いたことある？
            {0x249, new EventFlagPlayer(0 , 1   , 0585, "HasLookMyHouseExplain"                      )}, // 家の機能説明ダイアログを見たことがある？
            {0x24A, new EventFlagPlayer(0 , 1   , 0586, "TownNewsHeardRemakeTrialFlag"               )}, // 村内放送|リメイク体験開催のお知らせを聞いた？
            {0x24B, new EventFlagPlayer(0 , 1   , 0587, "RcoEnableRemakeTrial"                       )}, // たぬきち|リメイク体験選択肢解禁
            {0x24C, new EventFlagPlayer(0 , 1   , 0588, "RcoRemakeTrialOngoing"                      )}, // たぬきち|リメイク体験中
            {0x24D, new EventFlagPlayer(0 , 1   , 0589, "RcoRemakeTrialGetFurniture"                 )}, // たぬきち|リメイク体験中に必要な家具を持った状態でたぬきちに話しかけた
            {0x24F, new EventFlagPlayer(0 , 1   , 0591, "RcoTalkAboutRemakeTrial"                    )}, // たぬきち|リメイク体験会のお誘い会話発動させるか？
            {0x250, new EventFlagPlayer(0 , 1   , 0592, "RcoStayMyHouseImmQClear"                    )}, // たぬきち|移住クエストクリアで自宅前にくるか？
            {0x251, new EventFlagPlayer(0 , 5   , 0593, "1stPresentHatType"                          )}, // (1P)初期HAからもらった帽子タイプは？
            {0x253, new EventFlagPlayer(0 , 1   , 0595, "DodHeardAboutMileTravelTicket"              )}, // モーリー|たぬきちから預かったマイル旅行券の説明聞いたか？
            {0x255, new EventFlagPlayer(0 , 1   , 0597, "DocMysterytourExplain1st"                   )}, // ロドリー|ミステリーツアー初上陸で説明聞いた？
            {0x256, new EventFlagPlayer(0 , 3   , 0598, "CampGameClear"                              )}, // キャンプゲームクリア回数
            {0x257, new EventFlagPlayer(0 , 1   , 0599, "RctTnx4CollectingMaterials"                 )}, // つぶきち|資材集め協力のお礼を聞いた？
            {0x258, new EventFlagPlayer(0 , 1   , 0600, "RctTnx4CollectingMaterials2"                )}, // つぶきち|資材集め終了のお礼を聞いた？
            {0x259, new EventFlagPlayer(0 , 1   , 0601, "RctTnx4ConfirmingStorePlace"                )}, // つぶきち|店の場所決め終了のお礼を聞いた？
            {0x25A, new EventFlagPlayer(0 , 1   , 0602, "RcoFinishAdvice"                            )}, // たぬきち|アドバイス終了？
            {0x25B, new EventFlagPlayer(5 , 5   , 0603, "RumorPFavoriteProgressDays"                 )}, // RumorP_Favoriteを聞いてからの経過日数
            {0x25C, new EventFlagPlayer(0 , 1   , 0604, "PAnnounceExplainCeremony"                   )}, // 島内放送|セレモニーの説明入った？
            {0x25D, new EventFlagPlayer(0 , 1   , 0605, "PAnnounceTailorBuilt"                       )}, // 島内放送|仕立て屋オープンの話聞いた？
            {0x25E, new EventFlagPlayer(0 , 1   , 0606, "RctHintCongratsMyhome"                      )}, // つぶきち|マイホームのお祝いを聞いた？
            {0x25F, new EventFlagPlayer(0 , 1   , 0607, "PAnnounceCampsite"                          )}, // 島内放送|キャンプ場オープンの話聞いた？
            {0x260, new EventFlagPlayer(0 , 1   , 0608, "PAnnounceHeardOfficeRenual"                 )}, // 島内放送|案内所改装の話聞いた？
            {0x261, new EventFlagPlayer(0 , 1   , 0609, "RcoFirstTalkNewOffice"                      )}, // たぬきち|案内所建物初会話聞いた？
            {0x262, new EventFlagPlayer(0 , 1   , 0610, "ItemRingEnable"                             )}, // アイテムリング解禁
            {0x263, new EventFlagPlayer(0 , 1   , 0611, "RcoTalkAboutOfficeWork"                     )}, // たぬきち|案内所での業務内容聞いた？
            {0x264, new EventFlagPlayer(0 , 1   , 0612, "TwinTurnipExplanation"                      )}, // まめつぶからカブ価と高額買取品の説明聞いた？
            {0x265, new EventFlagPlayer(0 , 1   , 0613, "HeldCeremonyMarket1"                        )}, // セレモニ|商店（小）を開いた
            {0x266, new EventFlagPlayer(0 , 1   , 0614, "HeldCeremonyMarket2"                        )}, // セレモニ|商店（大）を開いた
            {0x267, new EventFlagPlayer(0 , 1   , 0615, "HerdCeremonyOffice"                         )}, // セレモニ|案内所を開いた
            {0x268, new EventFlagPlayer(0 , 1   , 0616, "HeldCeremonyMuseum"                         )}, // セレモニ|博物館を開いた
            {0x269, new EventFlagPlayer(0 , 1   , 0617, "HeldCeremonyTailor"                         )}, // セレモニ|仕立て屋を開いた
            {0x26A, new EventFlagPlayer(0 , 1   , 0618, "HeldCeremonyCampSite"                       )}, // セレモニ|キャンプ場を開いた
            {0x26B, new EventFlagPlayer(0 , 1   , 0619, "HeldCeremonyBridge"                         )}, // セレモニ|橋を開いた
            {0x26C, new EventFlagPlayer(0 , 1   , 0620, "HeldCeremonySlope"                          )}, // セレモニ|坂を開いた
            {0x26D, new EventFlagPlayer(0 , 1   , 0621, "HghPeddlerPurchaceToday"                    )}, // きぬよ行商|今回の来訪で商品購入した
            {0x26E, new EventFlagPlayer(0 , 1   , 0622, "RollanBuyWallpaperCount"                    )}, // ローラン|今日フシギなかべがみを買った？
            {0x26F, new EventFlagPlayer(0 , 1   , 0623, "RollanBuyCarpetCount"                       )}, // ローラン|今日フシギなゆかを買った？
            {0x270, new EventFlagPlayer(0 , 1   , 0624, "RcoTalkAboutMoveBuilding"                   )}, // たぬきち|建物移設の説明した
            {0x271, new EventFlagPlayer(0 , 1   , 0625, "UseMigrantHousingKit1st"                    )}, // 移住クエ用ハウジングキットを初めて使用しようとした
            {0x272, new EventFlagPlayer(0 , 1   , 0626, "RcoHeardLadderExplain"                      )}, // たぬきち|電話ではしごの説明を聞いた
            {0x273, new EventFlagPlayer(0 , 1   , 0627, "RcoReciveMigrantEvPhone1st"                 )}, // たぬきち|移住クエ予定地設置後初めての電話かかってきた
            {0x274, new EventFlagPlayer(0 , 1   , 0628, "SzaTalkAboutIncresePopulation"              )}, // しずえ|島の評判：人口8人突破報告を聞いた
            {0x275, new EventFlagPlayer(0 , 1   , 0629, "RcoMoveCampSiteReserved"                    )}, // たぬきち|キャンプ場の移設を予約している
            {0x276, new EventFlagPlayer(0 , 1   , 0630, "SkkPurchaseToday"                           )}, // シャンク|今回の来訪で商品購入した
            {0x277, new EventFlagPlayer(0 , 1   , 0631, "SkkTalkTodayFlag"                           )}, // シャンク|今日会話した？
            {0x278, new EventFlagPlayer(0 , 1   , 0632, "TkkFirstLiveJoined"                         )}, // とたけけ|初ライブに自身が参加した？
            {0x279, new EventFlagPlayer(0 , 1   , 0633, "FirstPlayAfterPlayerMake"                   )}, // このプレイヤを作った初日？
            {0x27A, new EventFlagPlayer(0 , 1   , 0634, "RcoMigrantProgressTalk1st"                  )}, // たぬきち|移住クエ経過強制会話を聞いたことがある？
            {0x27B, new EventFlagPlayer(0 , 1   , 0635, "DodTodayFlightMileGet"                      )}, // モーリー|今日のおでかけマイルもらった
            {0x27C, new EventFlagPlayer(0 , 1   , 0636, "PAnnouceHeardRemakeWsNewsToday"             )}, // 島内放送|今日リメイクワークショップの案内聞いた
            {0x27D, new EventFlagPlayer(0 , 1   , 0637, "HghGetTailorHousingKit"                     )}, // きぬよ|自分が仕立て屋予定地キット受け取った
            {0x27E, new EventFlagPlayer(0 , 1   , 0638, "SzaTalkAboutIncreseHousingKit"              )}, // しずえ|島の評判：ハウジングキット含め８軒突破報告を聞いた
            {0x27F, new EventFlagPlayer(0 , 1   , 0639, "HghHeardRequestHousingKit"                  )}, // きぬよ|仕立て屋の場所探しの依頼を聞いた
            {0x280, new EventFlagPlayer(0 , 1   , 0640, "HghEndRequestHousingKit"                    )}, // きぬよ|仕立て屋の場所探しの話が完結した
            {0x281, new EventFlagPlayer(0 , 1   , 0641, "OfficeSzaIntroduction"                      )}, // 案内所|強制会話で直接しずえの紹介受けた
            {0x282, new EventFlagPlayer(0 , 1   , 0642, "PAnnouceHeardKkProject"                     )}, // 島内放送|とたけけプロジェクトの予告発生した？
            {0x283, new EventFlagPlayer(0 , 1   , 0643, "RcoHeardAboutKkProject1st"                  )}, // たぬきち|けけプロジェクトの存在を聞いた？
            {0x284, new EventFlagPlayer(0 , 1   , 0644, "GetLicenseGrdMydesign"                      )}, // 工事ライセンス|道路工事：マイデザイン地面貼り工事解禁
            {0x285, new EventFlagPlayer(0 , 1   , 0645, "RcoHeardAbout1stCamperToday"                )}, // たぬきち|初キャンパーの話と勧誘依頼を今日聞いた？
            {0x286, new EventFlagPlayer(0 , 1   , 0646, "RcoHeardAboutEvaluationStart"               )}, // たぬきち|評価開始前の会話を聞いた？
            {0x287, new EventFlagPlayer(0 , 1   , 0647, "RcoHeardAboutEvalutationDetail"             )}, // たぬきち|評価の詳細を聞いた？
            {0x288, new EventFlagPlayer(0 , 1   , 0648, "RcoAwaitingExplanation"                     )}, // たぬきち|お願い聞いてねと頼まれてる状態？
            {0x289, new EventFlagPlayer(0 , 1   , 0649, "SzaHeardAboutEvaluationDetail"              )}, // しずえ|村の評判の詳細説明を聞いた？
            {0x28A, new EventFlagPlayer(0 , 1   , 0650, "PopDiyGoldFromStoneToday"                   )}, // 今日、岩から金鉱石を出した？
            {0x28B, new EventFlagPlayer(0 , 1   , 0651, "BeyEvent_TalkFirst"                         )}, // [大会]ジャスティン|つり大会の日に会話したか？
            {0x28C, new EventFlagPlayer(0 , 10  , 0652, "AppUrgentEscapeMobCounter"                  )}, // 緊急脱出|ラケットさん出現カウンター
            {0x28D, new EventFlagPlayer(0 , 1   , 0653, "AppUrgentEscapeTodayShiftMob"               )}, // 緊急脱出|今日の当番はラケットさん
            {0x28E, new EventFlagPlayer(0 , 1   , 0654, "GotMedicineRecipe"                          )}, // (NPCから)おくすりのレシピをもらった
            {0x28F, new EventFlagPlayer(0 , 1   , 0655, "MessageCardPayment"                         )}, // メッセージカードの代金を支払っているか
            {0x290, new EventFlagPlayer(0 , 1   , 0656, "PlayerHalfAsleepDemoFlag"                   )}, // 寝ぼけデモフラグ
            {0x291, new EventFlagPlayer(0 , 1   , 0657, "ChyEvent_TalkFirst"                         )}, // [大会]レックス|ムシとり大会の日に会話をしたか？
            {0x292, new EventFlagPlayer(0 , 1   , 0658, "RcoWallFtrRemoveHouseRemodel"               )}, // たぬきち｜家増築時に壁掛け家具の撤去が発生した？
            {0x293, new EventFlagPlayer(0 , 1   , 0659, "LegacyMyDesignDLEnable"                     )}, // Blanco|3DSマイデザインのダウンロード解禁
            {0x294, new EventFlagPlayer(0 , 1   , 0660, "Got2ndLoach"                                )}, // 2匹目のドジョウ
            {0x295, new EventFlagPlayer(0 , 1   , 0661, "PlayReportDaily"                            )}, // デイリープレイレポート
            {0x296, new EventFlagPlayer(0 , 1   , 0662, "UseCloset"                                  )}, // クロゼット機能を利用したことがある
            {0x297, new EventFlagPlayer(0 , 1   , 0663, "RemakeWs_TalkWhenItemFull"                  )}, // リメイク体験会で持ち物いっぱいを指摘された
            {0x299, new EventFlagPlayer(0 , 1   , 0665, "ImmQCompleteDemo"                           )}, // 移住クエスト|クリア時の単独デモを見たか？
            {0x29A, new EventFlagPlayer(0 , 1   , 0666, "DodSelectCommune1st"                        )}, // モーリー|コミューン島に行くを選んだことがある
            {0x29B, new EventFlagPlayer(0 , 1   , 0667, "SpnTalkAtHomelandToday"                     )}, // パニエル|自分の島で会話して招待された当日か？
            {0x29C, new EventFlagPlayer(0 , 1   , 0668, "SpnTalkAtCommuneToday"                      )}, // パニエル|今日コミューン島で会話したか？
            {0x29D, new EventFlagPlayer(0 , 1   , 0669, "UpgradePocket30"                            )}, // 持ち物欄が30に拡張された
            {0x29E, new EventFlagPlayer(0 , 1   , 0670, "UpgradePocket40"                            )}, // 持ち物欄が40に拡張された
            {0x29F, new EventFlagPlayer(0 , 20  , 0671, "IllegalReportCount"                         )}, // 通報回数
            {0x2A0, new EventFlagPlayer(0 , 1   , 0672, "SellPocket40"                               )}, // 持ち物欄を40にするアイテムを陳列するか？
            {0x2A1, new EventFlagPlayer(0 , 1   , 0673, "BeyDaily_GetDemo_Clear"                     )}, // 来訪クエスト達成時ゲットデモを見たか？
            {0x2A2, new EventFlagPlayer(0 , 1   , 0674, "OpenDIYRecipeEtcCategory"                   )}, // DIYレシピ・作業台|タブカテゴリ【その他】解禁
            {0x2A3, new EventFlagPlayer(0 , 1   , 0675, "RcoBuildBridgeSlopeMyself"                  )}, // たぬきち|今、橋/坂建設を申し込んでいるのが自分？
            {0x2A4, new EventFlagPlayer(0 , 1   , 0676, "RcoRemoveBridgeSlopeMyself"                 )}, // たぬきち|今、橋/坂撤去を申し込んでいるのが自分？
            {0x2A5, new EventFlagPlayer(0 , 1   , 0677, "RcoTalkAboutBuildBridgeSlope"               )}, // たぬきち|橋/坂建築について説明受けた
            {0x2A6, new EventFlagPlayer(0 , 1   , 0678, "RcoTalkAboutHaniwa"                         )}, // たぬきち|募金集めのハニワについて説明受けた
            {0x2A7, new EventFlagPlayer(0 , 1   , 0679, "PAnnounceHintRnd"                           )}, // 村内放送|ヒント発生制御用フラグ
            {0x2A8, new EventFlagPlayer(0 , 1   , 0680, "PickUpFirst"                                )}, // Yボタン「ひろう」が可能な状態だが、ものを拾ったことがない
            {0x2A9, new EventFlagPlayer(0 , 1   , 0681, "StandByGameStartPhoneCall"                  )}, // 電話デモ|ゲーム開始時入電するか？
            {0x2AA, new EventFlagPlayer(0 , 1   , 0682, "StandByPhoneCallPrintService"               )}, // 電話デモ|プリントサービス入電するか？
            {0x2AB, new EventFlagPlayer(0 , 1   , 0683, "StandByPhoneCallSharePlay"                  )}, // 電話デモ|おすそわけ解禁入電するか？
            {0x2AC, new EventFlagPlayer(0 , 1   , 0684, "StandByPhoneCallPurchaseBox"                )}, // 電話デモ|買取BOX入金電話するか？
            {0x2AD, new EventFlagPlayer(0 , 3   , 0685, "HeardAboutFreeDKeywordA"                    )}, // 肩書会話|今日同じ島のPの肩書会話を聞いた？
            {0x2AE, new EventFlagPlayer(0 , 3   , 0686, "HeardAboutFreeDKeywordB"                    )}, // 肩書会話|今日他の島のPの肩書会話を聞いた？
            {0x2AF, new EventFlagPlayer(0 , 3   , 0687, "HeardAboutFreeDKeywordC"                    )}, // 肩書会話|今日訪問先のPの肩書会話を聞いた？
            {0x2B0, new EventFlagPlayer(0 , 1   , 0688, "RcoMoveSomeBuiding"                         )}, // たぬきち|なにかの建物の移設を依頼しているか？
            {0x2B1, new EventFlagPlayer(0 , 1   , 0689, "BuiltMyHome"                                )}, // マイホームが建った
            {0x2B2, new EventFlagPlayer(0 , 1   , 0690, "RcoMoveHousingSetSomeBuild"                 )}, // たぬきち|移設用のハウジングキット設置した
            {0x2B4, new EventFlagPlayer(0 , 1   , 0692, "SzaIslandEvaluation5star1st"                )}, // しずえ|島の評価で初めて５つ星とった
            {0x2B5, new EventFlagPlayer(0 , 1   , 0693, "JohnnySitUpBeforeFlag"                      )}, // ジョニー|今までに起こしたことある？(海賊ジョニーは別フラグ)
            {0x2B6, new EventFlagPlayer(0 , 1   , 0694, "CampFirstTalk_FirstVisitor"                 )}, // キャンパーNPCとの初回会話を済ませた(初回キャンパー用）
            {0x2B7, new EventFlagPlayer(0 , 1   , 0695, "BocAllowAddBuyCount"                        )}, // ウリ|カブ購入回数加算許可
            {0x2B8, new EventFlagPlayer(0 , 10  , 0696, "BocBuyCount"                                )}, // ウリ|カブ購入回数
            {0x2B9, new EventFlagPlayer(0 , 300 , 0697, "BocBuyNumCount"                             )}, // ウリ|カブ購入個数
            {0x2BD, new EventFlagPlayer(0 , 10  , 0701, "EmoticonLastLearnVillagerIndex"             )}, // 最後に漫符を教わったNPCの住人番号
            {0x2BE, new EventFlagPlayer(0 , 1   , 0702, "MainmenuUnlockMydesingPro"                  )}, // スマホUI|PROデザイン解禁
            {0x2BF, new EventFlagPlayer(0 , 255 , 0703, "HeardCurrentPlayerActivityInfo"             )}, // 今回の行動に関する噂話を聞いたプレイヤーの情報
            {0x2C0, new EventFlagPlayer(0 , 255 , 0704, "HeardPreviousPlayerActivityInfo"            )}, // 前回の行動に関する噂話を聞いたプレイヤーの情報
            {0x2C1, new EventFlagPlayer(0 , 9999, 0705, "DodPresentCounter"                          )}, // 飛行場|ノベルティ用搭乗回数
            {0x2C2, new EventFlagPlayer(0 , 3   , 0706, "DodPresentCounterToday"                     )}, // 飛行場|今日の搭乗回数カウンタ
            {0x2C3, new EventFlagPlayer(0 , 1   , 0707, "DodSingleFlightToday"                       )}, // 飛行場|今日ツアー島、パニー島に行ったか？
            {0x2C4, new EventFlagPlayer(0 , 20  , 0708, "DodPresentSendCounter"                      )}, // 飛行場|ノベルティ入手カウンタ
            {0x2C5, new EventFlagPlayer(-1, -1  , 0709, "BDayMsgSenderSNpcUniqueID0"                 )}, // バースデーメッセージを送ったSNpcのユニークID
            {0x2C6, new EventFlagPlayer(-1, -1  , 0710, "BDayMsgSenderSNpcUniqueID1"                 )}, // バースデーメッセージを送ったSNpcのユニークID
            {0x2C7, new EventFlagPlayer(-1, -1  , 0711, "BDayMsgSenderNNpcUniqueID0"                 )}, // バースデーメッセージを送ったNNpcのユニークID
            {0x2C8, new EventFlagPlayer(-1, -1  , 0712, "BDayMsgSenderNNpcUniqueID1"                 )}, // バースデーメッセージを送ったNNpcのユニークID
            {0x2C9, new EventFlagPlayer(0 , -1  , 0713, "BDayMsgRandomSead"                          )}, // バースデーメッセージの内容を決定する乱数のシード値
            {0x2CA, new EventFlagPlayer(0 , 1   , 0714, "UnlockMyDesignProCategory"                  )}, // スマホUI|PROデザインのタブカテゴリ解禁
            {0x2D5, new EventFlagPlayer(0 , 30  , 0725, "BalloonShootCountToday"                     )}, // 今日風船をいくつ撃ったか？
            {0x2D6, new EventFlagPlayer(0 , 1   , 0726, "ContributedBuildBridgeorSlope"              )}, // セレモニ|橋か坂の建設に貢献した
            {0x2D7, new EventFlagPlayer(0 , 1   , 0727, "ContributedTodaysCeremonyBridgeorSlope"     )}, // セレモニ|今日の橋か坂のセレモニーに貢献した
            {0x2D8, new EventFlagPlayer(0 , 1   , 0728, "Mobile1stBootAfterUnlockPro_Mydesign"       )}, // プロ編集解禁後スマホアプリ初起動|マイデザイン
            {0x2D9, new EventFlagPlayer(0 , 1   , 0729, "TkkBirthdayMessageFlag"                     )}, // とたけけ|バースデーメッセージ送った？
            {0x2DA, new EventFlagPlayer(0 , 1   , 0730, "TalkFirstCamperAfterSetHousing"             )}, // たぬきち|１人目のキャンプ客とハウジングキットセット後会話した
            {0x2DB, new EventFlagPlayer(0 , 1   , 0731, "TalkFirstCamperAfterRequestSetHousing"      )}, // たぬきち|１人目のキャンプ客とハウジングキット設置依頼後会話した
            {0x2DC, new EventFlagPlayer(0 , 1   , 0732, "NnpcAppE_Rep_OccuredToday"                  )}, // NNPC_ApproachE_IslandReputationが今日発生した
            {0x2DD, new EventFlagPlayer(0 , 10  , 0733, "SzaPAAccidentCounter"                       )}, // 村内放送|しずえがハッとするイベント発生カウンタ
            {0x2DF, new EventFlagPlayer(0 , 1   , 0735, "SzaIslandEvaluationTalkAbout1Star"          )}, // しずえ|島の環境：ゆうたろうからの感想を見たことがある
            {0x2E0, new EventFlagPlayer(0 , 1   , 0736, "SzaIslandEvaluationHeardToday"              )}, // しずえ|島の環境を今日聞いた
            {0x2E4, new EventFlagPlayer(0 , 1   , 0740, "DailyQuestFivePointDay"                     )}, // 日課の5倍ポイントデーか？
            {0x2E5, new EventFlagPlayer(0 , 1   , 0741, "DailyQuestFirstFivePoint"                   )}, // 日課の初回5倍ポイント使用済みか？
            {0x2E6, new EventFlagPlayer(0 , 3   , 0742, "DailyQuestFivePointMiss"                    )}, // 日課ポイント5倍デーはずれ回数
            {0x2E7, new EventFlagPlayer(0 , -1  , 0743, "DailyQuestFivePointQuest"                   )}, // 日課ポイント5倍対象ユニークID
            {0x2E8, new EventFlagPlayer(0 , 1   , 0744, "DailyQuestFirstFivePointToday"              )}, // 今日日課の初回5倍ポイントが選ばれているか？
            {0x2E9, new EventFlagPlayer(0 , 1   , 0745, "DailyQuestFivePointSelect"                  )}, // 日課ポイント5倍デー抽選済みフラグ
            {0x2EA, new EventFlagPlayer(0 , 1   , 0746, "AppE_WelcomoMigrants_Occured"               )}, // AppE_WelcomeMigrantsが発生した
            {0x2EB, new EventFlagPlayer(0 , 999 , 0747, "BeyEvent_ResultGetFish"                     )}, // [大会]つり大会|(結果発表用)捕まえたサカナ数
            {0x2EC, new EventFlagPlayer(0 , 999 , 0748, "ChyEvent_ResultGetInsect"                   )}, // [大会]ムシとり大会|(結果発表用)捕まえたムシ数
            {0x2ED, new EventFlagPlayer(0 , 1   , 0749, "KotonoKateTalkFlag"                         )}, // ことの|ケイトの説明聞いたことある？
            {0x2EE, new EventFlagPlayer(0 , 999 , 0750, "BeyEvent_ResultGetPoint"                    )}, // [大会]つり大会|(結果発表用)獲得したポイント
            {0x2EF, new EventFlagPlayer(0 , 999 , 0751, "ChyEvent_ResultGetPoint"                    )}, // [大会]ムシとり大会|(結果発表用)獲得したポイント
            {0x2F0, new EventFlagPlayer(0 , 1   , 0752, "PhoneCallByRcm"                             )}, // 電話デモ|まめきちの入電受けたことある
            {0x2F1, new EventFlagPlayer(0 , 1   , 0753, "PhoneCallByRct"                             )}, // 電話デモ|つぶきちの入電受けたことある
            {0x2F2, new EventFlagPlayer(0 , 1   , 0754, "ThisPCcreatedbeforeOfficeUpgrading"         )}, // 案内所がテントのうちに作成されたプレイヤーか？
            {0x2F3, new EventFlagPlayer(0 , 1   , 0755, "RcoMachineAmiiboCamperUnlock"               )}, // タヌポート|amiiboキャンパー勧誘機能解禁
            {0x2F4, new EventFlagPlayer(0 , 1   , 0756, "ObjRcoMachineHeardExplanation"              )}, // タヌポート|たぬきちの最初の説明を聞いた？
            {0x2F5, new EventFlagPlayer(0 , 1   , 0757, "OwlHeardInsectExplanation"                  )}, // フータ|寄贈経由でムシの解説を聞いたことがある？
            {0x2F6, new EventFlagPlayer(0 , 1   , 0758, "OwlEverDonatedInsect"                       )}, // フータ|自分がムシを寄贈したことがある
            {0x2F7, new EventFlagPlayer(0 , 1   , 0759, "2P_CreatedAfterOwlMoving"                   )}, // フータのテント完成以降に作られたプレイヤー
            {0x2F8, new EventFlagPlayer(0 , 1   , 0760, "OwlGotDiyRecipe"                            )}, // フータからテントでDIYレシピもらったか？
            {0x2F9, new EventFlagPlayer(0 , 1   , 0761, "RcoTalkAboutMoveMyHome"                     )}, // たぬきち|自宅の移設の解禁情報を聞いた？
            {0x2FA, new EventFlagPlayer(0 , 1   , 0762, "RcoPAnnounceMuseumSP"                       )}, // 島内放送|フータ移住アナウンスで寄贈完了のことを聞いた？
            {0x2FB, new EventFlagPlayer(0 , 1   , 0763, "PAnnounceHeardMarketUpgradeInfo"            )}, // 島内放送|商店小→大の改装決定のアナウンスを聞いた？(たぬきち)
            {0x2FC, new EventFlagPlayer(0 , 1   , 0764, "PAnnounceHeardMarketUpgradeInfoSza"         )}, // 島内放送|商店小→大の改装決定のアナウンスを聞いた？(しずえ)
            {0x2FD, new EventFlagPlayer(0 , 1   , 0765, "NoticeAboutLicenseRiver"                    )}, // 工事ライセンス|河川工事解禁して初起動した？
            {0x2FE, new EventFlagPlayer(0 , 1   , 0766, "NoticeAboutLicenseCliff"                    )}, // 工事ライセンス|崖工事解禁して初起動した？
            {0x2FF, new EventFlagPlayer(0 , 1   , 0767, "OdekakeFirstInternet"                       )}, // 空港|モーリー|おでかけ初めてインターネットの島を選択
            {0x300, new EventFlagPlayer(0 , 1   , 0768, "UploadProfileGrowupDaily"                   )}, // 成長処理でプロフィールアップロードを行ったか？
            {0x301, new EventFlagPlayer(0 , 30  , 0769, "GoldenBalloonCount"                         )}, // 金の風船発生条件カウンタ
            {0x302, new EventFlagPlayer(0 , 200 , 0770, "GoldenAxeLearningCount"                     )}, // 金のオノレシピひらめきカウンタ
            {0x303, new EventFlagPlayer(0 , 3   , 0771, "LastUseLicense"                             )}, // 工事ライセンス|最後に使ったライセンスをできるだけ記憶する
            {0x304, new EventFlagPlayer(0 , 1   , 0772, "GoldenRodRecipeSent"                        )}, // 金のつりざおレシピ投函済か？
            {0x305, new EventFlagPlayer(0 , 1   , 0773, "GoldenNetRecipeSent"                        )}, // 金のあみレシピ投函済か？
            {0x306, new EventFlagPlayer(0 , 1   , 0774, "CompleteFish"                               )}, // サカナコンプリート済か？
            {0x307, new EventFlagPlayer(0 , 1   , 0775, "CompleteInsects"                            )}, // ムシコンプリート済か？
            {0x308, new EventFlagPlayer(0 , 1   , 0776, "Experienced3starEvaluation"                 )}, // ３つ星以下の島の評価を聞いたことがある
            {0x309, new EventFlagPlayer(0 , 20  , 0777, "CountGotTrash"                              )}, // ゴミを釣り上げて入手した回数カウント
            {0x30A, new EventFlagPlayer(0 , 10  , 0778, "CountGotTrash_Can"                          )}, // あきかんを釣り上げて入手した回数カウント
            {0x30B, new EventFlagPlayer(0 , 10  , 0779, "CountGotTrash_Tire"                         )}, // タイヤを釣り上げて入手した回数カウント
            {0x30C, new EventFlagPlayer(0 , 50  , 0780, "JohnnyHelpCount"                            )}, // ジョニー|助けた回数(海賊ジョニーは別フラグ)
            {0x30D, new EventFlagPlayer(0 , 1   , 0781, "CatchtFesBox_Valid"                         )}, // ムシサカナBOXの中身をキープ
            {0x30E, new EventFlagPlayer(0 , 1   , 0782, "TreasurePlayerWin"                          )}, // 宝探しプレイヤー勝利
            {0x30F, new EventFlagPlayer(0 , 1   , 0783, "PAnnounce_SummerShell"                      )}, // 島内放送|季節素材告知_夏_なつのかいがら
            {0x310, new EventFlagPlayer(0 , 1   , 0784, "PAnnounce_AutumnNuts"                       )}, // 島内放送|季節素材告知_秋_木の実
            {0x311, new EventFlagPlayer(0 , 1   , 0785, "UploadPlayerProfileIllegal"                 )}, // アップロードしたプレイヤープロフィールがNG扱いに
            {0x312, new EventFlagPlayer(0 , 1   , 0786, "PAnnounce_AutumnMushroom"                   )}, // 島内放送|季節素材告知_秋_キノコ
            {0x313, new EventFlagPlayer(0 , 1   , 0787, "PAnnounce_WinterSnowFlake"                  )}, // 島内放送|季節素材告知_冬_雪の結晶
            {0x314, new EventFlagPlayer(0 , 1   , 0788, "PAnnounce_WinterSnowball"                   )}, // 島内放送|季節素材告知_冬_雪だるま
            {0x315, new EventFlagPlayer(0 , 1   , 0789, "PAnnounce_WinterOrnament"                   )}, // 島内放送|季節素材告知_冬_オーナメント
            {0x316, new EventFlagPlayer(0 , 1   , 0790, "NotStartImmQByDIYDisable"                   )}, // 移住クエスト|DIY未修得で移住クエストを始められない
            {0x317, new EventFlagPlayer(0 , 1   , 0791, "PAnnounce_AutumnRedLeaf"                    )}, // 島内放送|季節素材告知_秋_もみじ
            {0x318, new EventFlagPlayer(0 , 1   , 0792, "PAnnounce_SpringSakura"                     )}, // 島内放送|季節素材告知_春_桜の花びら
            {0x319, new EventFlagPlayer(0 , 1   , 0793, "PAnnounce_SpringBamboo"                     )}, // 島内放送|季節素材告知_春_春の若竹
            {0x31A, new EventFlagPlayer(0 , 1   , 0794, "RcoHeardInviteRemakeWS"                     )}, // たぬきち|リメイク体験会のお誘い会話聞いた
            {0x31C, new EventFlagPlayer(0 , 1   , 0796, "KinuyoPROdesginFlag"                        )}, // きぬよ|PROデザインの説明聞いたことある？
            {0x31D, new EventFlagPlayer(0 , 1   , 0797, "NoticeAboutMydesingOnWorkBench"             )}, // 作業台|マイデザインリメイク選んで説明ダイアログ見た
            {0x31E, new EventFlagPlayer(0 , -1  , 0798, "LatestMysteryTourUniqueID"                  )}, // 最後に選出したミステリーツアーのユニークID
            {0x31F, new EventFlagPlayer(0 , 1   , 0799, "OwlMultiDonateExplain"                      )}, // フータ|複数鑑定＆コレって何説明聞いた？
            {0x320, new EventFlagPlayer(0 , 1   , 0800, "StandByPhoneCallIslandCreater"              )}, // 電話デモ|島クリエイタの解禁入電するか？
            {0x321, new EventFlagPlayer(0 , -1  , 0801, "PastDaysFromLastPlay"                       )}, // 最後にプレイした日から今日の成長処理までの経過日数
            {0x322, new EventFlagPlayer(0 , 1   , 0802, "UncollectedTreasure"                        )}, // 宝未回収で終了
            {0x323, new EventFlagPlayer(0 , 1   , 0803, "VisitMysteryTourID11"                       )}, // ID: 11のミステリーツアー島にその日行ったことがある
            {0x324, new EventFlagPlayer(0 , 1   , 0804, "VisitMysteryTourID12"                       )}, // ID: 12のミステリーツアー島にその日行ったことがある
            {0x325, new EventFlagPlayer(0 , 1   , 0805, "VisitMysteryTourID13"                       )}, // ID: 13のミステリーツアー島にその日行ったことがある
            {0x326, new EventFlagPlayer(0 , 1   , 0806, "VisitMysteryTourID14"                       )}, // ID: 14のミステリーツアー島にその日行ったことがある
            {0x327, new EventFlagPlayer(0 , 1   , 0807, "VisitMysteryTourID16"                       )}, // ID: 16のミステリーツアー島にその日行ったことがある
            {0x328, new EventFlagPlayer(0 , 1   , 0808, "VisitMysteryTourID17"                       )}, // ID: 17のミステリーツアー島にその日行ったことがある
            {0x329, new EventFlagPlayer(0 , 1   , 0809, "VisitMysteryTourID19"                       )}, // ID: 19のミステリーツアー島にその日行ったことがある
            {0x32A, new EventFlagPlayer(0 , 1   , 0810, "VisitMysteryTourID21"                       )}, // ID: 21のミステリーツアー島にその日行ったことがある
            {0x32B, new EventFlagPlayer(0 , 1   , 0811, "VisitMysteryTourID24"                       )}, // ID: 24のミステリーツアー島にその日行ったことがある
            {0x32C, new EventFlagPlayer(0 , 1   , 0812, "FriendMailGuideRetentionPeriod"             )}, // メッセージカード|サーバ保持期間に関する説明を見たか？
            {0x32D, new EventFlagPlayer(0 , 1   , 0813, "StandByRcoVisitMyHomeAfterTkkFirstLive"     )}, // たぬきち|とたけけライブ後の自宅訪問するか？
            {0x32E, new EventFlagPlayer(0 , 1   , 0814, "SpnTalkBeforeGotHouseToday"                 )}, // パニエル|家ないプレイヤー（ホスト）が島で今日会話した
            {0x32F, new EventFlagPlayer(0 , 1   , 0815, "TodayGrowUp"                                )}, // 今日成長処理済みか
            {0x330, new EventFlagPlayer(0 , 32  , 0816, "KotonoQuestClearCount"                      )}, // ことの|クリアした回数
            {0x331, new EventFlagPlayer(0 , 1   , 0817, "PhotoStudioUseCantCallAmiibo"               )}, // 撮影スタジオ|呼べないamiiboを使った
            {0x332, new EventFlagPlayer(0 , 1   , 0818, "ChyDaily_ObjEntry1"                         )}, // レックス(来訪)|OBJ申込（1回目）した
            {0x333, new EventFlagPlayer(0 , 1   , 0819, "ChyDaily_ObjEntry2"                         )}, // レックス(来訪)|OBJ申込（2回目）した
            {0x334, new EventFlagPlayer(0 , 1   , 0820, "ChyDaily_ObjEntry3"                         )}, // レックス(来訪)|OBJ申込（3回目）した
            {0x335, new EventFlagPlayer(0 , 1   , 0821, "BeyDaily_ObjEntry1"                         )}, // ジャスティン(来訪)|OBJ申込(1回目)した
            {0x336, new EventFlagPlayer(0 , 1   , 0822, "BeyDaily_ObjEntry2"                         )}, // ジャスティン(来訪)|OBJ申込(2回目)した
            {0x337, new EventFlagPlayer(0 , 1   , 0823, "BeyDaily_ObjEntry3"                         )}, // ジャスティン(来訪)|OBJ申込(3回目)した
            {0x338, new EventFlagPlayer(0 , 1   , 0824, "BeyDaily_TalkAlways1"                       )}, // ジャスティン(来訪)|OBJ申込後雑談①聞いた
            {0x339, new EventFlagPlayer(0 , 1   , 0825, "BeyDaily_TalkAlways2"                       )}, // ジャスティン(来訪)|OBJ申込後雑談②聞いた
            {0x33A, new EventFlagPlayer(0 , 1   , 0826, "BeyDaily_TalkAlways3"                       )}, // ジャスティン(来訪)|OBJ申込後雑談③聞いた
            {0x33B, new EventFlagPlayer(0 , 1   , 0827, "CampQuestRecipeGet"                         )}, // キャンプ家具クエストでレシピを貰った
            {0x33C, new EventFlagPlayer(0 , 1   , 0828, "Mobile1stBoot_IslandCreater"                )}, // スマホアプリ初起動|島クリエイター
            {0x33D, new EventFlagPlayer(0 , 1   , 0829, "Closet_Explain_ChangeStick"                 )}, // タンスで変身ステッキの説明を聞いた
            {0x33E, new EventFlagPlayer(0 , 1   , 0830, "TkkFirstLiveToday"                          )}, // とたけけ|今日初めてライブを聴いた？
            {0x33F, new EventFlagPlayer(0 , 1   , 0831, "1stBootIslandCreaterCleanService"           )}, // 島クリエイター|お片付けサービスの説明聞いた
            {0x340, new EventFlagPlayer(0 , 1   , 0832, "MarketBuiltMyVillage"                       )}, // 自分の村のお店が開店した
            {0x341, new EventFlagPlayer(0 , 1   , 0833, "Mobile1stBootUnlockCantEditMydesign"        )}, // 編集不可デザイン保存後スマホアプリ初起動|マイデザイン
            {0x342, new EventFlagPlayer(0 , 1   , 0834, "DodHeardAboutIslandCreator"                 )}, // モーリー|島クリエイター強制解除されたことある？
            {0x343, new EventFlagPlayer(0 , 5   , 0835, "SzaBeforeIslandEvaluation"                  )}, // しずえ|前回聞いた島の評判（１～５）
            {0x344, new EventFlagPlayer(0 , 1   , 0836, "PAnnouceProcessDoneToday"                   )}, // 村内放送のProcess処理を今日行ったか？
            {0x345, new EventFlagPlayer(0 , 1   , 0837, "ImprovePlayerProfile"                       )}, // NG扱いとなったプレイヤープロフィールが修正されたか？
            {0x346, new EventFlagPlayer(0 , 1   , 0838, "EnableInviteMoveoutNPC"                     )}, // よその島の引っ越し状態のNPCを勧誘可能か？
            {0x348, new EventFlagPlayer(0 , 1   , 0840, "TodayMainGrowUp"                            )}, // 今日メインプレイヤーとして成長処理済みか
            {0x349, new EventFlagPlayer(0 , 1   , 0841, "SzaTalkAtOfficeToday"                       )}, // しずえ|案内所で今日話しかけたか？
            {0x34A, new EventFlagPlayer(0 , 1   , 0842, "MainmenuChatLog"                            )}, // スマホUI|チャットログ解禁
            {0x34B, new EventFlagPlayer(0 , 1   , 0843, "Mobile1stBoot_ChatLog"                      )}, // スマホアプリ初起動|チャットログ
            {0x34C, new EventFlagPlayer(0 , 1   , 0844, "Activate_WebService"                        )}, // Blanco解禁
            {0x34D, new EventFlagPlayer(0 , 1   , 0845, "MyDesignExchangeFirstAccess"                )}, // マイデザイン交換端末|初回アクセス
            {0x34E, new EventFlagPlayer(0 , 1   , 0846, "MyDesignExchangeUploadOnce"                 )}, // マイデザイン交換端末|一度でも投稿したか？
            {0x34F, new EventFlagPlayer(0 , 1   , 0847, "OhirakiRollbackTutorial"                    )}, // 通信|緊急おひらきによるロールバックの説明をしたか？
            {0x350, new EventFlagPlayer(0 , 1   , 0848, "SzaTalkFirstNotOffice"                      )}, // しずえ|案内所以外で初めて会話した
            {0x351, new EventFlagPlayer(0 , 1   , 0849, "Talk1stCamperMultiplay"                     )}, // キャンプ場|通信中に最初のキャンパーと会話したか？
            {0x352, new EventFlagPlayer(0 , 20  , 0850, "EasterTodayRecipeRandomGenerateNum"         )}, // イースター|今日のランダム出現レシピ数
            {0x353, new EventFlagPlayer(0 , 1   , 0851, "ObjRcoMachineHeardFenceRecipe"              )}, // タヌポート|たぬきちに柵レシピ解禁の話聞いた？（2P専用）
            {0x354, new EventFlagPlayer(0 , 100 , 0852, "WinningProbabilityOfEasterEggGroundRecipe"  )}, // じめんのたまご関連のレシピの抽選確率
            {0x355, new EventFlagPlayer(0 , 100 , 0853, "WinningProbabilityOfEasterEggRockRecipe"    )}, // いわのたまご関連のレシピの抽選確率
            {0x356, new EventFlagPlayer(0 , 100 , 0854, "WinningProbabilityOfEasterEggLeafRecipe"    )}, // はっぱのたまご関連のレシピの抽選確率
            {0x357, new EventFlagPlayer(0 , 100 , 0855, "WinningProbabilityOfEasterEggForestRecipe"  )}, // もりのたまご関連のレシピの抽選確率
            {0x358, new EventFlagPlayer(0 , 100 , 0856, "WinningProbabilityOfEasterEggSkyRecipe"     )}, // そらとぶたまご関連のレシピの抽選確率
            {0x359, new EventFlagPlayer(0 , 100 , 0857, "WinningProbabilityOfEasterEggFishRecipe"    )}, // サカナのたまご関連のレシピの抽選確率
            {0x35A, new EventFlagPlayer(0 , 20  , 0858, "ShootDownEasterRecipeBalloon"               )}, // イースター|今日、レシピのついたたまご型風船を撃ち落とした数
            {0x35B, new EventFlagPlayer(0 , 5   , 0859, "EasterRecipeAddLotNum"                      )}, // イースター|レシピ出現追加抽選実施回数
            {0x35C, new EventFlagPlayer(0 , 1   , 0860, "PynTalkBeforeFlag"                          )}, // ぴょんたろう|今までに会話したことある？
            {0x35D, new EventFlagPlayer(0 , 1   , 0861, "PynTalkBackTodayFlag"                       )}, // ぴょんたろう|今日背後から話しかけたことある？
            {0x35E, new EventFlagPlayer(0 , 1   , 0862, "PynTalkPreVisitDayFlag"                     )}, // ぴょんたろう|イースター前に会話した？
            {0x35F, new EventFlagPlayer(0 , 1   , 0863, "PynTalkEasterDayFlag"                       )}, // ぴょんたろう|イースター当日に会話した？
            {0x360, new EventFlagPlayer(0 , 1   , 0864, "PynCannotGetItemFlag"                       )}, // ぴょんたろう|受け取り損ねたアイテムがある？
            {0x361, new EventFlagPlayer(0 , 1   , 0865, "PynExplainExchangeEggsFlag"                 )}, // ぴょんたろう|たまご交換の説明を聞いた？
            {0x362, new EventFlagPlayer(0 , 1   , 0866, "PynExplainInventRecipeFlag"                 )}, // ぴょんたろう|プレイヤーがひらめいたレシピの説明を聞いた？
            {0x363, new EventFlagPlayer(0 , 1   , 0867, "PynExplainNnpcRecipeFlag"                   )}, // ぴょんたろう|一般NPCからもらえるレシピのヒントを聞いた？
            {0x364, new EventFlagPlayer(0 , 1   , 0868, "PynGetFirstRecipeEasterDayFlag"             )}, // ぴょんたろう|イースター当日の初回会話でレシピを入手済み？
            {0x365, new EventFlagPlayer(0 , 1   , 0869, "PynGetFinalMissionRecipeFlag"               )}, // ぴょんたろう|イースターの最終お題レシピを入手済み？
            {0x366, new EventFlagPlayer(0 , 1   , 0870, "PynCompleteDiyMissionFlag"                  )}, // ぴょんたろう|イースターのDIYミッションをクリア済み？
            {0x367, new EventFlagPlayer(0 , 1   , 0871, "PynGetEggBasketFlag"                        )}, // ぴょんたろう|たまごのバスケットを入手済み？
            {0x368, new EventFlagPlayer(0 , 1   , 0872, "PynExplainEasterDateFlag"                   )}, // ぴょんたろう|イースターの日付を聞いた？
            {0x369, new EventFlagPlayer(0 , 1   , 0873, "SetMessageBottleEgg"                        )}, // イースター|今日タマゴのメッセージボトルを配置したか
            {0x36A, new EventFlagPlayer(0 , 1   , 0874, "SetTreeEggLeaf"                             )}, // イースター|今日はっぱのタマゴの木を配置したか
            {0x36B, new EventFlagPlayer(0 , 1   , 0875, "BuryEggGround"                              )}, // イースター|今日じめんのタマゴを埋めたか
            {0x36C, new EventFlagPlayer(0 , 1   , 0876, "IsGetMessageBottleEgg"                      )}, // イースター|今日タマゴのメッセージボトルを入手したか
            {0x36D, new EventFlagPlayer(0 , 2   , 0877, "HitMessageBottleEgg"                        )}, // イースター|漂着のタマゴが選ばれた回数
            {0x36E, new EventFlagPlayer(0 , 6   , 0878, "MissMessageBottleEgg"                       )}, // イースター|漂着のタマゴが選ばれなかった回数
            {0x36F, new EventFlagPlayer(0 , 2   , 0879, "EasterNnpcRecipeCount"                      )}, // イースター|一般NPCからもらったレシピの数
            {0x370, new EventFlagPlayer(0 , 10  , 0880, "LastEasterApproachVillagerIndex"            )}, // イースター|最後にイースター用アプローチ会話をしたNPCの住人番号
            {0x371, new EventFlagPlayer(0 , 1   , 0881, "OpenDIYRecipeSeasonCategory"                )}, // DIYレシピ・作業台|タブカテゴリ【季節】解禁
            {0x372, new EventFlagPlayer(0 , 9999, 0882, "LastPlayEasterYear"                         )}, // イースター|最後に遊んだイースターの年
            {0x373, new EventFlagPlayer(0 , 1   , 0883, "PynEvent_SendRecipeMail"                    )}, // イースター|受け取れなかったレシピを手紙で受け取った？
            {0x374, new EventFlagPlayer(0 , 1   , 0884, "PynGetPreVisitRecipeFlag"                   )}, // イースター|準備期間にレシピを受け取った？
            {0x376, new EventFlagPlayer(0 , 1   , 0886, "PynInventRecipeFlag"                        )}, // ぴょんたろう|イースターエッグ関連レシピをひらめいた？
            {0x377, new EventFlagPlayer(0 , 1   , 0887, "SnowmanDIYMailFlag"                         )}, // ゆきだるま|DIYレシピの手紙送った？
            {0x378, new EventFlagPlayer(0 , 64  , 0888, "AlwJuneBrideDayCount"                       )}, // リサ/ジューンブライド|今年クリアした回数
            {0x379, new EventFlagPlayer(0 , 1   , 0889, "EasterCannotGetNnpcRecipeFlag"              )}, // イースター|一般NPCから受け取り損ねたレシピがある？
            {0x37A, new EventFlagPlayer(0 , 1   , 0890, "AlwJuneBrideQuestStartFlag"                 )}, // リサ/ジューンブライド|クエスト開始フラグ
            {0x37B, new EventFlagPlayer(0 , 1   , 0891, "AlwJuneBrideQuestClearFlag"                 )}, // リサ/ジューンブライド|今日クリアした？
            {0x37C, new EventFlagPlayer(0 , 1   , 0892, "StampRallyRunningForPlayer"                 )}, // フータ/国際ミュージアム|スタンプラリーに参加中？
            {0x37D, new EventFlagPlayer(0 , 1   , 0893, "OwlInsectStampRally1"                       )}, // フータ/国際ミュージアム|【ムシ】スタンプ1つ目を押した？
            {0x37E, new EventFlagPlayer(0 , 1   , 0894, "OwlInsectStampRally2"                       )}, // フータ/国際ミュージアム|【ムシ】スタンプ2つ目を押した？
            {0x37F, new EventFlagPlayer(0 , 1   , 0895, "OwlInsectStampRally3"                       )}, // フータ/国際ミュージアム|【ムシ】スタンプ3つ目を押した？
            {0x380, new EventFlagPlayer(0 , 1   , 0896, "OwlFishStampRally1"                         )}, // フータ/国際ミュージアム|【サカナ】スタンプ1つ目を押した？
            {0x381, new EventFlagPlayer(0 , 1   , 0897, "OwlFishStampRally2"                         )}, // フータ/国際ミュージアム|【サカナ】スタンプ2つ目を押した？
            {0x382, new EventFlagPlayer(0 , 1   , 0898, "OwlFishStampRally3"                         )}, // フータ/国際ミュージアム|【サカナ】スタンプ3つ目を押した？
            {0x383, new EventFlagPlayer(0 , 1   , 0899, "OwlFossilStampRally1"                       )}, // フータ/国際ミュージアム|【かせき】スタンプ1つ目を押した？
            {0x384, new EventFlagPlayer(0 , 1   , 0900, "OwlFossilStampRally2"                       )}, // フータ/国際ミュージアム|【かせき】スタンプ2つ目を押した？
            {0x385, new EventFlagPlayer(0 , 1   , 0901, "OwlFossilStampRally3"                       )}, // フータ/国際ミュージアム|【かせき】スタンプ3つ目を押した？
            {0x386, new EventFlagPlayer(0 , 1   , 0902, "AlpJuneBrideExchangeFlag"                   )}, // カイゾー/ジューンブライド|今日交換した？
            {0x387, new EventFlagPlayer(0 , 1   , 0903, "AlwJuneBrideRemakeOpenFlag"                 )}, // リサ/ジューンブライド|リメイクテーマ解禁済み？
            {0x388, new EventFlagPlayer(0 , 9999, 0904, "MailSendFlag_VersionUp"                     )}, // 手紙|アップデートお礼手紙を送った
            {0x389, new EventFlagPlayer(0 , 1   , 0905, "MailSendFlag_BundledEdition"                )}, // 手紙|同梱版購入お礼手紙を送った
            {0x38B, new EventFlagPlayer(0 , 1   , 0907, "GetMayDayTicket"                            )}, // メーデー|メーデーりょこうけんを入手した？
            {0x38C, new EventFlagPlayer(0 , 1   , 0908, "WHEREAREN_VisitDone"                        )}, // HHD|ウェアラン諸島に行ったことがある
            {0x38D, new EventFlagPlayer(0 , 1   , 0909, "PAnnouncePreEaster"                         )}, // 島内放送|イースター準備期間の放送を聞いた？
            {0x390, new EventFlagPlayer(0 , 7   , 0912, "ShootDownEasterOverCountRecipeBalloon"      )}, // イースター|たまご風船をレシピ排出数がない状態で撃ち落とした数をカウント
            {0x391, new EventFlagPlayer(0 , 1   , 0913, "RcoEarthDayAnnouncement"                    )}, // アースデー|案内所たぬきちのアースデー告知を聞いた？
            {0x392, new EventFlagPlayer(0 , 1   , 0914, "RcoEarthDayGetHedge"                        )}, // アースデー|アースデー期間にたぬきちから「いけがき」もらった？
            {0x393, new EventFlagPlayer(0 , 1   , 0915, "SloTalkAboutHedge"                          )}, // レイジ|レイジから「いけがき」の話をされたことある？
            {0x394, new EventFlagPlayer(0 , 3   , 0916, "SloBuyCount"                                )}, // レイジ|行商レイジから買い物した回数
            {0x397, new EventFlagPlayer(0 , 1   , 0919, "TalkRumorOVlgFavoriteToday"                 )}, // 今日RumorOP_Favorite（同じ島の住人P）を聞いたか？
            {0x398, new EventFlagPlayer(0 , 1   , 0920, "EasterCompleteFlag"                         )}, // イースター|イベントを最後までクリアしたことがある？
            {0x399, new EventFlagPlayer(0 , 1   , 0921, "PhoneCallPrintServiceDelayFlag"             )}, // ポスター解禁入電が次回ゲーム開始時に先延ばしされたか？
            {0x39A, new EventFlagPlayer(0 , 1   , 0922, "EarthdayDailyAllClear"                      )}, // アースデー用の5倍日課を両方クリアしたことがある
            {0x39B, new EventFlagPlayer(0 , 9999, 0923, "GetCountEasterEggGround"                    )}, // イースター期間中のじめんのたまごの取得数
            {0x39C, new EventFlagPlayer(0 , 9999, 0924, "GetCountEasterEggRock"                      )}, // イースター期間中のいわのたまごの取得数
            {0x39D, new EventFlagPlayer(0 , 9999, 0925, "GetCountEasterEggLeaf"                      )}, // イースター期間中のはっぱのたまごの取得数
            {0x39E, new EventFlagPlayer(0 , 9999, 0926, "GetCountEasterEggForest"                    )}, // イースター期間中のもりのたまごの取得数
            {0x39F, new EventFlagPlayer(0 , 9999, 0927, "GetCountEasterEggSky"                       )}, // イースター期間中のそらとぶたまごの取得数
            {0x3A0, new EventFlagPlayer(0 , 9999, 0928, "GetCountEasterEggFish"                      )}, // イースター期間中のサカナのたまごの取得数
            {0x3A1, new EventFlagPlayer(0 , 1   , 0929, "DodHeardAboutMayDayTravelTicket"            )}, // メーデー|モーリー|たぬきちから預かったメーデー旅行券の説明聞いたか？
            {0x3A2, new EventFlagPlayer(0 , 1   , 0930, "UseMayDayTicket"                            )}, // メーデー|メーデー旅行券を使用した？
            {0x3A6, new EventFlagPlayer(0 , 1   , 0934, "OwlShowPaintingMyself"                      )}, // フータ|自分が絵画クエストを達成した
            {0x3A7, new EventFlagPlayer(0 , 1   , 0935, "Owl1stTalkMuseum2"                          )}, // フータ|博物館②完成後の挨拶した？
            {0x3A8, new EventFlagPlayer(0 , 1   , 0936, "OwlPaintingQuestExplain"                    )}, // フータ|絵画クエストの説明を受けたか？
            {0x3A9, new EventFlagPlayer(0 , 1   , 0937, "FutaReadyForMuseum2"                        )}, // フータ|博物館②建設条件達成の報告を聞いたか？
            {0x3AA, new EventFlagPlayer(0 , 1   , 0938, "HeldCeremonyMuseum2"                        )}, // セレモニ|博物館②を開いた
            {0x3AB, new EventFlagPlayer(0 , 2   , 0939, "EarthdayDailyClearNum"                      )}, // アースデー専用クエストを今日クリアした数
            {0x3AC, new EventFlagPlayer(0 , 1   , 0940, "OwlShowPaintingBeforeQuest"                 )}, // フータ|絵画クエスト前に絵画を見せたか？
            {0x3AD, new EventFlagPlayer(0 , 1   , 0941, "OwlPaintingQuestDeclined"                   )}, // フータ|絵画クエストで寄贈を断ったことある
            {0x3AE, new EventFlagPlayer(0 , 10  , 0942, "LastIslandRepApproachVillagerIndex"         )}, // 最後に島評判アップアプローチ会話をしたNPCの住人番号
            {0x3B0, new EventFlagPlayer(0 , 1   , 0944, "ChangedPermanentNum"                        )}, // 疑似本体IDが合わないフラグ
            {0x3B1, new EventFlagPlayer(0 , 1   , 0945, "ClearMayDayTour"                            )}, // メーデーツアーの謎解きをクリアした？
            {0x3B2, new EventFlagPlayer(0 , 3   , 0946, "NnpcApproachNoIslandRepCount"               )}, // アプローチ会話｜評判UP応援会話を見ないまま経過したプレイ日数
            {0x3B3, new EventFlagPlayer(0 , 1   , 0947, "JuneBridePlacementDataClearFlag"            )}, // ジューンブライド|配置データクリア
            {0x3B4, new EventFlagPlayer(0 , 1   , 0948, "SloGetHedge"                                )}, // レイジ|レイジから「いけがき」をもらった？
            {0x3B5, new EventFlagPlayer(0 , 1   , 0949, "XctGerReward"                               )}, // メーデー|みしらぬネコから報酬をもらった？
            {0x3B6, new EventFlagPlayer(0 , 1   , 0950, "SpnJuneBrideClearTalkFrag"                  )}, // パニエル/ジューンブライド|今年クリア後の会話した？
            {0x3B7, new EventFlagPlayer(0 , 1   , 0951, "AlwJuneBrideTalkBeforeFlag"                 )}, // リサ|面識ある？
            {0x3B8, new EventFlagPlayer(0 , 1   , 0952, "AlpJuneBrideTalkBeforeFlag"                 )}, // カイゾー|面識ある？
            {0x3B9, new EventFlagPlayer(0 , 1   , 0953, "SpnJuneBrideTalkEventFrag"                  )}, // パニエル/ジューンブライド|今年イベント期間中に会話した？
            {0x3BA, new EventFlagPlayer(0 , 9999, 0954, "PynVisitYear"                               )}, // ぴょんたろうが来訪した年
            {0x3BB, new EventFlagPlayer(0 , 1   , 0955, "PynVisitToday"                              )}, // ぴょんたろうが今日来訪NPCとして来訪する
            {0x3BC, new EventFlagPlayer(0 , 1   , 0956, "OwlStampPlayed"                             )}, // フータ/国際ミュージアム|今年スタンプラリーに参加した？
            {0x3BF, new EventFlagPlayer(0 , 1   , 0959, "OwlStampPocketWasFull"                      )}, // フータ/国際ミュージアム|報酬受け取りでポケットいっぱいだった
            {0x3C0, new EventFlagPlayer(0 , 1   , 0960, "OwlStampGotInsectReward"                    )}, // フータ/国際ミュージアム|その日、ムシ報酬を貰った
            {0x3C1, new EventFlagPlayer(0 , 1   , 0961, "OwlStampGotFishReward"                      )}, // フータ/国際ミュージアム|その日、サカナ報酬を貰った
            {0x3C2, new EventFlagPlayer(0 , 1   , 0962, "OwlStampGotFossilReward"                    )}, // フータ/国際ミュージアム|その日、かせき報酬を貰った
            {0x3D5, new EventFlagPlayer(0 , 1   , 0981, "DocDeliveryPurchaseExplain"                 )}, // ロドリー|宅配・買取サービスの説明聞いた？
            {0x3D6, new EventFlagPlayer(0 , 1   , 0982, "TalkRumorN2TodayAnyone"                     )}, // 今日誰かにRumorN2を聞いたか？
            {0x3D7, new EventFlagPlayer(0 , 1   , 0983, "TownNewsHeardMuseum2OpenFlag"               )}, // 村内放送|博物館建物②が建った告知を聞いた？
            {0x3DC, new EventFlagPlayer(0 , 1   , 0988, "KinuyoMydesginMachineFlag"                  )}, // きぬよ|マイデザイン端末の説明聞いたことある？
            {0x3DD, new EventFlagPlayer(0 , 1   , 0989, "OwlStampGotInsect"                          )}, // フータ/国際ミュージアム|その日、フータスタンプ(ムシ)を押した
            {0x3DE, new EventFlagPlayer(0 , 1   , 0990, "OwlStampGotFish"                            )}, // フータ/国際ミュージアム|その日、フータスタンプ(サカナ)を押した
            {0x3DF, new EventFlagPlayer(0 , 1   , 0991, "OwlStampGotFossil"                          )}, // フータ/国際ミュージアム|その日、フータスタンプ(かせき)を押した
            {0x3E0, new EventFlagPlayer(0 , 1   , 0992, "CompleteEventMayDay"                        )}, // メーデーイベントが全て完了した
            {0x3E1, new EventFlagPlayer(0 , 64  , 0993, "AlwJuneBrideDayAlreadyCount"                )}, // リサ/ジューンブライド|今までに何日目までクリアしたか用カウント
            {0x3E2, new EventFlagPlayer(0 , 1   , 0994, "PAnnounceEarthDay"                          )}, // 島内放送|アースデー初回ログイン時の放送を聞いた？
            {0x3E3, new EventFlagPlayer(0 , 1   , 0995, "TipsChatFlag"                               )}, // チャット説明ダイアログを見たか？
            {0x3E4, new EventFlagPlayer(0 , 1   , 0996, "RcoEarthDayAnnouncementPre"                 )}, // アースデー|案内所たぬきちのアースデー準備中告知を聞いた？
            {0x3E5, new EventFlagPlayer(0 , 1   , 0997, "FoxPreVisitBuyArtFlag"                      )}, // つねきち|事前来訪中に美術品を買った？
            {0x3E6, new EventFlagPlayer(0 , 1   , 0998, "FoxPreVisitWantSellFlag"                    )}, // つねきち|事前来訪で美術品を売り込み中？
            {0x3E7, new EventFlagPlayer(0 , 1   , 0999, "SloTalkedToday"                             )}, // レイジ|今日会話した？
            {0x3EB, new EventFlagPlayer(0 , 2   , 1003, "CurrentJuneBrideTheme"                      )}, // 現在のジューンブライドのテーマ
            {0x3EC, new EventFlagPlayer(0 , 2   , 1004, "PreviousJuneBrideTheme"                     )}, // 前回のジューンブライドのテーマ
            {0x3ED, new EventFlagPlayer(0 , 1   , 1005, "IsSelectedJuneBrideCuteThisYear"            )}, // ジューンブライド|今年キュートが選ばれたか？
            {0x3EE, new EventFlagPlayer(0 , 1   , 1006, "IsSelectedJuneBrideChicThisYear"            )}, // ジューンブライド|今年シックが選ばれたか？
            {0x3EF, new EventFlagPlayer(0 , 1   , 1007, "IsSelectedJuneBrideGardenThisYear"          )}, // ジューンブライド|今年ガーデンが選ばれたか？
            {0x3F2, new EventFlagPlayer(0 , 9999, 1010, "LastPlayJuneBrideYear"                      )}, // ジューンブライド|最後に遊んだジューンブライドの年
            {0x3F3, new EventFlagPlayer(0 , 1   , 1011, "FoxFirstTalkInShipFlag"                     )}, // つねきち|船内で会話したことある？
            {0x3F4, new EventFlagPlayer(0 , 1   , 1012, "FoxInvitedShipFlag"                         )}, // つねきち|船へ誘導された？
            {0x3F5, new EventFlagPlayer(0 , 1   , 1013, "NoticeAboutSmartPhoneCase"                  )}, // 作業台リメイク|スマホケースの説明ダイアログ見た
            {0x3F6, new EventFlagPlayer(0 , 1   , 1014, "AlwJuneBridePleaseShootFlag"                )}, // リサ/ジューンブライド|写真も撮ってと言われた
            {0x3F7, new EventFlagPlayer(0 , 1   , 1015, "OwlPaintingQuestReminder"                   )}, // フータ|その日、美術品提出の催促を受けた
            {0x3F8, new EventFlagPlayer(0 , 1   , 1016, "OwlShowDiveFishReport"                      )}, // フータ|海の幸発見の報告を受けた
            {0x3F9, new EventFlagPlayer(0 , 1   , 1017, "DocUsePurchaseServiceFalg"                  )}, // ロドリー|買取サービス使った？
            {0x3FA, new EventFlagPlayer(0 , 1   , 1018, "UsePurchaseBOXFalg"                         )}, // 今日、買取BOX使った？（入電のメッセージ分岐用）
            {0x3FB, new EventFlagPlayer(0 , 1   , 1019, "FoxForcedTalkTodayFlag"                     )}, // つねきち|今日お店で入店時の強制会話した？
            {0x3FC, new EventFlagPlayer(0 , 1   , 1020, "FoxForcedTalk2TodayFlag"                    )}, // つねきち|今日お店で退店時の強制会話した？
            {0x3FE, new EventFlagPlayer(0 , 9999, 1022, "EDDIYFlowerWreathOrderYear"                 )}, // 花を摘んでリースをつくる活動受注年
            {0x3FF, new EventFlagPlayer(0 , 9999, 1023, "EDDIYCorollaOrderYear"                      )}, // 花を摘んで花冠をつくる活動受注年
            {0x400, new EventFlagPlayer(0 , 1   , 1024, "OwlStampGotRewardExplain"                   )}, // フータ/国際ミュージアム|スタンプラリー報酬は二重に貰えない説明を受けた
            {0x401, new EventFlagPlayer(0 , 1   , 1025, "UseNavigationMayDayTour"                    )}, // メーデー|緊急脱出サービスを使用中？
            {0x402, new EventFlagPlayer(0 , 1   , 1026, "FirstPlayAfterMuseumBuilt2Flag"             )}, // 博物館2に拡張したあとのプレイ初日？
            {0x404, new EventFlagPlayer(0 , 256 , 1028, "AlwJuneBrideTotalClearCount"                )}, // リサ/ジューンブライド|今年クリアした回数（１日何回でも）
            {0x405, new EventFlagPlayer(0 , 1   , 1029, "SloTalkedWeedFirst"                         )}, // レイジ|雑草初回会話したことある？
            {0x406, new EventFlagPlayer(0 , 1   , 1030, "SpnJuneBrideGetFenceFrag"                   )}, // パニエル/ジューンブライド|今年柵もらった？
            {0x407, new EventFlagPlayer(0 , 1   , 1031, "SpnJuneBrideNotGetFenceTodayFrag"           )}, // パニエル/ジューンブライド|今日柵もらえなかった？
            {0x408, new EventFlagPlayer(0 , 1   , 1032, "JuneBrideBGMHasUnlocked"                    )}, // ジューンブライド|今年BGMが解禁されているか？
            {0x40A, new EventFlagPlayer(0 , 1   , 1034, "XctFirstTalk"                               )}, // みしらぬネコ/メーデー|面識ある？
            {0x40B, new EventFlagPlayer(0 , 1   , 1035, "PAnnounceJuneBride"                         )}, // 島内放送|今年ジューンブライド初回ログイン時の放送を聞いた？
            {0x40C, new EventFlagPlayer(0 , 1   , 1036, "StandByPhoneCallJuneBrideSpn"               )}, // 電話デモ|今年パニエルからジューンブライド告知された？
            {0x40D, new EventFlagPlayer(0 , 1   , 1037, "AlpJuneBrideGetStickFrag"                   )}, // カイゾー/ジューンブライド|今年ステッキもらった？
            {0x40F, new EventFlagPlayer(0 , 10  , 1039, "LastApproachVillagerIndex"                  )}, // 最後にアプローチ会話をしたNPCの住人番号
            {0x410, new EventFlagPlayer(0 , 1   , 1040, "StandByPhoneCallJuneBride"                  )}, // 電話デモ|ジューンブライド告知電話するか？
            {0x412, new EventFlagPlayer(0 , 1   , 1042, "OwlExplainDiveFishAfterComp"                )}, // フータ|コンプ後に海の幸の追加説明を受けた
            {0x414, new EventFlagPlayer(0 , 1   , 1044, "AlwJuneBridePartyTalkFlag"                  )}, // リサ/ジューンブライド|パーティの案内された
            {0x415, new EventFlagPlayer(0 , 1   , 1045, "AlwJuneBrideLastDayTalkFlag"                )}, // リサ/ジューンブライド|最終日の挨拶された
            {0x416, new EventFlagPlayer(0 , 1   , 1046, "VisitFriendMileageGet"                      )}, // よその島へのおでかけマイルゲット
            {0x417, new EventFlagPlayer(0 , 1   , 1047, "AlwJuneBrideBalloonFlag"                    )}, // リサ/ジューンブライド|バルーン出す状態？
            {0x419, new EventFlagPlayer(0 , 1   , 1049, "GstRichItemFlag"                            )}, // ゆうたろう|高価な品もらった？
            {0x41A, new EventFlagPlayer(1 , 1   , 1050, "MyDesignExchangeDiscloseAuthorID"           )}, // マイデザイン交換端末|作者IDの公開
            {0x41B, new EventFlagPlayer(1 , 1   , 1051, "TapDiscloseDreamLandID"                     )}, // ゆめみ|夢番地の公開
            {0x41C, new EventFlagPlayer(0 , 1   , 1052, "PlayerPocketUIEnableInCommuneIsland"        )}, // プレイヤー|コミューン島でのポケットUI解禁
            {0x41D, new EventFlagPlayer(0 , 5   , 1053, "GotoMysteryTour"                            )}, // モーリー|ミステリーツアー島に行った回数
            {0x41E, new EventFlagPlayer(0 , 1   , 1054, "EnableGotoRareMysteryTour"                  )}, // モーリー|ミステリーツアーのレア島に行っていいか？
            {0x41F, new EventFlagPlayer(0 , 1   , 1055, "VisitMysteryTourID20"                       )}, // ID: 20のミステリーツアー島にその日行ったことがある
            {0x420, new EventFlagPlayer(0 , 1   , 1056, "PAnnounceStampRally"                        )}, // 島内放送|今年国際ミュージアム初回ログイン時の放送を聞いた？
            {0x421, new EventFlagPlayer(0 , 1   , 1057, "FoxPreVisitBuyArtMaxFlag"                   )}, // つねきち|事前来訪中に2個美術品を買った？
            {0x424, new EventFlagPlayer(0 , 9999, 1060, "EDDIYFlowerWreathClearYear"                 )}, // 花を摘んでリースをつくる活動達成年
            {0x425, new EventFlagPlayer(0 , 9999, 1061, "EDDIYCorollaClearYear"                      )}, // 花を摘んで花冠をつくる活動達成年
            {0x426, new EventFlagPlayer(0 , 1   , 1062, "GulBQuestStartFlag"                         )}, // 海賊ジョニー|クエスト開始フラグ
            {0x427, new EventFlagPlayer(0 , 1   , 1063, "GulBQuestFinishFlag"                        )}, // 海賊ジョニー|クエスト完了フラグ
            {0x428, new EventFlagPlayer(0 , 1   , 1064, "GulBTalkBeforeFlag"                         )}, // 海賊ジョニー|今までに会話したことある？
            {0x429, new EventFlagPlayer(0 , 1   , 1065, "GulBAnotherPlayerClearFlag"                 )}, // 海賊ジョニー|クエスト発生後に他のプレイヤーがクリアした？
            {0x42A, new EventFlagPlayer(0 , 16  , 1066, "GulBPartsCount"                             )}, // 海賊ジョニー|渡したパーツの個数
            {0x42B, new EventFlagPlayer(0 , 1   , 1067, "GulBSitUpBeforeFlag"                        )}, // 海賊ジョニー|今までに起こしたことある？
            {0x42C, new EventFlagPlayer(0 , 3   , 1068, "InducedNpcNum"                              )}, // お出かけ先で勧誘したNPCの数
            {0x42D, new EventFlagPlayer(0 , 1   , 1069, "TalkFreeMultiDayEventTodayFlag"             )}, // 今日、期間型イベント用のFreeFを聞いたか？
            {0x42E, new EventFlagPlayer(0 , -1  , 1070, "EarthDayBonus"                              )}, // アースデーの5倍クエストをクリアした日フラグ
            {0x42F, new EventFlagPlayer(0 , 1   , 1071, "TalkVillagerClearToday"                     )}, // 日課あいさつ活動を今日クリア済み
            {0x430, new EventFlagPlayer(0 , 1   , 1072, "EarthDayFirstQuestSystem"                   )}, // アースデーの5倍クエストをまだ出していない（システム用）
            {0x431, new EventFlagPlayer(0 , 1   , 1073, "EarthDayFirstQuestTalk"                     )}, // アースデーの5倍クエストをまだ出していない（会話用）
            {0x432, new EventFlagPlayer(0 , 1   , 1074, "SeoExchangeItemToday"                       )}, // ラコスケ|ホタテをその日渡した？
            {0x433, new EventFlagPlayer(0 , 1   , 1075, "MailSendFlag_EarthDayNotice"                )}, // 手紙|アースデー導入の手紙を送った？
            {0x434, new EventFlagPlayer(0 , 1   , 1076, "PAnnounceMayDayTour"                        )}, // 島内放送|メーデー初回ログイン時の放送を聞いた？
            {0x435, new EventFlagPlayer(0 , 1   , 1077, "DreamFirstExplain"                          )}, // ゆめみ|DLの初回説明読んだ？
            {0x436, new EventFlagPlayer(0 , 1   , 1078, "TapDreamFirstTalk"                          )}, // ゆめみ|初回会話済ませた？
            {0x437, new EventFlagPlayer(0 , 50  , 1079, "GulBHelpCount"                              )}, // 海賊ジョニー|助けた回数
            {0x438, new EventFlagPlayer(0 , 1   , 1080, "GulBGetQuestItem"                           )}, // 海賊ジョニー|クエストアイテムを入手した個数
            {0x439, new EventFlagPlayer(0 , 1   , 1081, "HasGottenMarinesuit"                        )}, // マリンスーツを入手したことがあるか？
            {0x43A, new EventFlagPlayer(0 , 1   , 1082, "SeoFirstmeetingFlag"                        )}, // ラコスケにはじめて会った
            {0x43D, new EventFlagPlayer(0 , 1   , 1085, "TalkRumorOActionTodayAnyone"                )}, // 今日RumorOP_Action（同じ島の住人P）を聞いたか？
            {0x43E, new EventFlagPlayer(0 , 1   , 1086, "SzaFireworksTalkTodayA"                     )}, // 花火大会しずえ｜今日会話した？(5:00-19:00)
            {0x43F, new EventFlagPlayer(0 , 1   , 1087, "SzaFireworksTalkTodayB"                     )}, // 花火大会しずえ｜今日会話した？(19:00-24:00)
            {0x440, new EventFlagPlayer(0 , 1   , 1088, "SzaFireworksRewardToday"                    )}, // 花火大会しずえ｜今日「光るアクセサリー」もらった？
            {0x443, new EventFlagPlayer(0 , 1   , 1091, "FireworksApproachEnd"                       )}, // 花火大会|専用アプローチ会話済
            {0x444, new EventFlagPlayer(0 , 11  , 1092, "FireworksApproachNpcIndex"                  )}, // 花火大会|専用アプローチ会話予定NPC住人番号
            {0x445, new EventFlagPlayer(0 , 1   , 1093, "FireworksApproachGetFirework"               )}, // 花火大会|花火をもらった
            {0x446, new EventFlagPlayer(0 , 1   , 1094, "TapDreamTalkToday"                          )}, // ゆめみ|今日ゆめみ室内を訪れた
            {0x447, new EventFlagPlayer(0 , 1   , 1095, "TapULFirstExplain"                          )}, // ゆめみ|ULの初回説明読んだ？
            {0x449, new EventFlagPlayer(0 , 1   , 1097, "TapDreamUploadToday"                        )}, // ゆめみ|今日夢をアップロードした
            {0x44A, new EventFlagPlayer(0 , 1   , 1098, "TapDreamDeleteToday"                        )}, // ゆめみ|今日夢を削除した
            {0x44B, new EventFlagPlayer(0 , 1   , 1099, "PknTalkBeforeFlag"                          )}, // パンプキング/ハロウィン|面識ある？
            {0x44C, new EventFlagPlayer(0 , 1   , 1100, "PknTalkTodayFlag"                           )}, // パンプキング/ハロウィン|今日会話した？
            {0x44D, new EventFlagPlayer(0 , 64  , 1101, "PknGiveCandyCount"                          )}, // パンプキング/ハロウィン|アメをあげた回数
            {0x44E, new EventFlagPlayer(0 , 1   , 1102, "PknGetCarriageFlag"                         )}, // パンプキング/ハロウィン|かぼちゃのばしゃもらった？
            {0x44F, new EventFlagPlayer(0 , 1   , 1103, "PknGetBromideFlag"                          )}, // パンプキング/ハロウィン|ブロマイドもらった？
            {0x450, new EventFlagPlayer(0 , 1   , 1104, "PknGetCarriageRecipeFlag"                   )}, // パンプキング/ハロウィン|かぼちゃのばしゃのレシピもらった？
            {0x451, new EventFlagPlayer(0 , 1   , 1105, "OwlPaintingDiveFish"                        )}, // フータのうみのさちチュートリアル聞いた？
            {0x452, new EventFlagPlayer(0 , 1   , 1106, "PAnnounceFireworksSza1"                     )}, // 島内放送|花火大会しずえ1回目の放送を聞いた？
            {0x454, new EventFlagPlayer(0 , 1   , 1108, "RcmBoughtCandyTodayFlag"                    )}, // まめきち/ハロウィン|今日アメ買った？
            {0x456, new EventFlagPlayer(0 , 1   , 1110, "WHEREAREN_Unlock_AccentWall"                )}, // OneRoom|ライセンス(アクセントウォール)解禁
            {0x457, new EventFlagPlayer(0 , 1   , 1111, "FoxFirstTalkFireworksFlag"                  )}, // つねきち|花火大会で会話したことある？
            {0x458, new EventFlagPlayer(0 , 1   , 1112, "CharacterCreationFlag"                      )}, // 夏パッチ以降でキャラメイク完了したか？
            {0x459, new EventFlagPlayer(0 , 1   , 1113, "PublicAnnouncement_DiveFish"                )}, // 泳ぎ解禁の島内放送聞いたか？手紙だす？
            {0x45A, new EventFlagPlayer(0 , 1   , 1114, "DiveFish_GetLetter"                         )}, // 初回泳ぎ島内放送聞けず、手紙を受け取った
            {0x45B, new EventFlagPlayer(0 , 1   , 1115, "DiveFishPublic_1day"                        )}, // 初回泳ぎ解禁島内放送を聞いた？
            {0x45C, new EventFlagPlayer(0 , 1   , 1116, "DiveFishPublic_2day"                        )}, // ２日目の泳ぎ解禁島内放送を聞いた？
            {0x45D, new EventFlagPlayer(0 , 1   , 1117, "RcmTalkAboutMarinesuitFlag"                 )}, // まめきち|マリンスーツの説明を聞いた
            {0x45E, new EventFlagPlayer(0 , 1   , 1118, "Encylopedia_DiveFishMes"                    )}, // 夏パッチ後、図鑑開いてうみのさち追加案内を見た
            {0x45F, new EventFlagPlayer(0 , 1   , 1119, "MyDesignExchangeExp_v1_4"                   )}, // マイデザイン交換| 夏パッチ２で追加された機能説明
            {0x460, new EventFlagPlayer(0 , 1   , 1120, "MyDesignExchangeExp_NormalUsage"            )}, // マイデザイン交換| ノーマル用途追加の説明
            {0x461, new EventFlagPlayer(0 , 1   , 1121, "PlayerHouseBuiltToday"                      )}, // 今日自宅が完成した（今日テント→家になった）
            {0x462, new EventFlagPlayer(0 , 1   , 1122, "ReceiveTapBedLetter"                        )}, // ゆめみからベッド付き手紙を受け取った
            {0x463, new EventFlagPlayer(0 , 1   , 1123, "FoxTalkOnlyStandShopFlag"                   )}, // つねきち|屋台でしか会話したことがない？
            {0x464, new EventFlagPlayer(0 , 1   , 1124, "NpcGetCandyTodayFlag"                       )}, // 一般NPC/ハロウィン|今日アメもらった？
            {0x465, new EventFlagPlayer(0 , 1   , 1125, "DiveFish_FirstDonation"                     )}, // 海の幸を初寄贈した
            {0x466, new EventFlagPlayer(0 , 1   , 1126, "TapSendThankyouLetter"                      )}, // ゆめみ|翌日、夢をアップしたお礼の手紙が届くか？
            {0x467, new EventFlagPlayer(0 , 9999, 1127, "PickUpDIYGoldCount"                         )}, // ver1.4.0以降、拾われたことがない金鉱石を拾った回数
            {0x468, new EventFlagPlayer(0 , 1   , 1128, "FireworkCannotGetNnpcItemFlag"              )}, // 花火大会|一般NPCから受け取り損ねたアイテムがある？
            {0x46B, new EventFlagPlayer(0 , 7   , 1131, "SurpriseVisitCount"                         )}, // 突撃訪問発生までのカウント
            {0x46C, new EventFlagPlayer(0 , 1   , 1132, "SurpriseVisitDone"                          )}, // 突撃訪問された事があるか
            {0x46D, new EventFlagPlayer(0 , 1   , 1133, "GetHalloweenRag"                            )}, // 一般NPC/ハロウィン|ラグもらった？
            {0x46E, new EventFlagPlayer(0 , 1   , 1134, "GetHalloweenWallPaper"                      )}, // 一般NPC/ハロウィン|かべがみもらった？
            {0x46F, new EventFlagPlayer(0 , 1   , 1135, "GetHalloweenFloor"                          )}, // 一般NPC/ハロウィン|ゆかもらった？
            {0x470, new EventFlagPlayer(0 , 1   , 1136, "GetHalloweenStickRecipe"                    )}, // パンプキング/ハロウィン|ステッキ(レシピ)もらった？
            {0x471, new EventFlagPlayer(0 , 1   , 1137, "GetHalloweenGarland"                        )}, // 一般NPC/ハロウィン|ガーランドもらった？
            {0x473, new EventFlagPlayer(0 , 1   , 1139, "GetHalloweenTableSetting"                   )}, // 一般NPC/ハロウィン|テーブルセッティングもらった？
            {0x475, new EventFlagPlayer(0 , 1   , 1141, "GetHalloweenBag"                            )}, // 今年ハロウィンのはねをもらった
            {0x476, new EventFlagPlayer(0 , 1   , 1142, "AddBodyColor"                               )}, // タヌポート|追加ボディカラー解禁
            {0x477, new EventFlagPlayer(0 , 1   , 1143, "AddEyeColor"                                )}, // タヌポート|追加アイカラー解禁
            {0x478, new EventFlagPlayer(0 , 1   , 1144, "AddCheekColor"                              )}, // タヌポート|追加チークカラー解禁
            {0x479, new EventFlagPlayer(0 , 1   , 1145, "SaveDataRestoringSettingNotice"             )}, // セーブデータ復元|設定異常検知
            {0x47A, new EventFlagPlayer(0 , 1   , 1146, "TapTalkAboutMydesignShowcase"               )}, // ゆめみ|マイデザインショーケースについて説明聞いた
            {0x47B, new EventFlagPlayer(0 , 1   , 1147, "NpcHalloweenTrickFlag"                      )}, // ハロウィン|今日イタズラされた？
            {0x47C, new EventFlagPlayer(0 , 1   , 1148, "TapFirstDreamIn"                            )}, // ゆめみ|夢の中に入ったことがある？
            {0x47D, new EventFlagPlayer(0 , 1   , 1149, "TapFirstCheckMydesingShowcase"              )}, // ゆめみ|夢の中のマイデザインショーケース端末にアクセスしたことがある？
            {0x47F, new EventFlagPlayer(0 , 1   , 1151, "SpecialMakeChanged"                         )}, // プレイヤが特殊メイクに変更した
            {0x480, new EventFlagPlayer(0 , 1   , 1152, "TalkMakeTodayAnyone"                        )}, // 今日誰かにメイク会話を聞いたか
            {0x481, new EventFlagPlayer(0 , 1   , 1153, "RcmExplainCandyFlag"                        )}, // まめきち/ハロウィン|今年アメの説明聞いた？
            {0x482, new EventFlagPlayer(0 , 1   , 1154, "RcmExplainPumpkinFlag"                      )}, // まめきち/ハロウィン|今日かぼちゃの苗の説明聞いた？
            {0x483, new EventFlagPlayer(0 , 1   , 1155, "SzaFireworksSubmitMyDesignToday"            )}, // 花火大会しずえ｜今日マイデザイン花火を提出した？
            {0x484, new EventFlagPlayer(0 , 1   , 1156, "PAnnounceHalloween"                         )}, // 島内放送|今年ハロウィン期間初回ログイン時の放送を聞いた？
            {0x486, new EventFlagPlayer(0 , 1   , 1158, "ExplainPumpkinColorFlag"                    )}, // ハロウィン|今年かぼちゃの苗の説明聞いた？
            {0x487, new EventFlagPlayer(0 , 1   , 1159, "SloExplainPumpkinSeedingFlag"               )}, // レイジ/ハロウィン|今日かぼちゃの苗の特別価格の説明きいた？
            {0x488, new EventFlagPlayer(0 , 1   , 1160, "CalcPastDays"                               )}, // 経過日数の計算をした
            {0x489, new EventFlagPlayer(0 , 1   , 1161, "PlayerProducedByPlayerMoving"               )}, // プレイヤーだけ引越し|プレイヤーだけ引越しによって作られたプレイヤーか？
            {0x48A, new EventFlagPlayer(0 , 3000, 1162, "FireworksLastApproachYear"                  )}, // 花火大会|最後にアプローチ挙動をした年
            {0x48B, new EventFlagPlayer(0 , 1   , 1163, "RcoTalkAboutMovingBelongings"               )}, // プレイヤーだけ引越し|たぬきちと所持品について話した
            {0x48C, new EventFlagPlayer(0 , 1   , 1164, "RcmRctTalkAboutMovingBelongings"            )}, // プレイヤーだけ引越し|まめきち、つぶきちと所持品について話した
            {0x48D, new EventFlagPlayer(0 , 1   , 1165, "SloExplainAddVegetable"                     )}, // レイジ/ハロウィン|今日かぼちゃの苗販売の説明聞いた？
            {0x48E, new EventFlagPlayer(0 , 1   , 1166, "PocketItemSendRecycleBoxByMoving"           )}, // プレイヤーだけ引越し|ポケットの所持品がリサイクルBOXに送られた
            {0x48F, new EventFlagPlayer(0 , 1   , 1167, "TentItemSendRecycleBoxByMoving"             )}, // プレイヤーだけ引越し|テントの配置物がリサイクルBOXに送られた
            {0x492, new EventFlagPlayer(0 , 1   , 1170, "PknTalkLastNoCandyFlag"                     )}, // パンプキング/ハロウィン|最後の会話時アメ持ってなかった？
            {0x493, new EventFlagPlayer(0 , 1   , 1171, "AddHowtoBookMydesignPro2"                   )}, // マイデザインPROエディタ２解禁条件を満たしたか？
            {0x494, new EventFlagPlayer(0 , 1   , 1172, "UnlockMydesignPro2"                         )}, // マイデザインPROエディタ２習得済みか？
            {0x495, new EventFlagPlayer(0 , 1   , 1173, "ExplainMydesignPro2"                        )}, // マイデザインPROエディタ２習得後の説明を聞いたか？
            {0x496, new EventFlagPlayer(0 , 1   , 1174, "RcoMachineExplainMydesignPro2"              )}, // タヌポートでマイデザインPROエディタ２販売開始の案内聞いたか？
            {0x499, new EventFlagPlayer(0 , 1   , 1177, "NotBuilt2PMyHomeAfterMoving"                )}, // プレイヤーだけ引越し|（2P限定）引越し後、まだ家の場所を決めてない
            {0x49A, new EventFlagPlayer(0 , 4   , 1178, "HarvestProgress"                            )}, // ハーベスト｜完成した料理の数（プレイヤー単位）
            {0x49B, new EventFlagPlayer(0 , 64  , 1179, "PknGiveLollipopCount"                       )}, // パンプキング/ハロウィン|ロリポップをあげた回数
            {0x49C, new EventFlagPlayer(0 , 1   , 1180, "TapSelWhereAreHere"                         )}, // ゆめみ|ここはどこ？を１度選んだらON
            {0x49D, new EventFlagPlayer(0 , 1   , 1181, "PknTalkLastNotGetFlag"                      )}, // パンプキング/ハロウィン|最後の会話でアイテムもらえなかった？
            {0x49E, new EventFlagPlayer(0 , 1   , 1182, "PknLastGiveCandyFlag"                       )}, // パンプキング/ハロウィン|前回渡したのはアメ？
            {0x49F, new EventFlagPlayer(0 , 1   , 1183, "PknCompItemCandyFlag"                       )}, // パンプキング/ハロウィン|アメ報酬コンプした？
            {0x4A0, new EventFlagPlayer(0 , 1   , 1184, "PknCompItemLollipopFlag"                    )}, // パンプキング/ハロウィン|ロリポップ報酬コンプした？
            {0x4A1, new EventFlagPlayer(0 , 1   , 1185, "PknPumpkingLookChatFlag"                    )}, // パンプキング/ハロウィン|パンプキング装備の雑談した？
            {0x4A2, new EventFlagPlayer(0 , 1   , 1186, "Mobile1stBoot_Camera_UnlockKeyGuideOff"     )}, // スマホアプリ初起動|カメラアプリにキーガイドOFF追加
            {0x4A3, new EventFlagPlayer(0 , 1   , 1187, "GetHalloweenRobe"                           )}, // パンプキング/ハロウィン|ローブをもらった
            {0x4A4, new EventFlagPlayer(0 , 1   , 1188, "GetHalloweenMask"                           )}, // パンプキング/ハロウィン|かぶりものをもらった
            {0x4A5, new EventFlagPlayer(0 , 1   , 1189, "PknSendLetterFlag"                          )}, // パンプキング/ハロウィン|今年手紙送った？
            {0x4A6, new EventFlagPlayer(0 , 1   , 1190, "PlayerMovingwithNoBelongings"               )}, // プレイヤーだけ引越し|所持品(手荷物)なしで引越してきた
            {0x4A7, new EventFlagPlayer(0 , 8   , 1191, "NpcGiveCandyCount"                          )}, // 一般NPC/ハロウィン|アメのお礼もらった回数
            {0x4A8, new EventFlagPlayer(0 , 1   , 1192, "GetHalloweenGarlandRecipe"                  )}, // 一般NPC/ハロウィン|ガーランドのレシピをもらった
            {0x4A9, new EventFlagPlayer(0 , 1   , 1193, "GetHalloweenTableSettingRecipe"             )}, // 一般NPC/ハロウィン|テーブルセッティングのレシピをもらった
            {0x4AA, new EventFlagPlayer(0 , 1   , 1194, "NpcTalkLastNotGetFlag"                      )}, // 一般NPC/ハロウィン|イベント中、誰かと話した？
            {0x4AB, new EventFlagPlayer(0 , 1   , 1195, "EnabledEmoticonIrregular"                   )}, // 漫符UI解禁済みかつ漫符入手会話が未発生
            {0x4AC, new EventFlagPlayer(0 , 1   , 1196, "CanGetMileTicketTrialForMoving"             )}, // プレイヤーだけ引越し|引越しで来たプレイヤーに旅行券渡してよい？
            {0x4AD, new EventFlagPlayer(0 , 1   , 1197, "PlayerMovingOrderHouseBuilt"                )}, // たぬきち|家建築、増築申し込み当日にPだけ引越しした？
            {0x4AE, new EventFlagPlayer(0 , 1   , 1198, "PlayerMovingOrderChangeHouseDesign"         )}, // たぬきち|家外観変更申し込み当日にPだけ引越しした？
            {0x4AF, new EventFlagPlayer(0 , 1   , 1199, "PlayerMovingOrderHouseMoveInIsland"         )}, // たぬきち|自宅移設申し込み当日にPだけ引越しした？
            {0x4B0, new EventFlagPlayer(0 , 1   , 1200, "PlayerMovingAfterHouseRemodel"              )}, // たぬきち|家増築後説明の発生予約中にPだけ引越しした？
            {0x4B1, new EventFlagPlayer(0 , 1   , 1201, "PlayerMovingAfterLoanFinish"                )}, // たぬきち|ローン完済会話の発生予約中にPだけ引越しした？
            {0x4B2, new EventFlagPlayer(0 , 1   , 1202, "TapUnlockFavorite"                          )}, // ゆめみ|「前に見た夢を見る」解禁
            {0x4B3, new EventFlagPlayer(0 , 9999, 1203, "LastPlayHalloweenYear"                      )}, // ハロウィン|最後に遊んだハロウィンの年
            {0x4B5, new EventFlagPlayer(0 , 1   , 1205, "PlayerMovingDefaultHouseHasBasement"        )}, // プレイヤーだけ引越し|引越し時点で家に地下室がある
            {0x4B6, new EventFlagPlayer(0 , 1   , 1206, "PlayerMovingEnable"                         )}, // プレイヤーだけ引越し|プレイヤーだけ引越しが可能か？（自宅完成済みか？）
            {0x4B7, new EventFlagPlayer(0 , 1   , 1207, "RemakeWithRcoOfficeBeforeWS"                )}, // プレイヤーだけ引越し|リメイクWS前に案内所でリメイクした
            {0x4B8, new EventFlagPlayer(0 , 1   , 1208, "RemakeWithRcoTentBeforeWS"                  )}, // プレイヤーだけ引越し|リメイクWS前にたぬきちテントでリメイクした
            {0x4B9, new EventFlagPlayer(0 , 1   , 1209, "IslandCreaterUnlockMoving"                  )}, // プレイヤーだけ引越し|引越しのタイミングで島クリエイター解禁した？
            {0x4BA, new EventFlagPlayer(0 , 1   , 1210, "AnnounceHalloween"                          )}, // ハロウィンを島内放送で告知した(2回目放送用)
            {0x4BB, new EventFlagPlayer(0 , 1   , 1211, "AnnounceHarvest"                            )}, // ハーベスト｜当日島内放送で告知した(2回目放送用)
            {0x4BE, new EventFlagPlayer(0 , 1   , 1214, "SloGetVegetableBasketDIY"                   )}, // レイジ|野菜の籠レシピもらった？
            {0x4BF, new EventFlagPlayer(0 , 1   , 1215, "MilageSendLetterFlag"                       )}, // タヌポート/ハロウィン|新規肌・目の色の追加手紙送った？
            {0x4C0, new EventFlagPlayer(0 , 1   , 1216, "NpcHalloweenGetMirrorFlag"                  )}, // ハロウィン|今日NPCからミラーもらった？
            {0x4C1, new EventFlagPlayer(0 , 1   , 1217, "NpcHalloweenCandyHelpFlag"                  )}, // ハロウィン|今日NPCから救済用アメもらった？
            {0x4C2, new EventFlagPlayer(0 , 1   , 1218, "PlayerMovingWithEmoticonUI"                 )}, // プレイヤーだけ引越し｜引越しを漫符解禁状態でやったか？
            {0x4C3, new EventFlagPlayer(0 , 1   , 1219, "AddHairStyle4"                              )}, // 『ホットなヘアアレンジ』解禁
            {0x4C7, new EventFlagPlayer(0 , 8   , 1223, "PknGetItem"                                 )}, // パンプキング/ハロウィン|報酬アイテムは？
            {0x4C9, new EventFlagPlayer(0 , 1   , 1225, "XctGetRewardThisIsland"                     )}, // メーデー|みしらぬネコから「今住んでる島で」報酬もらった？
            {0x4CA, new EventFlagPlayer(0 , 1   , 1226, "HarvestHQDish1P"                            )}, // ハーベスト｜Pが料理１クラムチャウダーの隠し食材納めた？
            {0x4CB, new EventFlagPlayer(0 , 1   , 1227, "HarvestHQDish2P"                            )}, // ハーベスト｜Pが料理２パンプキンパイの隠し食材納めた？
            {0x4CC, new EventFlagPlayer(0 , 1   , 1228, "HarvestHQDish3P"                            )}, // ハーベスト｜Pが料理３グラタンの隠し食材納めた？
            {0x4CD, new EventFlagPlayer(0 , 1   , 1229, "HarvestHQDish4P"                            )}, // ハーベスト｜Pが料理４サカナのムニエルの隠し食材納めた？
            {0x4CE, new EventFlagPlayer(0 , 1   , 1230, "TukTalkFirst"                               )}, // ハーベスト｜フランクリンとの面識あるか？
            {0x4CF, new EventFlagPlayer(0 , 4   , 1231, "HarvestTalkAboutNextDishProgress"           )}, // ハーベスト｜次の料理の話を聞いたか？
            {0x4D0, new EventFlagPlayer(0 , 1   , 1232, "TapUnlockLeaveTap"                          )}, // ゆめみ|「おまかせ」解禁
            {0x4D1, new EventFlagPlayer(0 , 8   , 1233, "HarvestKeepReward"                          )}, // ハーベスト｜渡す報酬の種類情報
            {0x4D2, new EventFlagPlayer(0 , 1   , 1234, "RewindDays"                                 )}, // 日付を巻き戻した
            {0x4D3, new EventFlagPlayer(0 , 1   , 1235, "TukTalkBeforeEvent"                         )}, // ハーベスト｜フランクリンとイベント開始前に会話した
            {0x4D4, new EventFlagPlayer(0 , 1   , 1236, "TukTalkAfterEvent"                          )}, // ハーベスト｜フランクリンとイベント終了後に会話した
            {0x4D5, new EventFlagPlayer(0 , 1   , 1237, "AnnounceBeforeHarvest"                      )}, // ハーベスト｜５日前～２日前に島内放送で告知した
            {0x4D6, new EventFlagPlayer(0 , 1   , 1238, "PasswordIsOld"                              )}, // パスワードが古いのでPOPID使用不可
            {0x4D7, new EventFlagPlayer(0 , 3   , 1239, "FishExchangeLoseCount"                      )}, // ハーベスト｜物々交換でハズレをもらった回数
            {0x4D8, new EventFlagPlayer(0 , 1   , 1240, "ReiTalkFirst"                               )}, // クリスマス｜ジングルとの面識あるか？
            {0x4D9, new EventFlagPlayer(0 , 1   , 1241, "ReiGetReward1"                              )}, // クリスマス｜ジングルからくつしたのかざり受け取った？
            {0x4DA, new EventFlagPlayer(0 , 1   , 1242, "ReiGetReward2"                              )}, // クリスマス｜ジングルからプレゼントのやまレシピ受け取った？
            {0x4DB, new EventFlagPlayer(0 , 1   , 1243, "ReiGetReward3"                              )}, // クリスマス｜ジングルからクリスマスのソリ受け取った？
            {0x4DC, new EventFlagPlayer(0 , 1   , 1244, "ReiStartQuest1"                             )}, // クリスマス｜ジングルからラッピングDIYクエスト受注した？
            {0x4DD, new EventFlagPlayer(0 , 1   , 1245, "ReiStartQuest2"                             )}, // クリスマス｜ジングルからプレゼント配布クエスト受注した？
            {0x4DF, new EventFlagPlayer(0 , 1   , 1247, "ReiFinishQuest1"                            )}, // クリスマス｜ジングルのDIYクエスト完了した？
            {0x4E0, new EventFlagPlayer(0 , 1   , 1248, "AnnouncePreChristmas"                       )}, // クリスマス｜事前期間に島内放送で告知した？
            {0x4E2, new EventFlagPlayer(0 , 1   , 1250, "WHEREAREN_NoticeAboutDustCloth"             )}, // OneRoom|まごころ雑巾の初回ダイアログを見た？
            {0x4E3, new EventFlagPlayer(0 , 10  , 1251, "SantaMissionNpcIndex1"                      )}, // クリスマス｜サンタミッションでお返しをくれるNPC1
            {0x4E4, new EventFlagPlayer(0 , 10  , 1252, "SantaMissionNpcIndex2"                      )}, // クリスマス｜サンタミッションでお返しをくれるNPC2
            {0x4E5, new EventFlagPlayer(0 , 10  , 1253, "SantaMissionNpcIndex3"                      )}, // クリスマス｜サンタミッションでお返しをくれるNPC3
            {0x4E6, new EventFlagPlayer(0 , 1   , 1254, "ReceiveLeaveTapLetter"                      )}, // ゆめみ|おまかせ解禁の手紙を受け取った
            {0x4E7, new EventFlagPlayer(0 , 1   , 1255, "RcmExplainToy"                              )}, // クリスマス｜おもちゃ家具陳列の案内を受けた？
            {0x4E8, new EventFlagPlayer(0 , 1   , 1256, "PckTalkTodayFlag"                           )}, // カーニバル/べルリーナ|今日すでに会話した？
            {0x4E9, new EventFlagPlayer(0 , 9999, 1257, "ChristmasWreathGetYear"                     )}, // クリスマス｜クリスマスリースをNPCから貰った年
            {0x4EA, new EventFlagPlayer(0 , 9   , 1258, "TukSecretRewardType"                        )}, // ハーベスト｜フランクリンの隠し食材報酬抽選結果
            {0x4EC, new EventFlagPlayer(0 , 1   , 1260, "WHEREAREN_Unlock_ResortPlannerApp"          )}, // OneRoom|リゾートプランナーアプリアンロック
            {0x4ED, new EventFlagPlayer(0 , 1   , 1261, "WHEREAREN_Unlock_ResortStudyApp"            )}, // OneRoom|リゾートスタディアプリアンロック
            {0x4EE, new EventFlagPlayer(0 , 1   , 1262, "TapUpdatedDreamFirstTalk"                   )}, // ゆめみ|初回会話を1.6.0以降に行った？
            {0x4EF, new EventFlagPlayer(0 , 1   , 1263, "SzaChristmasOrnament"                       )}, // クリスマス｜しずえからオーナメント素材もらった？
            {0x4F1, new EventFlagPlayer(0 , 1   , 1265, "CheckHarvestFtrInStore"                     )}, // ハーベスト｜ハーベスト家具をお店でチェックしたことがあるか？
            {0x4F2, new EventFlagPlayer(0 , 9999, 1266, "ChristmasPresentYear"                       )}, // クリスマス|自宅プレゼントをもらった年
            {0x4F3, new EventFlagPlayer(0 , 2   , 1267, "InputApproachBanCount"                      )}, // アプローチ｜入力系アプローチ禁止カウント
            {0x4F4, new EventFlagPlayer(0 , 1   , 1268, "PckLookChatFlag"                            )}, // カーニバル/べルリーナ|カーニバル装備の雑談した？
            {0x4F5, new EventFlagPlayer(0 , 1   , 1269, "TukCancel1stRequest"                        )}, // ハーベスト｜フランクリン１品目で「大変ですね」を選択した
            {0x4F6, new EventFlagPlayer(0 , 1   , 1270, "ChristmasWrappingGiftFlag"                  )}, // クリスマス｜プレゼント交換初回でラッピングもらった？
            {0x4F8, new EventFlagPlayer(0 , 1   , 1272, "HarvestRefuseGiveHQFood1"                   )}, // ハーベスト｜料理１の隠し食材を渡すのを拒んだ
            {0x4F9, new EventFlagPlayer(0 , 1   , 1273, "HarvestRefuseGiveHQFood2"                   )}, // ハーベスト｜料理２の隠し食材を渡すのを拒んだ
            {0x4FA, new EventFlagPlayer(0 , 1   , 1274, "HarvestRefuseGiveHQFood3"                   )}, // ハーベスト｜料理３の隠し食材を渡すのを拒んだ
            {0x4FB, new EventFlagPlayer(0 , 1   , 1275, "HarvestRefuseGiveHQFood4"                   )}, // ハーベスト｜料理４の隠し食材を渡すのを拒んだ
            {0x4FC, new EventFlagPlayer(0 , 2   , 1276, "HarvestGetHint1"                            )}, // ハーベスト｜料理１の隠し食材ヒント聞いた
            {0x4FD, new EventFlagPlayer(0 , 2   , 1277, "HarvestGetHint2"                            )}, // ハーベスト｜料理２の隠し食材ヒント聞いた
            {0x4FE, new EventFlagPlayer(0 , 2   , 1278, "HarvestGetHint3"                            )}, // ハーベスト｜料理３の隠し食材ヒント聞いた
            {0x4FF, new EventFlagPlayer(0 , 2   , 1279, "HarvestGetHint4"                            )}, // ハーベスト｜料理４の隠し食材ヒント聞いた
            {0x500, new EventFlagPlayer(0 , 1   , 1280, "ChristmasWrappingPresentFlag"               )}, // クリスマス｜ラッピングを誰かくれようとしたか？
            {0x501, new EventFlagPlayer(0 , 1   , 1281, "PckRecipeFlag"                              )}, // カーニバル/べルリーナ|にじいろのはねのレシピもらった？
            {0x502, new EventFlagPlayer(0 , 1   , 1282, "RcoStorageExpansionReserved"                )}, // たぬきち|収納の拡張を予約している
            {0x503, new EventFlagPlayer(0 , 1   , 1283, "RcoStorageExpansionLevel"                   )}, // たぬきち|収納の拡張段階（'20冬パッチ 1段階のみ）
            {0x504, new EventFlagPlayer(0 , 1   , 1284, "PlayerMovingReservedStorageExpand"          )}, // たぬきち|収納の拡張申し込み当日にPだけ引越しした？
            {0x505, new EventFlagPlayer(0 , 1   , 1285, "MailSend_NoticeStorageExpansion"            )}, // たぬきち|収納の拡張のお知らせ手紙の判定処理したか？
            {0x506, new EventFlagPlayer(0 , 1   , 1286, "RcoStandbyNoticeStorageExpansion"           )}, // たぬきち|収納の拡張について強制会話するか？
            {0x507, new EventFlagPlayer(0 , 1   , 1287, "ChristmasWreathNoGetFlag"                   )}, // クリスマス|このNPCからリース受け取り損ねた
            {0x508, new EventFlagPlayer(0 , 3   , 1288, "PckGetItem"                                 )}, // カーニバル/べルリーナ|報酬アイテムは？
            {0x509, new EventFlagPlayer(0 , 1   , 1289, "WHEREAREN_Unlock_CoordinateNpcHouse"        )}, // OneRoom|ライセンス(NPC家コーディネート)解禁
            {0x50A, new EventFlagPlayer(0 , 1   , 1290, "GetCarnivalLight"                           )}, // カーニバル/べルリーナ|カーニバルなライトもらった？
            {0x50B, new EventFlagPlayer(0 , 1   , 1291, "GetCarnivalFoodStand"                       )}, // カーニバル/べルリーナ|カーニバルな屋台もらった？
            {0x50C, new EventFlagPlayer(0 , 1   , 1292, "GetCarnivalstage"                           )}, // カーニバル/べルリーナ|カーニバルなステージもらった？
            {0x50D, new EventFlagPlayer(0 , 1   , 1293, "GetCarnivalConfettiMachine"                 )}, // カーニバル/べルリーナ|カーニバルなかみふぶきマシンもらった？
            {0x50E, new EventFlagPlayer(0 , 1   , 1294, "GetCarnivalPercussion"                      )}, // カーニバル/べルリーナ|カーニバルなパーカッションもらった？
            {0x50F, new EventFlagPlayer(0 , 1   , 1295, "GetCarnivalBalloonLight"                    )}, // カーニバル/べルリーナ|カーニバルバルーンライトもらった？
            {0x510, new EventFlagPlayer(0 , 1   , 1296, "GetCarnivalUmbrellas"                       )}, // カーニバル/べルリーナ|カーニバルなパラソルもらった？
            {0x511, new EventFlagPlayer(0 , 1   , 1297, "GetCarnivalFlag"                            )}, // カーニバル/べルリーナ|カーニバルなフラッグもらった？
            {0x512, new EventFlagPlayer(0 , 1   , 1298, "GetCarnivalGarland"                         )}, // カーニバル/べルリーナ|カーニバルなガーランドもらった？
            {0x513, new EventFlagPlayer(0 , 1   , 1299, "GetCarnivalFloat"                           )}, // カーニバル/べルリーナ|カーニバルなフロートもらった？
            {0x515, new EventFlagPlayer(0 , 10  , 1301, "PckGiveFurnitureCount"                      )}, // カーニバル/べルリーナ|家具をもらった回数
            {0x516, new EventFlagPlayer(0 , 1   , 1302, "WHEREAREN_Unlock_ResortPlannerAppNetwork"   )}, // OneRoom|リゾートプランナーアプリのツクッターアンロック
            {0x517, new EventFlagPlayer(0 , 1   , 1303, "WHEREAREN_Unlock_ResortPlannerAppRevisit"   )}, // OneRoom|リゾートプランナーアプリの再訪アンロック
            {0x518, new EventFlagPlayer(0 , 1   , 1304, "SloExplainPumpkinColorFlag"                 )}, // レイジ|かぼちゃの苗説明聞いたことある？
            {0x519, new EventFlagPlayer(0 , 1   , 1305, "SloExplainAddPumpkinFlag"                   )}, // レイジ|かぼちゃの苗販売開始の説明聞いた？
            {0x51B, new EventFlagPlayer(0 , 1   , 1307, "TukSecretRewardType3rd"                     )}, // ハーベスト｜フランクリンの隠し食材報酬抽選結果（３回目）
            {0x51C, new EventFlagPlayer(0 , 1   , 1308, "PckTalkBeforeFlag"                          )}, // カーニバル/べルリーナ|面識ある？
            {0x51D, new EventFlagPlayer(0 , 1   , 1309, "SendNNPCConversationPlayReport"             )}, // 会話のフリのプレイレポートがその日送信されたか
            {0x51E, new EventFlagPlayer(0 , 1   , 1310, "MainmenuMydesignShowcase"                   )}, // スマホUI|マイデザインショーケース解禁
            {0x51F, new EventFlagPlayer(0 , 8   , 1311, "ChristmasPrevPresentItemType"               )}, // クリスマス｜直前にNPCにもらったアイテムの種類
            {0x520, new EventFlagPlayer(0 , 1   , 1312, "ValentineLetterFlag"                        )}, // バレンタイン|手紙送った？
            {0x522, new EventFlagPlayer(0 , 1   , 1314, "AnnounceChristmasEve"                       )}, // クリスマス｜当日に島内放送で告知した？(2回目放送用)
            {0x526, new EventFlagPlayer(0 , 511 , 1318, "GetCarnivalFurniture"                       )}, // カーニバル/ベルリーナ|どのカーニバル家具をもらったか？
            {0x52C, new EventFlagPlayer(0 , 9999, 1324, "LastPlayValentineYear"                      )}, // バレンタイン|最後に遊んだバレンタインの年
            {0x52D, new EventFlagPlayer(0 , 1   , 1325, "PckRecipeTalkFlag"                          )}, // カーニバル/べルリーナ|にじいろのはねのレシピもらう会話した？
            {0x52E, new EventFlagPlayer(0 , 1   , 1326, "Mobile1stBoot_MydesignShowcase"             )}, // スマホアプリ初起動|マイデザインアプリにショーケース追加
            {0x52F, new EventFlagPlayer(0 , 1   , 1327, "MydesignExchangeTalkAboutMobile"            )}, // マイデザイン交換| マイデザインショーケースアプリについて説明
            {0x530, new EventFlagPlayer(0 , 1   , 1328, "BuyReactionBook17"                          )}, // カーニバル用リアクション本を購入した
            {0x531, new EventFlagPlayer(0 , 511 , 1329, "GetCarnivalFurnitureRed"                    )}, // カーニバル/ベルリーナ|どの赤色カーニバル家具をもらったか？
            {0x532, new EventFlagPlayer(0 , 511 , 1330, "GetCarnivalFurnitureBlue"                   )}, // カーニバル/ベルリーナ|どの青色カーニバル家具をもらったか？
            {0x533, new EventFlagPlayer(0 , 511 , 1331, "GetCarnivalFurnitureGreen"                  )}, // カーニバル/ベルリーナ|どの緑色カーニバル家具をもらったか？
            {0x534, new EventFlagPlayer(0 , 511 , 1332, "GetCarnivalFurniturePurple"                 )}, // カーニバル/ベルリーナ|どの紫色カーニバル家具をもらったか？
            {0x535, new EventFlagPlayer(0 , 511 , 1333, "GetCarnivalFurnitureRainbow"                )}, // カーニバル/ベルリーナ|どの虹色カーニバル家具をもらったか？
            {0x536, new EventFlagPlayer(0 , 1   , 1334, "PckColorLotteryFlag"                        )}, // カーニバル/ベルリーナ|色ごとにカーニバル家具の抽選をするか？
            {0x537, new EventFlagPlayer(0 , 1   , 1335, "RcmChkReactionBook"                         )}, // カーニバル用リアクション本をチェックした
            {0x538, new EventFlagPlayer(0 , 1   , 1336, "RcmChkCarnivalFtr"                          )}, // まめきち|カーニバル家具チェックした？
            {0x539, new EventFlagPlayer(0 , 1   , 1337, "AnnounceCarnival"                           )}, // カーニバル｜当日に島内放送で告知した？(2回目放送用)
            {0x53A, new EventFlagPlayer(0 , 1   , 1338, "ShootDownShamrockRecipeBalloon"             )}, // シャムロックデー|今日、シャムロックステッキのレシピ風船を撃ち落としたか
            {0x53B, new EventFlagPlayer(0 , 1   , 1339, "MailSendFlag_ReceiveAnniversaryItem"        )}, // 手紙|1周年手紙を送った
            {0x53C, new EventFlagPlayer(0 , 1   , 1340, "AOC_EventFlag_002"                          )}, // AOC同期フラグ| 002 1.9.0NSO加入特典
            {0x53D, new EventFlagPlayer(0 , 1   , 1341, "UnlockSanrioCollaboPoster"                  )}, // サンリオNPCポスター解禁_キティ
            {0x53E, new EventFlagPlayer(0 , 1   , 1342, "UnlockSanrioCollaboPoster2"                 )}, // サンリオNPCポスター解禁_プリン
            {0x53F, new EventFlagPlayer(0 , 1   , 1343, "UnlockSanrioCollaboPoster3"                 )}, // サンリオNPCポスター解禁_キキララ
            {0x540, new EventFlagPlayer(0 , 1   , 1344, "UnlockSanrioCollaboPoster4"                 )}, // サンリオNPCポスター解禁_シナモン
            {0x541, new EventFlagPlayer(0 , 1   , 1345, "UnlockSanrioCollaboPoster5"                 )}, // サンリオNPCポスター解禁_マイメロ
            {0x542, new EventFlagPlayer(0 , 1   , 1346, "UnlockSanrioCollaboPoster6"                 )}, // サンリオNPCポスター解禁_けろっぴ
            {0x543, new EventFlagPlayer(0 , 1   , 1347, "AnnounceEaster"                             )}, // イースター(2021年)｜当日に島内放送で告知した？(2回目放送用)
            {0x544, new EventFlagPlayer(0 , 1   , 1348, "PhoneCallByRcoWherearen"                    )}, // 電話デモ|たぬきちからウェアラン入電受けたことがある？
            {0x545, new EventFlagPlayer(0 , 1   , 1349, "RcoTalkWithOtg"                             )}, // たぬきち|タクミとの会話を聞いたことがある？
            {0x547, new EventFlagPlayer(0 , 1   , 1351, "SloTalkCommuneBeforeFlag"                   )}, // レイジ｜コミューンで会話したことある？
            {0x548, new EventFlagPlayer(0 , 1   , 1352, "SloExplainVegetableSeedling"                )}, // レイジ｜野菜の苗の説明聞いたことある？
            {0x549, new EventFlagPlayer(0 , 1   , 1353, "SloExplainPlumeriaSeedling"                 )}, // レイジ｜プルメリアの苗の説明聞いたことある？
            {0x54A, new EventFlagPlayer(0 , 1   , 1354, "SloExplainWeeding"                          )}, // レイジ｜草むしりサービスの説明聞いたことある？
            {0x54B, new EventFlagPlayer(0 , 1   , 1355, "AnnounceEasterReady"                        )}, // イースター(2021年)｜準備期間に島内放送で告知した？(2回目放送用)
            {0x54C, new EventFlagPlayer(0 , 1   , 1356, "AnnounceJuneBride"                          )}, // ジューンブライド(2021年)｜当日に島内放送で告知した？(2回目放送用)
            {0x54D, new EventFlagPlayer(0 , 1   , 1357, "StandByPhoneCallOtgVisit"                   )}, // OneRoom｜電話デモ|タクミ訪問の入電するか？
            {0x54E, new EventFlagPlayer(0 , 1   , 1358, "PynEvent_SendMailThisYear"                  )}, // イースター|今年手紙を受け取った？
            {0x553, new EventFlagPlayer(0 , 1   , 1363, "UnlockWherearen"                            )}, // OneRoom|ウェアラン渡航解禁
            {0x555, new EventFlagPlayer(0 , 1   , 1365, "OwlArtStampRally1"                          )}, // フータ/国際ミュージアム|【美術品】スタンプ1つ目を押した？
            {0x556, new EventFlagPlayer(0 , 1   , 1366, "OwlArtStampRally2"                          )}, // フータ/国際ミュージアム|【美術品】スタンプ2つ目を押した？
            {0x557, new EventFlagPlayer(0 , 1   , 1367, "OwlArtStampRally3"                          )}, // フータ/国際ミュージアム|【美術品】スタンプ3つ目を押した？
            {0x558, new EventFlagPlayer(0 , 1   , 1368, "OwlStampGotArtReward"                       )}, // フータ/国際ミュージアム|その日、美術品報酬を貰った
            {0x559, new EventFlagPlayer(0 , 1   , 1369, "OwlStampGotArt"                             )}, // フータ/国際ミュージアム|その日、フータスタンプ(美術品)を押した
            {0x55A, new EventFlagPlayer(0 , 1   , 1370, "OwlArtUnfinished"                           )}, // フータ/国際ミュージアム|初参加時、美術品部屋未完成
            {0x55C, new EventFlagPlayer(0 , 1   , 1372, "WHEREAREN_DisclosePlannerID"                )}, // OneRoom|プランナーIDの公開
            {0x55D, new EventFlagPlayer(0 , 1   , 1373, "UnlockSanrioCollabo"                        )}, // サンリオコラボ解禁_キティ
            {0x55E, new EventFlagPlayer(0 , 1   , 1374, "UnlockSanrioCollabo2"                       )}, // サンリオコラボ解禁_プリン
            {0x55F, new EventFlagPlayer(0 , 1   , 1375, "UnlockSanrioCollabo3"                       )}, // サンリオコラボ解禁_キキララ
            {0x560, new EventFlagPlayer(0 , 1   , 1376, "UnlockSanrioCollabo4"                       )}, // サンリオコラボ解禁_シナモン
            {0x561, new EventFlagPlayer(0 , 1   , 1377, "UnlockSanrioCollabo5"                       )}, // サンリオコラボ解禁_マイメロ
            {0x562, new EventFlagPlayer(0 , 1   , 1378, "UnlockSanrioCollabo6"                       )}, // サンリオコラボ解禁_けろっぴ
            {0x565, new EventFlagPlayer(0 , 4   , 1381, "OwlClearCount"                              )}, // フータ/国際ミュージアム|クリアした部屋の個数
            {0x566, new EventFlagPlayer(0 , 1   , 1382, "WHEREAREN_Pickup_Disclose"                  )}, // OneRoom|現在、宣伝内容をピックアップに公開中か？
            {0x567, new EventFlagPlayer(0 , 1   , 1383, "XctGetRewardSec"                            )}, // メーデー|みしらぬネコから2回目の報酬をもらった？
            {0x568, new EventFlagPlayer(0 , 1   , 1384, "OwlStampPlayedThisYear"                     )}, // フータ/国際ミュージアム|今年サカナのスタンプラリーをクリアした？
            {0x569, new EventFlagPlayer(0 , 1   , 1385, "OwlStampPlayedThisYear2"                    )}, // フータ/国際ミュージアム|今年ムシのスタンプラリーをクリアした？
            {0x56A, new EventFlagPlayer(0 , 1   , 1386, "OwlStampPlayedThisYear3"                    )}, // フータ/国際ミュージアム|今年かせきのスタンプラリーをクリアした？
            {0x56B, new EventFlagPlayer(0 , 1   , 1387, "OwlStampPlayedThisYear4"                    )}, // フータ/国際ミュージアム|今年美術品のスタンプラリーをクリアした？
            {0x56C, new EventFlagPlayer(0 , 1   , 1388, "MuseumCafeEv_1_HeardExplanation"            )}, // 博物館カフェ増築イベント|フータから依頼受けた？
            {0x56D, new EventFlagPlayer(0 , 1   , 1389, "MuseumCafeEv_2_TalkedWithMasterAtIsland"    )}, // 博物館カフェ増築イベント|離島でマスターと会話したことがある？
            {0x56E, new EventFlagPlayer(0 , 1   , 1390, "MuseumCafeEv_3_ConfirmedVisitingTown"       )}, // 博物館カフェ増築イベント|離島マスターに来訪の約束した？
            {0x56F, new EventFlagPlayer(0 , 1   , 1391, "MuseumCafeEv_4_ReportedToOwl"               )}, // 博物館カフェ増築イベント|フータにマスターのことを報告した？
            {0x570, new EventFlagPlayer(0 , 1   , 1392, "Owl_HeardAboutCafeConstruction"             )}, // フータ|カフェの工事のことを聞いた？
            {0x571, new EventFlagPlayer(0 , 1   , 1393, "Owl_HeardAboutCafeOpen"                     )}, // フータ|カフェオープンのことを聞いた？
            {0x572, new EventFlagPlayer(0 , 1   , 1394, "PgeThankToMainPC"                           )}, // マスター|カフェ開店後に島民代表が初会話した？
            {0x573, new EventFlagPlayer(0 , 8   , 1395, "TodayFortune"                               )}, // ハッケミィ|今日の運勢
            {0x574, new EventFlagPlayer(0 , 8   , 1396, "ReserveFortune"                             )}, // ハッケミィ|発動前の運勢
            {0x575, new EventFlagPlayer(0 , 1   , 1397, "RadioGymnasticsFirstExplain"                )}, // ラジオ体操|初回説明読んだ？
            {0x576, new EventFlagPlayer(0 , 1   , 1398, "Bpt_1stTalk"                                )}, // ハッケミィ｜占ったことがある？
            {0x577, new EventFlagPlayer(0 , 1   , 1399, "Bpt_FinishFortune_Today"                    )}, // ハッケミィ｜今日「今日の運勢」占い済？
            {0x578, new EventFlagPlayer(0 , 1   , 1400, "Bpt_FinishCompatibilityToday"               )}, // ハッケミィ｜今日「相性占い」占い済？
            {0x57A, new EventFlagPlayer(0 , 8   , 1402, "LastFortune"                                )}, // ハッケミィ|前回の運勢
            {0x57B, new EventFlagPlayer(0 , 1   , 1403, "SkkCommuneTalkBefore"                       )}, // シャンク｜コミューンで以前話したことある？
            {0x57C, new EventFlagPlayer(0 , 1   , 1404, "AlpJuneBrideNotGetLoveCrystalFrag"          )}, // カイゾー/ジューンブライド|今日あいのけっしょうもらえなかった？
            {0x57D, new EventFlagPlayer(0 , 1   , 1405, "AlwJuneBrideExchangeTalkFlag"               )}, // リサ/ジューンブライド|今年交換回数制限の説明聞いた？
            {0x57E, new EventFlagPlayer(0 , 9999, 1406, "LastPlayMuseumYear"                         )}, // 国際ミュージアム|最後に遊んだ国際ミュージアムの年
            {0x57F, new EventFlagPlayer(0 , -1  , 1407, "RadioGymnasticsCount"                       )}, // ラジオ体操|累計参加回数
            {0x580, new EventFlagPlayer(0 , 5   , 1408, "RadioGymnasticsGetReward"                   )}, // ラジオ体操|報酬何回もらった？
            {0x581, new EventFlagPlayer(0 , 1   , 1409, "ExplainIslandRegulation"                    )}, // 条例|しずえから条例の説明受けた
            {0x582, new EventFlagPlayer(0 , 1   , 1410, "MainmenuRecipe_v2"                          )}, // スマホUI|レシピ＋解禁（v2.0.0料理レシピ）
            {0x583, new EventFlagPlayer(0 , 1   , 1411, "Mobile1stBoot_DIYrecipe_v2"                 )}, // スマホアプリ初起動|DIYレシピ＋（v2.0.0料理レシピ）
            {0x584, new EventFlagPlayer(0 , 1   , 1412, "TapUnlockSearchByIslandName"                )}, // ゆめみ|「島の名前で探す」解禁説明読んだ？
            {0x585, new EventFlagPlayer(0 , 1   , 1413, "MuseumCafe_Telephone_Access1stTime"         )}, // 喫茶ハトの巣｜店内電話初回説明見たか？
            {0x586, new EventFlagPlayer(0 , 1   , 1414, "AlpCommuneTalkBeforeFlag"                   )}, // カイゾー｜コミューンで会話したことある？
            {0x589, new EventFlagPlayer(0 , 1   , 1417, "FirstPlayAfterMuseumBuilt3Flag"             )}, // 博物館3に拡張したあとのプレイ初日？
            {0x58A, new EventFlagPlayer(0 , 1   , 1418, "ReserveCommuneExpansion"                    )}, // コミューン｜拡張イベント予約
            {0x58C, new EventFlagPlayer(0 , 1   , 1420, "DoneCommuneSloOpenEvent"                    )}, // コミューン島レイジ開店イベント発生制御
            {0x58D, new EventFlagPlayer(0 , 1   , 1421, "DoneCommuneCmlOpenEvent"                    )}, // コミューン島ローラン開店イベント発生制御
            {0x58E, new EventFlagPlayer(0 , 1   , 1422, "DoneCommuneFoxOpenEvent"                    )}, // コミューン島つねきち開店イベント発生制御
            {0x58F, new EventFlagPlayer(0 , 1   , 1423, "DoneCommuneBptOpenEvent"                    )}, // コミューン島ハッケミィ開店イベント発生制御
            {0x590, new EventFlagPlayer(0 , 1   , 1424, "DoneCommuneSkkOpenEvent"                    )}, // コミューン島シャンク開店イベント発生制御
            {0x591, new EventFlagPlayer(0 , 1   , 1425, "DoneCommuneAlpOpenEvent"                    )}, // コミューン島リサカイゾー開店イベント発生制御
            {0x592, new EventFlagPlayer(0 , 1   , 1426, "PooTalkAboutHairArrange"                    )}, // カットリーヌ｜初回ヘアアレンジの話を聞いた
            {0x593, new EventFlagPlayer(0 , 1   , 1427, "PooRefuseHairArrange"                       )}, // カットリーヌ｜ヘアアレンジを断った
            {0x594, new EventFlagPlayer(0 , 1   , 1428, "PooTodayGetHairStyle"                       )}, // カットリーヌ｜今日、ヘアアレンジをしてもらった
            {0x595, new EventFlagPlayer(0 , 1   , 1429, "PooUndoHairStyelAfterArrange"               )}, // カットリーヌ｜ヘアアレンジ後、元に戻してもらった
            {0x596, new EventFlagPlayer(0 , 1   , 1430, "PooGetNewHairStyle1"                        )}, // カットリーヌ｜ヘアアレンジ解禁１（レイジ）
            {0x597, new EventFlagPlayer(0 , 1   , 1431, "PooGetNewHairStyle2"                        )}, // カットリーヌ｜ヘアアレンジ解禁２（ローラン）
            {0x598, new EventFlagPlayer(0 , 1   , 1432, "PooGetNewHairStyle3"                        )}, // カットリーヌ｜ヘアアレンジ解禁３（つねきち）
            {0x599, new EventFlagPlayer(0 , 1   , 1433, "PooGetNewHairStyle4"                        )}, // カットリーヌ｜ヘアアレンジ解禁４（ハッケミィ）
            {0x59A, new EventFlagPlayer(0 , 1   , 1434, "PooGetNewHairStyle5"                        )}, // カットリーヌ｜ヘアアレンジ解禁５（シャンク）
            {0x59B, new EventFlagPlayer(0 , 1   , 1435, "PooGetNewHairStyle6"                        )}, // カットリーヌ｜ヘアアレンジ解禁６（リサカイゾー）
            {0x59C, new EventFlagPlayer(0 , 1   , 1436, "SpnTodayExplainedPhotoStudio"               )}, // パニエル｜撮影スタジオに今日初めて入った
            {0x59D, new EventFlagPlayer(0 , 1   , 1437, "RcoCordinateNpcHouseSelEnable"              )}, // たぬきち｜NPC家コーデの選択肢が解禁
            {0x59E, new EventFlagPlayer(0 , 8   , 1438, "PgeItemGetCount"                            )}, // マスター|もらったアイテムの数
            {0x59F, new EventFlagPlayer(0 , 1   , 1439, "PgeTalkFirstFlag"                           )}, // マスター|面識ある？
            {0x5A0, new EventFlagPlayer(0 , 1   , 1440, "AlwCommuneTalkBeforeFlag"                   )}, // リサ｜コミューンで会話したことある？
            {0x5A2, new EventFlagPlayer(0 , 1   , 1442, "CmlCommuneTalkBefore"                       )}, // ローラン｜コミューンで会話したことある？
            {0x5A4, new EventFlagPlayer(0 , 1   , 1444, "CmlCommuneBuyToday"                         )}, // ローラン｜今日買い物した？
            {0x5A5, new EventFlagPlayer(0 , 1   , 1445, "UnlockBuyRecipePlus"                        )}, // タヌポート｜レシピ+の陳列開始
            {0x5A7, new EventFlagPlayer(0 , 1   , 1447, "Mobile1stBoot_MydesignPatternPlus"          )}, // 汎用布地ページ追加後スマホアプリ初起動｜マイデザイン
            {0x5A8, new EventFlagPlayer(0 , 1   , 1448, "MainmenuMydesignPatternPlus"                )}, // マイデザイン｜汎用布地ページ追加
            {0x5A9, new EventFlagPlayer(0 , 1   , 1449, "Mobile1stBoot_Camera1stPersonView"          )}, // 主観カメラ追加後スマホアプリ初起動｜カメラ
            {0x5AA, new EventFlagPlayer(0 , 1   , 1450, "MainmenuCamera1stPersonView"                )}, // カメラ｜主観カメラ解禁
            {0x5AC, new EventFlagPlayer(0 , 1   , 1452, "UnlockInterior_CeilingFurniture"            )}, // インテリアモード｜天井家具解禁
            {0x5AD, new EventFlagPlayer(0 , 1   , 1453, "FenceRemakeEnable"                          )}, // リメイク｜柵リメイク解禁
            {0x5B0, new EventFlagPlayer(0 , 1   , 1456, "GetMayDayTicketFirst"                       )}, // メーデー|1.10.0未満でメーデーりょこうけんを入手したことがあるか？
            {0x5B1, new EventFlagPlayer(0 , 1   , 1457, "TotakekeLive2_0Flag"                        )}, // とたけけ|2.0アプデ後に初めてライブ聴いた？
            {0x5B2, new EventFlagPlayer(0 , 3   , 1458, "RcoStorageExpansion_v200_AddLevel"          )}, // たぬきち|収納の拡張（v2.0.0）追加段階0～3
            {0x5B3, new EventFlagPlayer(0 , 1   , 1459, "MailSend_Notice_v200_AddStorage"            )}, // たぬきち|収納の拡張（v2.0.0）段階追加お知らせの手紙判定したか？
            {0x5B4, new EventFlagPlayer(0 , 1   , 1460, "RcoStandbyNotice_v200_AddStorage"           )}, // たぬきち|収納の拡張（v2.0.0）段階追加のお知らせ強制会話するか？
            {0x5B5, new EventFlagPlayer(0 , 1   , 1461, "RcoStandbyNotice_v200_AfterStorageExpansion")}, // たぬきち|収納の拡張（v2.0.0）収納拡張後の強制会話予約フラグ
            {0x5B6, new EventFlagPlayer(0 , 1   , 1462, "PlayerMovingAfterStorageExpansion"          )}, // たぬきち|収納拡張後の説明の発生予約中にPだけ引っ越しした？
            {0x5B7, new EventFlagPlayer(0 , 1   , 1463, "UnlockBuyFenceRemake"                       )}, // タヌポート｜柵リメイク解禁の陳列開始
            {0x5B8, new EventFlagPlayer(0 , 1   , 1464, "RcoHeardAboutMayDayTravelTicket"            )}, // メーデー|たぬきち|メーデー旅行券の説明聞いたか？
            {0x5B9, new EventFlagPlayer(0 , 1   , 1465, "XctGetRewardPast"                           )}, // メーデー|1.10.0未満でみしらぬネコから報酬をもらった？
            {0x5BB, new EventFlagPlayer(0 , 1   , 1467, "SloExplainBuyVegetableSeedling"             )}, // レイジ｜野菜購入時に説明聞いたことある？
            {0x5BC, new EventFlagPlayer(0 , 1   , 1468, "SloWeedingBeforeCommune"                    )}, // レイジ｜コミューン誘致前に草むしりサービス解禁した？
            {0x5BD, new EventFlagPlayer(0 , 1   , 1469, "FoxTalk2020FireworksFlag"                   )}, // つねきち|2020年の花火大会で会話したことない？
            {0x5BE, new EventFlagPlayer(0 , 1   , 1470, "FoxTalkIceCandyTodayFlag"                   )}, // つねきち|アイスキャンディの説明した？
            {0x5BF, new EventFlagPlayer(0 , 1   , 1471, "FoxTalkTapiocaTodayFlag"                    )}, // つねきち|タピオカドリンクの説明した？
            {0x5C0, new EventFlagPlayer(0 , 1   , 1472, "KppTourExplain1st"                          )}, // かっぺい|かっぺいツアー初上陸で説明聞いた？
            {0x5C1, new EventFlagPlayer(0 , 1   , 1473, "KppTakeTourTodayFlag"                       )}, // かっぺい|今日かっぺいツアー参加した？
            {0x5C2, new EventFlagPlayer(0 , 1   , 1474, "KppFirstTalk"                               )}, // かっぺい|面識ある？
            {0x5C3, new EventFlagPlayer(0 , 1   , 1475, "SpnTodayDonation"                           )}, // パニエル｜今日募金したか？
            {0x5C4, new EventFlagPlayer(0 , 1   , 1476, "SpnTodayThanksDonation"                     )}, // パニエル｜今日募金を感謝されたか？
            {0x5C5, new EventFlagPlayer(0 , 1   , 1477, "SpnTodayCompleteDonation"                   )}, // パニエル｜今日募金達成したか？
            {0x5C6, new EventFlagPlayer(0 , 1   , 1478, "AlwJuneBrideNoRemake1stFlag"                )}, // リサ/ジューンブライド|今日1回目でリメイク解禁してなかった
            {0x5C7, new EventFlagPlayer(0 , 1   , 1479, "RcoExplainStorageExpandCostIncrease"        )}, // たぬきち|収納の拡張（v2.0.0）拡張工事の細かい説明聞いた
            {0x5C8, new EventFlagPlayer(0 , 1   , 1480, "AnnounceHalloween2"                         )}, // 2021年ハロウィンを島内放送で告知した(2回目放送用)
            {0x5C9, new EventFlagPlayer(0 , 1   , 1481, "HasLookMyHouseExplain_CeilingFtrAWall"      )}, // 家の機能説明ダイアログ（v200天井家具、Aウォール）を見たか？
            {0x5CA, new EventFlagPlayer(0 , 1   , 1482, "CompleteNoticeChangeHouseForm"              )}, // たぬきち|v200家外観変更に「家の形」が増えたこと告知した？
            {0x5CB, new EventFlagPlayer(0 , 1   , 1483, "SloTalkBeforeCommune"                       )}, // レイジ｜コミューン誘致後に本島で会話した？
            {0x5CC, new EventFlagPlayer(0 , 1   , 1484, "JoinedTodayRadioGymnastics"                 )}, // ラジオ体操|今日ラジオ体操に参加したか？
            {0x5CD, new EventFlagPlayer(0 , 1   , 1485, "TalkSloCommuneOpenEvent"                    )}, // レイジ｜コミューン開店イベントで話した
            {0x5CE, new EventFlagPlayer(0 , 1   , 1486, "TalkCmlCommuneOpenEvent"                    )}, // ローラン｜コミューン開店イベントで話した
            {0x5CF, new EventFlagPlayer(0 , 1   , 1487, "TalkFoxCommuneOpenEvent"                    )}, // つねきち｜コミューン開店イベントで話した
            {0x5D0, new EventFlagPlayer(0 , 1   , 1488, "TalkBptCommuneOpenEvent"                    )}, // ハッケミィ｜コミューン開店イベントで話した
            {0x5D1, new EventFlagPlayer(0 , 1   , 1489, "TalkSkkCommuneOpenEvent"                    )}, // シャンク｜コミューン開店イベントで話した
            {0x5D2, new EventFlagPlayer(0 , 1   , 1490, "TalkAlpCommuneOpenEvent"                    )}, // リサカイゾー｜コミューン開店イベントで話した
            {0x5D3, new EventFlagPlayer(0 , 1   , 1491, "BptFirstTalk"                               )}, // ハッケミィ|面識ある？
            {0x5D4, new EventFlagPlayer(0 , 1   , 1492, "SpnSendMailCommuneExpansion"                )}, // パニエル｜コミューン拡張の手紙出したか？
            {0x5D5, new EventFlagPlayer(0 , 1023, 1493, "ChocolateVillagerIndex"                     )}, // 各インデックスの住民がチョコレート勧誘されているかどうか
            {0x5D6, new EventFlagPlayer(0 , -1  , 1494, "LatestChocolateDate"                        )}, // 最新の勧誘をした日付
            {0x5D7, new EventFlagPlayer(0 , 1   , 1495, "PgeTalkCafeFlag"                            )}, // マスター|店で会話したことある？
            {0x5D8, new EventFlagPlayer(0 , 1   , 1496, "AnnounceHarvest2"                           )}, // 2021年ハーベストを島内放送で告知した(2回目放送用)
            {0x5D9, new EventFlagPlayer(0 , 1   , 1497, "MuseumCafeRandomVisitSpTalked_hgs"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（あさみ）
            {0x5DA, new EventFlagPlayer(0 , 1   , 1498, "MuseumCafeRandomVisitSpTalked_hgh"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（きぬよ）
            {0x5DB, new EventFlagPlayer(0 , 1   , 1499, "MuseumCafeRandomVisitSpTalked_doc"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（ロドリー）
            {0x5DC, new EventFlagPlayer(0 , 1   , 1500, "MuseumCafeRandomVisitSpTalked_boc"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（ウリ）
            {0x5DD, new EventFlagPlayer(0 , 1   , 1501, "MuseumCafeRandomVisitSpTalked_mol"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（リセットさん）
            {0x5DE, new EventFlagPlayer(0 , 1   , 1502, "MuseumCafeRandomVisitSpTalked_mob"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（ラケットさん）
            {0x5DF, new EventFlagPlayer(0 , 1   , 1503, "MuseumCafeRandomVisitSpTalked_tkkA"         )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（とたけけ）
            {0x5E0, new EventFlagPlayer(0 , 1   , 1504, "MuseumCafeRandomVisitSpTalked_skk"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（シャンク）
            {0x5E1, new EventFlagPlayer(0 , 1   , 1505, "MuseumCafeRandomVisitSpTalked_cml"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（ローラン）
            {0x5E2, new EventFlagPlayer(0 , 1   , 1506, "MuseumCafeRandomVisitSpTalked_hgc"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（ことの）
            {0x5E3, new EventFlagPlayer(0 , 1   , 1507, "MuseumCafeRandomVisitSpTalked_slo"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（レイジ）
            {0x5E4, new EventFlagPlayer(0 , 1   , 1508, "MuseumCafeRandomVisitSpTalked_ows"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（フーコ）
            {0x5E5, new EventFlagPlayer(0 , 1   , 1509, "MuseumCafeRandomVisitSpTalked_chy"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（レックス）
            {0x5E6, new EventFlagPlayer(0 , 1   , 1510, "MuseumCafeRandomVisitSpTalked_bey"          )}, // 喫茶ハトの巣|ランダム来訪特殊NPC今日店内で会話したか（ジャスティン）
            {0x5E7, new EventFlagPlayer(0 , 5   , 1511, "MuseumCafeRandomVisitSpMeetCount_hgs"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（あさみ）
            {0x5E8, new EventFlagPlayer(0 , 5   , 1512, "MuseumCafeRandomVisitSpMeetCount_hgh"       )}, // 喫茶ハトの巣ランダム来訪特殊NPC店内で会った回数（きぬよ）
            {0x5E9, new EventFlagPlayer(0 , 5   , 1513, "MuseumCafeRandomVisitSpMeetCount_doc"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（ロドリー）
            {0x5EA, new EventFlagPlayer(0 , 5   , 1514, "MuseumCafeRandomVisitSpMeetCount_boc"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（ウリ）
            {0x5EB, new EventFlagPlayer(0 , 5   , 1515, "MuseumCafeRandomVisitSpMeetCount_mol"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（リセットさん）
            {0x5EC, new EventFlagPlayer(0 , 5   , 1516, "MuseumCafeRandomVisitSpMeetCount_mob"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（ラケットさん）
            {0x5ED, new EventFlagPlayer(0 , 5   , 1517, "MuseumCafeRandomVisitSpMeetCount_tkkA"      )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（とたけけ）
            {0x5EE, new EventFlagPlayer(0 , 5   , 1518, "MuseumCafeRandomVisitSpMeetCount_skk"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（シャンク）
            {0x5EF, new EventFlagPlayer(0 , 5   , 1519, "MuseumCafeRandomVisitSpMeetCount_cml"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（ローラン）
            {0x5F0, new EventFlagPlayer(0 , 5   , 1520, "MuseumCafeRandomVisitSpMeetCount_hgc"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（ことの）
            {0x5F1, new EventFlagPlayer(0 , 5   , 1521, "MuseumCafeRandomVisitSpMeetCount_slo"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（レイジ）
            {0x5F2, new EventFlagPlayer(0 , 5   , 1522, "MuseumCafeRandomVisitSpMeetCount_ows"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（フーコ）
            {0x5F3, new EventFlagPlayer(0 , 5   , 1523, "MuseumCafeRandomVisitSpMeetCount_chy"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（レックス）
            {0x5F4, new EventFlagPlayer(0 , 5   , 1524, "MuseumCafeRandomVisitSpMeetCount_bey"       )}, // 喫茶ハトの巣|ランダム来訪特殊NPC店内で会った回数（ジャスティン）
            {0x5F5, new EventFlagPlayer(0 , 1   , 1525, "DoneCommuneTtlOpenEvent"                    )}, // コミューン島コトブキ開店イベント発生制御
            {0x5F6, new EventFlagPlayer(0 , 1   , 1526, "DodSelectWherearen1st"                      )}, // モーリー|「お仕事に行く」の説明を聞いた
            {0x5F7, new EventFlagPlayer(0 , 1   , 1527, "FortuneApproachTalked"                      )}, // 占い結果でのアプローチ会話発生済み
            {0x5F8, new EventFlagPlayer(0 , 1   , 1528, "SawMuseumCafeTakeoutNpc"                    )}, // 喫茶ハトの巣|テイクアウトで来店した特殊NPCを見た
            {0x5F9, new EventFlagPlayer(0 , 7   , 1529, "LastSawMuseumCafeTakeoutNpc"                )}, // 喫茶ハトの巣|最後にテイクアウトで来店するのを見たNPC
            {0x5FA, new EventFlagPlayer(0 , 1   , 1530, "KppTourDone_RareStarpiece"                  )}, // かっぺいツアー｜レア島行った：星のかけら
            {0x5FB, new EventFlagPlayer(0 , 1   , 1531, "KppTourDone_RareCherryBlossom"              )}, // かっぺいツアー｜レア島行った：桜の花びら
            {0x5FC, new EventFlagPlayer(0 , 1   , 1532, "KppTourDone_RareSpringBamboo"               )}, // かっぺいツアー｜レア島行った：春のわかたけ
            {0x5FD, new EventFlagPlayer(0 , 1   , 1533, "KppTourDone_RareSummerShell"                )}, // かっぺいツアー｜レア島行った：夏のかいがら
            {0x5FE, new EventFlagPlayer(0 , 1   , 1534, "KppTourDone_RareMushroom"                   )}, // かっぺいツアー｜レア島行った：キノコ
            {0x5FF, new EventFlagPlayer(0 , 1   , 1535, "KppTourDone_RareMapleLeaf"                  )}, // かっぺいツアー｜レア島行った：紅葉の葉っぱ
            {0x600, new EventFlagPlayer(0 , 1   , 1536, "KppTourDone_RareSnowCrystal"                )}, // かっぺいツアー｜レア島行った：雪のけっしょう
            {0x601, new EventFlagPlayer(0 , 1   , 1537, "MuseumCafe_Telephone_Calledxct"             )}, // 喫茶ハトの巣｜みしらぬネコ｜amiiboでみしらぬネコを呼び出し会話したか？
            {0x602, new EventFlagPlayer(0 , 1   , 1538, "MainmenuTips"                               )}, // スマホUI|徹底ライフサポート（Tips）解禁
            {0x603, new EventFlagPlayer(0 , 1   , 1539, "Mobile1stBoot_Tips"                         )}, // スマホアプリ初起動|徹底ライフサポート（Tips）
            {0x604, new EventFlagPlayer(0 , 1   , 1540, "MydesignExchangeExp_v2_0"                   )}, // マイデザイン交換| v2.0.0で追加された機能説明
            {0x605, new EventFlagPlayer(0 , 1   , 1541, "TalkTtlCommuneOpenEvent"                    )}, // コトブキ｜コミューン開店イベントで話した
            {0x606, new EventFlagPlayer(0 , 1   , 1542, "FoxTalkFireworksFoodFlag"                   )}, // つねきち|花火大会で食べ物追加された会話聞いた？
            {0x607, new EventFlagPlayer(0 , 1   , 1543, "AnnounceHalloween2Ready"                    )}, // 2021年ハロウィン｜準備期間に島内放送で告知した？(2回目放送用)
            {0x608, new EventFlagPlayer(0 , 1   , 1544, "PgeLikeTepidLasttimeFlag"                   )}, // マスター|前回ぬるい方が好きと答えた？
            {0x60A, new EventFlagPlayer(0 , 3   , 1546, "PgeTepidCount"                              )}, // マスター|ぬるく入れるか聞くカウンタ
            {0x60B, new EventFlagPlayer(0 , 1   , 1547, "SkkTalkFirstTimeCommune"                    )}, // シャンク｜初会話がコミューン店の方だった
            {0x60C, new EventFlagPlayer(0 , 1   , 1548, "TtlTodayTalkFlag"                           )}, // コトブキ｜今日もう会話した？
            {0x60D, new EventFlagPlayer(0 , 1   , 1549, "TtlBFirstTalkFlag"                          )}, // コトブキ｜ドンどんぐりとして今年会話した？
            {0x60F, new EventFlagPlayer(0 , 1   , 1551, "GetMayDayTicketBefore_v2_0"                 )}, // メーデー|2.0.0未満でメーデーりょこうけんを入手したことがあるか？
            {0x610, new EventFlagPlayer(0 , 1   , 1552, "XctGetRewardEveryYear"                      )}, // メーデー|みしらぬネコから3回目以降の報酬をもらった？
            {0x611, new EventFlagPlayer(0 , 1   , 1553, "FoxFirstTalkTodayFireworksFlag"             )}, // つねきち|今日花火大会で会話した？
            {0x612, new EventFlagPlayer(0 , 1   , 1554, "PlayerMovingWithPFlag555"                   )}, // パニエル|「撮影スタジオの説明」聞いた後に、P引越しした
            {0x613, new EventFlagPlayer(0 , 1   , 1555, "PooTalkFirst"                               )}, // カットリーヌ｜面識がある？
            {0x614, new EventFlagPlayer(0 , 1   , 1556, "PooTalkToday"                               )}, // カットリーヌ｜今日会話した？
            {0x615, new EventFlagPlayer(0 , 1   , 1557, "PooTalkFirstToday"                          )}, // カットリーヌ｜今日面識ができた？
            {0x616, new EventFlagPlayer(0 , 1   , 1558, "PooGetNewHairStyle7"                        )}, // カットリーヌ｜ヘアアレンジ解禁７（コトブキ）
            {0x617, new EventFlagPlayer(0 , 1   , 1559, "WHEREAREN_TapFirstCheckMydesingShowcase"    )}, // OneRoom|視察中にマイデザインショーケース端末にアクセスしたことがある？
            {0x618, new EventFlagPlayer(0 , 1   , 1560, "PAAboutUnlockIslandRegulation"              )}, // 島内放送|条例が解禁したこと聞いた
            {0x619, new EventFlagPlayer(0 , 1   , 1561, "SelectedGotoCafe"                           )}, // 日課「喫茶店に行こうキャンペーン」を今日達成した
            {0x61A, new EventFlagPlayer(0 , 2   , 1562, "SelectedDoRadioGymnastics"                  )}, // 日課「ラジオ体操をしよう」が出現カウンター
            {0x61B, new EventFlagPlayer(0 , 1   , 1563, "TtlB_Acorn_Today"                           )}, // コトブキ｜今日どんぐり貰った？
            {0x61C, new EventFlagPlayer(0 , 1   , 1564, "HeldCeremonyMuseum3"                        )}, // セレモニ|博物館③を開いた
            {0x61D, new EventFlagPlayer(0 , 1   , 1565, "StandByPhoneCallNpcNG"                      )}, // 電話デモ|NPCを呼び出せなかった入電するか？
            {0x61E, new EventFlagPlayer(0 , 1   , 1566, "PgeTalkTakeOutFlag"                         )}, // マスター|テイクアウトの話聞いた？
            {0x61F, new EventFlagPlayer(0 , 1   , 1567, "UnlockPlayerHair37"                         )}, // 髪型解禁：Hair37センターわけ
            {0x620, new EventFlagPlayer(0 , 1   , 1568, "UnlockPlayerHair38"                         )}, // 髪型解禁：Hair38ウルフカット
            {0x621, new EventFlagPlayer(0 , 1   , 1569, "UnlockPlayerHair39"                         )}, // 髪型解禁：Hair39オールバック
            {0x622, new EventFlagPlayer(0 , 1   , 1570, "UnlockPlayerHair40"                         )}, // 髪型解禁：Hair40マッシュルーム
            {0x623, new EventFlagPlayer(0 , 1   , 1571, "UnlockPlayerHair41"                         )}, // 髪型解禁：Hair41かっこいいMじ
            {0x624, new EventFlagPlayer(0 , 1   , 1572, "UnlockPlayerHair42"                         )}, // 髪型解禁：Hair42そりこみぼうず
            {0x625, new EventFlagPlayer(0 , 1   , 1573, "UnlockPlayerHair43"                         )}, // 髪型解禁：Hair43ハーフアップ
            {0x626, new EventFlagPlayer(0 , 1   , 1574, "UnlockPlayerHair44"                         )}, // 髪型解禁：Hair44ふわひとつあみ
            {0x627, new EventFlagPlayer(0 , 1   , 1575, "UnlockPlayerHair45"                         )}, // 髪型解禁：Hair45ふわひとつくくり
            {0x628, new EventFlagPlayer(0 , 1   , 1576, "UnlockPlayerHair46"                         )}, // 髪型解禁：Hair46まとめがみ
            {0x629, new EventFlagPlayer(0 , 1   , 1577, "UnlockPlayerHair47"                         )}, // 髪型解禁：Hair47みつあみツイン
            {0x62A, new EventFlagPlayer(0 , 1   , 1578, "TtlChangeTtlB"                              )}, // コトブキをドンどんぐりに差し替え
            {0x62B, new EventFlagPlayer(0 , 4095, 1579, "TkkFirstPlayNewSong"                        )}, // とたけけ|まだ演奏したことがない新曲かどうか
            {0x62C, new EventFlagPlayer(0 , 8   , 1580, "XctCalledMessageBefore"                     )}, // メーデー|前の1537で出現したメッセージ番号
            {0x62D, new EventFlagPlayer(0 , 9999, 1581, "LastPlayFireWorksFestival"                  )}, // 花火大会|最後に遊んだ花火大会の年
            {0x62E, new EventFlagPlayer(0 , 1   , 1582, "SendAocPurchasingPrize"                     )}, // AOC|予約・購入特典を送付した
            {0x62F, new EventFlagPlayer(0 , 1   , 1583, "FoxCommuneTalkBeforeFlag"                   )}, // つねきち|今日コミューンのつねきちからお店の説明聞いた？
            {0x630, new EventFlagPlayer(0 , 1   , 1584, "FoxCommuneTalkLotteryTodayFlag"             )}, // つねきち|今日コミューン開店イベントで話した
            {0x631, new EventFlagPlayer(0 , 1   , 1585, "FoxCommuneTalkExplainFlag"                  )}, // つねきち|コミューンのつねきちからお店の説明聞いた？
            {0x632, new EventFlagPlayer(0 , 1   , 1586, "FoxCommunePlayLotteryTodayFlag"             )}, // つねきち|今日コミューンのつねきちのくじ引いた？
            {0x634, new EventFlagPlayer(0 , 9999, 1588, "LastPlayMayDayYear"                         )}, // メーデー|最後に遊んだメーデーの年
            {0x635, new EventFlagPlayer(0 , 1   , 1589, "FoxCommuneTalkIceTodayFlag"                 )}, // つねきち|アイス系の説明した？
            {0x636, new EventFlagPlayer(0 , 1   , 1590, "FoxCommuneTalkJuiceTodayFlag"               )}, // つねきち|缶飲料の説明した？
            {0x637, new EventFlagPlayer(0 , 1   , 1591, "FoxCommuneTalkTodayFlag"                    )}, // つねきち|今日コミューンのつねきちと会話した？
            {0x639, new EventFlagPlayer(0 , 1   , 1593, "WHEREAREN_Unlock_RoomDimming"               )}, // OneRoom|オリジナル調光アンロック
            {0x63A, new EventFlagPlayer(0 , 1   , 1594, "OwlDonateDiveFishAtMuseumTent"              )}, // フータ|テント状態のときに海の幸を見せた？
            {0x63B, new EventFlagPlayer(0 , 1   , 1595, "FoxCommuneBuyArtTodayFlag"                  )}, // つねきち|今日コミューンで美術品買った？
            {0x63C, new EventFlagPlayer(0 , 1   , 1596, "UnlockBuyFIXLadderRecipe"                   )}, // お店｜はしごFIXキットのレシピ陳列開始
            {0x63D, new EventFlagPlayer(0 , 1   , 1597, "UnlockBuyInteriorModePro"                   )}, // タヌポート｜もようがえPROライセンス陳列解禁
            {0x63E, new EventFlagPlayer(0 , 1   , 1598, "AlwCommuneTalkTodayFlag"                    )}, // リサ｜今日コミューン島で会話した？
            {0x63F, new EventFlagPlayer(0 , 1   , 1599, "UnlockBuyReactionCollection_v200"           )}, // タヌポート｜リアクション集v200陳列解禁
            {0x640, new EventFlagPlayer(0 , 1   , 1600, "UnlockBuyHairStyleCollection_v200"          )}, // タヌポート｜ヘアスタイル集v200陳列解禁
            {0x641, new EventFlagPlayer(0 , 1   , 1601, "RadioGymnasticsAchievementFinish"           )}, // ラジオ体操の実績を今日カウントした
            {0x642, new EventFlagPlayer(0 , 1   , 1602, "UnlockBuyTipsApp"                           )}, // タヌポート｜徹底ライフサポートアプリ陳列解禁
            {0x643, new EventFlagPlayer(0 , 2   , 1603, "TreasureHuntJustMissed"                     )}, // 宝探し｜ギリギリだったか
            {0x644, new EventFlagPlayer(0 , 1   , 1604, "WHEREAREN_Use_AccentWall"                   )}, // アクセントウォールを使用したことがある
            {0x645, new EventFlagPlayer(0 , 1   , 1605, "WHEREAREN_Unlock_DustCloth_01"              )}, // OneRoom|まごころ雑巾アンロック01
            {0x646, new EventFlagPlayer(0 , 1   , 1606, "WHEREAREN_Unlock_DustCloth_02"              )}, // OneRoom|まごころ雑巾アンロック02
            {0x648, new EventFlagPlayer(0 , 1   , 1608, "WHEREAREN_Unlock_EnvSound_01"               )}, // OneRoom|環境音アンロック01
            {0x649, new EventFlagPlayer(0 , 1   , 1609, "WHEREAREN_Unlock_EnvSound_02"               )}, // OneRoom|環境音アンロック02
            {0x64A, new EventFlagPlayer(0 , 1   , 1610, "WHEREAREN_Unlock_EnvSound_03"               )}, // OneRoom|環境音アンロック03
            {0x64C, new EventFlagPlayer(0 , 1   , 1612, "WHEREAREN_Prev_Unlock_EnvSound_01"          )}, // OneRoom|環境音アンロック01_事前フラグ
            {0x64D, new EventFlagPlayer(0 , 1   , 1613, "WHEREAREN_Prev_Unlock_EnvSound_02"          )}, // OneRoom|環境音アンロック02_事前フラグ
            {0x64E, new EventFlagPlayer(0 , 1   , 1614, "WHEREAREN_Prev_Unlock_EnvSound_03"          )}, // OneRoom|環境音アンロック03_事前フラグ
            {0x650, new EventFlagPlayer(0 , 1   , 1616, "WHEREAREN_Unlock_RoomSizeModeUnlock"        )}, // OneRoom|部屋サイズモードアンロック
            {0x651, new EventFlagPlayer(0 , 1   , 1617, "Owl1stTalkMuseum3"                          )}, // フータ|博物館③（カフェ）完成後の挨拶した？
            {0x652, new EventFlagPlayer(0 , 1   , 1618, "LectureAboutMarinesuitBuyIt"                )}, // まめきち|マリンスーツを買ったときレクチャーをする？
            {0x653, new EventFlagPlayer(0 , 1   , 1619, "TalkHHATodayAnyone"                         )}, // 今日誰かにHHAを聞いたか
            {0x654, new EventFlagPlayer(0 , 1   , 1620, "UnlockBuyReactionCoolection_v160"           )}, // タヌポート｜リアクション集v160陳列解禁
            {0x655, new EventFlagPlayer(0 , 1   , 1621, "UnlockBuyHairStyleColection_v160"           )}, // タヌポート｜もっと！ヘアスタイル×６v160陳列解禁
            {0x656, new EventFlagPlayer(0 , 1   , 1622, "UnlockBuyAddBridgeSlope"                    )}, // タヌポート｜インフラぞうせつライセンス陳列解禁
            {0x657, new EventFlagPlayer(0 , 1   , 1623, "MuseumPosterTalkAboutMakePoster"            )}, // フータ/博物館コンプポスター|フータに「ポスター準備する話」を聞いたか？
            {0x658, new EventFlagPlayer(0 , 1   , 1624, "MuseumPosterUnlockBuySel"                   )}, // フータ/博物館コンプポスター|自身が「ポスター買う」選択肢出すか？
            {0x659, new EventFlagPlayer(0 , 1   , 1625, "MuseumPosterUnlockMyselfBug"                )}, // フータ/博物館コンプポスター|自身がムシのポスター購入を解禁した？
            {0x65A, new EventFlagPlayer(0 , 1   , 1626, "MuseumPosterUnlockMyselfFish"               )}, // フータ/博物館コンプポスター|自身がサカナのポスター購入を解禁した？
            {0x65B, new EventFlagPlayer(0 , 1   , 1627, "MuseumPosterUnlockMyselfFossil"             )}, // フータ/博物館コンプポスター|自身が化石のポスター購入を解禁した？
            {0x65C, new EventFlagPlayer(0 , 1   , 1628, "MuseumPosterUnlockMyselfPainting"           )}, // フータ/博物館コンプポスター|自身が美術品のポスター購入を解禁した？
            {0x65D, new EventFlagPlayer(0 , 1   , 1629, "MuseumPosterUnlockMySelfSea"                )}, // フータ/博物館コンプポスター|自身が海の幸のポスター購入を解禁した？
            {0x65E, new EventFlagPlayer(0 , 1   , 1630, "TtlTodayFirstTalkFlag"                      )}, // コトブキ｜今日初会話した？
            {0x65F, new EventFlagPlayer(0 , 256 , 1631, "BalloonShootCountSum"                       )}, // Tips|風船を撃ち落とした累計回数
            {0x660, new EventFlagPlayer(0 , 1   , 1632, "BocBuyNumCountSum"                          )}, // Tips|ウリからのカブ購入数X以上か？（X=15)
            {0x664, new EventFlagPlayer(0 , 1   , 1636, "NoticeAboutInteriorModePlus_playerHouse"    )}, // 自宅か撮影スタジオでインテリアモード開いてインテリアモード＋の初回ダイアログを見た？
            {0x665, new EventFlagPlayer(0 , 1   , 1637, "NoticeAboutInteriorModePlus_Dimming"        )}, // インテリアモード＋の調光追加の初回ダイアログを見た？
            {0x666, new EventFlagPlayer(0 , 1   , 1638, "NoticeAboutInteriorModePlus_EnvironmentalSound1")}, // 環境音解禁の初回ダイアログを見た？
            {0x667, new EventFlagPlayer(0 , 1   , 1639, "NoticeAboutInteriorModePlus_EnvironmentalSound2")}, // 環境音解禁の追加１ダイアログを見た？
            {0x668, new EventFlagPlayer(0 , 1   , 1640, "NoticeAboutInteriorModePlus_EnvironmentalSound3")}, // 環境音解禁の追加２ダイアログを見た？
            {0x669, new EventFlagPlayer(0 , 1   , 1641, "BuildAddtionalBridgeSlopeIntroduction"      )}, // たぬきち｜ライセンス所持状態で９本目の橋/坂建てようとしてる？
            {0x66A, new EventFlagPlayer(0 , 1   , 1642, "NoticeAboutMagokoro_MainIsland"             )}, // まごころ雑巾解禁後、本島側でスタジオ＆家に入った初回ダイアログを見た？
            {0x66B, new EventFlagPlayer(0 , 1   , 1643, "WHEREAREN_NoticeAboutDustCloth2"            )}, // OneRoom|まごころ雑巾の追加用ダイアログを見た？
            {0x66C, new EventFlagPlayer(0 , 1   , 1644, "GotToiletForTips"                           )}, // Tips|トイレ入手したか？
            {0x66D, new EventFlagPlayer(0 , 1   , 1645, "GotBushForTips"                             )}, // Tips|低木入手したか？
            {0x66E, new EventFlagPlayer(0 , 1   , 1646, "GetDresserForTips"                          )}, // Tips|ドレッサー入手したか？
            {0x66F, new EventFlagPlayer(0 , 20  , 1647, "KppTourDidntHit_Rare"                       )}, // かっぺいツアー｜連続ハズレカウンタ：レア島
            {0x670, new EventFlagPlayer(0 , 20  , 1648, "KppTourDidntHit_Haniwa"                     )}, // かっぺいツアー｜連続ハズレカウンタ：はにわ島
            {0x671, new EventFlagPlayer(0 , 20  , 1649, "KppTourDidntHit_Vegetable"                  )}, // かっぺいツアー｜連続ハズレカウンタ：やさい島
            {0x672, new EventFlagPlayer(0 , 20  , 1650, "KppTourDidntHit_DLC"                        )}, // かっぺいツアー｜連続ハズレカウンタ：OneRoom島
            {0x673, new EventFlagPlayer(0 , 1   , 1651, "GotBonusMax"                                )}, // Tips｜ログインボーナス上限X達したか？
            {0x674, new EventFlagPlayer(0 , 512 , 1652, "GotBonusToday"                              )}, // Tips｜今日のログインボーナスマイル？
            {0x675, new EventFlagPlayer(0 , 1   , 1653, "PgeCoffeeEatInTodayFlag"                    )}, // マスター|今日イートインでコーヒー注文した？
            {0x676, new EventFlagPlayer(0 , 1   , 1654, "RcmBlackFridayTodayFlag"                    )}, // まめきち｜ブラックフライデーの入店時会話した？
            {0x677, new EventFlagPlayer(0 , 256 , 1655, "DoneDIYCountNum"                            )}, // Tips｜DIY家具or道具、または料理をX回したか？
            {0x678, new EventFlagPlayer(0 , 1   , 1656, "RadioGymnasticsGotAllRewards"               )}, // Tips|ラジオ体操の報酬プロテインまでもらった？
            {0x679, new EventFlagPlayer(0 , 9999, 1657, "TtlBFirstTalkYear"                          )}, // コトブキ｜ドンどんぐりと会話した年
            {0x67A, new EventFlagPlayer(0 , 1   , 1658, "LettersNumForTips"                          )}, // Tips|メッセージが100通以上残っている＋未開封がある？
            {0x67B, new EventFlagPlayer(0 , 3   , 1659, "WHEREAREN_GetInspectRewardsNum"             )}, // OneRoom|見学した数についてナッティーからの話を聞いたかのフラグ
            {0x67C, new EventFlagPlayer(0 , -1  , 1660, "JoinedPastRadioGymnasticsNum"               )}, // Tips|前日以前に何回ラジオ体操に参加していないか
            {0x67D, new EventFlagPlayer(0 , 1   , 1661, "WHEREAREN_NoticeAboutMemberPage"            )}, // OneRoom|メンバーページを開いたときの説明ダイアログを見た？
            {0x67E, new EventFlagPlayer(0 , 1   , 1662, "WHEREAREN_NoticeAboutMyPage"                )}, // OneRoom|マイページを開いたときの説明ダイアログを見た？
            {0x67F, new EventFlagPlayer(0 , 1   , 1663, "SpnExpandEventAfterJuneBride"               )}, // パニエル｜ジューンブライド初回から解禁イベントにハシゴ
            {0x680, new EventFlagPlayer(0 , 1   , 1664, "RepayMileInteriorModePro"                   )}, // もようがえPROライセンスのマイルを返還する？
            {0x681, new EventFlagPlayer(0 , 1   , 1665, "WHEREAREN_Mobile1stBoot_ResortPlannerApp"   )}, // OneRoom|リゾプラappの初回起動かどうか？
            {0x682, new EventFlagPlayer(0 , 1   , 1666, "MuseumCafe_Tel_CalledThisYearXct"           )}, // 喫茶ハトの巣｜みしらぬネコ｜amiiboでみしらぬネコを今年呼び出し会話したか？
            {0x683, new EventFlagPlayer(0 , 1   , 1667, "PooTalkAfterJuneBride"                      )}, // カットリーヌ｜ジューンブライドクリア後の反応予約フラグ
            {0x684, new EventFlagPlayer(0 , 1   , 1668, "KppTalkAboutVine"                           )}, // かっぺい|ツアーでツタの説明した？
            {0x685, new EventFlagPlayer(0 , 1   , 1669, "IsOnPlayerMemoriesFireworksInMainfield"     )}, // 思い出機能｜花火が花火大会開催中にメインフィールドにいたがON？
            {0x686, new EventFlagPlayer(0 , 1   , 1670, "IsOnPlayerMemoriesDivingFirst"              )}, // 思い出機能｜マリンスーツで初めて海に飛び込んだがON？
            {0x687, new EventFlagPlayer(0 , 1   , 1671, "NoticeAboutInteriorModePlus_RoomSize"       )}, // OneRoomでインテリアモード＋の初回ダイアログを見た？
            {0x688, new EventFlagPlayer(0 , 1   , 1672, "WHEREAREN_NoticeAboutResortPlannnerAppNet"  )}, // OneRoom|マイページを開いたときの説明ダイアログを見た？
            {0x689, new EventFlagPlayer(0 , 1   , 1673, "UnlockBuyATM"                               )}, // タヌポート｜ATM陳列解禁
            {0x68A, new EventFlagPlayer(0 , 1   , 1674, "UnlockBuyStoreroom"                         )}, // タヌポート｜ものおき＆レシピ陳列解禁
            {0x68C, new EventFlagPlayer(0 , 1   , 1676, "NoticeAboutRoomSketch"                      )}, // ルームスケッチの初回ダイアログを見た？
            {0x68D, new EventFlagPlayer(0 , 1   , 1677, "CommuneCompleteExpandEvent_Player"          )}, // コミューン｜自分がコミューン拡張（または初回イベント）みたか？
            {0x68E, new EventFlagPlayer(0 , 1   , 1678, "PAnnounceAboutKppTourCompleted"             )}, // 島内放送｜かっぺいツアーに関する島内放送をしたか？
            {0x68F, new EventFlagPlayer(0 , 1   , 1679, "MakePlayerAfterStartingKppTour"             )}, // かっぺい｜かっぺいツアー開始後に作られたプレイヤーか？
            {0x690, new EventFlagPlayer(0 , 1   , 1680, "IsOnPlayerMemoriesSeasonPetal"              )}, // 思い出機能｜桜の花びらをその日初めて取得したがON？
            {0x691, new EventFlagPlayer(0 , 1   , 1681, "IsOnPlayerMemoriesSeasonCrystal"            )}, // 思い出機能｜雪の結晶をその日初めて取得したがON？
            {0x692, new EventFlagPlayer(0 , 1   , 1682, "IsOnPlayerMemoriesSeasonLeaf"               )}, // 思い出機能｜紅葉をその日初めて取得したがON？
            {0x693, new EventFlagPlayer(0 , 1   , 1683, "IsOnPlayerMemoriesSeasonBamboo"             )}, // 思い出機能｜はるのわかたけをその日初めて取得したがON？
            {0x694, new EventFlagPlayer(0 , 1   , 1684, "IsOnPlayerMemoriesSeasonShell"              )}, // 思い出機能｜夏のかいがらをその日初めて取得したがON？
            {0x695, new EventFlagPlayer(0 , 1   , 1685, "IsOnPlayerMemoriesSeasonAcorn"              )}, // 思い出機能｜どんぐりをその日初めて取得したがON？
            {0x696, new EventFlagPlayer(0 , 1   , 1686, "IsOnPlayerMemoriesSeasonPinecone"           )}, // 思い出機能｜まつぼっくりをその日初めて取得したがON？
            {0x697, new EventFlagPlayer(0 , 1   , 1687, "WHERWAREN_NoticeAbout_ResortPlanner"        )}, // OneRoom|ツクッターの初回ダイアログを見終わったか？
            {0x698, new EventFlagPlayer(0 , 1   , 1688, "WHEREAREN_PlayingContentsToday"             )}, // OneRoom|今日OneRoomを遊んだか
            {0x699, new EventFlagPlayer(0 , 1   , 1689, "WHEREAREN_PlayedContentsBefore"             )}, // OneRoom|前回OneRoomを遊んだか
            {0x69A, new EventFlagPlayer(0 , 1   , 1690, "MuseumPosterTodayflagbug"                   )}, // フータ/博物館コンプポスター|ムシのポスターもらった？
            {0x69B, new EventFlagPlayer(0 , 1   , 1691, "MuseumPosterTodayflagfish"                  )}, // フータ/博物館コンプポスター|サカナのポスターもらった？
            {0x69C, new EventFlagPlayer(0 , 1   , 1692, "MuseumPosterTodayflagfossil"                )}, // フータ/博物館コンプポスター|かせきのポスターもらった？
            {0x69D, new EventFlagPlayer(0 , 1   , 1693, "MuseumPosterTodayflagpainting"              )}, // フータ/博物館コンプポスター|美術品のポスターもらった？
            {0x69E, new EventFlagPlayer(0 , 1   , 1694, "MuseumPosterTodayflagsea"                   )}, // フータ/博物館コンプポスター|海の幸のポスターもらった？
            {0x69F, new EventFlagPlayer(0 , 1   , 1695, "WHEREAREN_RcoHeardRemakeWS"                 )}, // たぬきち|飛行場でリメイク体験会の話を聞いた
            {0x6A0, new EventFlagPlayer(0 , 1   , 1696, "IsOnPlayerMemoriesMushSplendid"             )}, // 思い出機能｜りっぱなキノコをその日初めて取得したがON？
            {0x6A1, new EventFlagPlayer(0 , 1   , 1697, "IsOnPlayerMemoriesMushRound"                )}, // 思い出機能｜まるいキノコをその日初めて取得したがON？
            {0x6A2, new EventFlagPlayer(0 , 1   , 1698, "IsOnPlayerMemoriesMushSlender"              )}, // 思い出機能｜ほそいキノコをその日初めて取得したがON？
            {0x6A3, new EventFlagPlayer(0 , 1   , 1699, "IsOnPlayerMemoriesMushFlat"                 )}, // 思い出機能｜ひらたいキノコをその日初めて取得したがON？
            {0x6A4, new EventFlagPlayer(0 , 1   , 1700, "IsOnPlayerMemoriesMushRare"                 )}, // 思い出機能｜めずらしいキノコをその日初めて取得したがON？
            {0x6A5, new EventFlagPlayer(0 , 1   , 1701, "RejectedTips"                               )}, // 徹底ライフサポート（Tips）受け取り拒否設定がON？
            {0x6A6, new EventFlagPlayer(0 , 1   , 1702, "UnlockBuyRcoOnePieceAerobics"               )}, // ラジオ体操｜レオタードをタヌポートにも陳列
            {0x6A7, new EventFlagPlayer(0 , 1   , 1703, "UnlockBuyRcoYogaMat"                        )}, // ラジオ体操｜ヨガマットをタヌポートにも陳列
            {0x6AA, new EventFlagPlayer(0 , 1   , 1706, "DodSelectWherearenFromBeginning"            )}, // モーリー|「お仕事に行く」の説明を他の件と一緒に聞いた
            {0x6AB, new EventFlagPlayer(0 , 1   , 1707, "EquipDustClothWithGateOpen"                 )}, // まごころ雑巾｜開門中にまごころ雑巾を装備のダイアログを見た？
            {0x6AD, new EventFlagPlayer(0 , 1   , 1709, "WHEREAREN_NoticeAboutFirstPublication_ResortPlanner")}, // OneRoom|マイページにて「施工事例から選んでね」ダイアログを一度表示したかどうか？
            {0x6AE, new EventFlagPlayer(0 , 1   , 1710, "TalkAboutNpcHouseCoordeHint"                )}, // たぬきち｜NPC家コーデ内装初回説明したか？
            {0x6AF, new EventFlagPlayer(0 , 10  , 1711, "NpcHouseCoordinateTodayCount"               )}, // たぬきち｜NPC家コーデの当日内回数チェックカウンタ
            {0x6B0, new EventFlagPlayer(0 , 1   , 1712, "PublicAnnouncement_MarinsuitHint"           )}, // 島内放送｜マリンスーツのヒントを聞いたか？
            {0x6B1, new EventFlagPlayer(0 , 1   , 1713, "WHEREAREN_NoticeAboutSNSShare"              )}, // OneRoom｜ツクッター初回掲載後のSN共有の説明を見た？
            {0x6B2, new EventFlagPlayer(0 , 10  , 1714, "PlanPalmSeedOnSand"                         )}, // Tips|やしのみを砂浜に植えた回数
            {0x6B3, new EventFlagPlayer(0 , 10  , 1715, "PlanBambooshoot"                            )}, // Tips|たけのこを植えた回数
            {0x6B4, new EventFlagPlayer(0 , 1   , 1716, "PlayerDoneEating"                           )}, // Tips|料理を1回以上「食べる」をした
            {0x6B5, new EventFlagPlayer(0 , 10  , 1717, "OpenUIMenuLoadTipsCount"                    )}, // Tips|徹底ライフサポートUIを開いた回数
            {0x6B6, new EventFlagPlayer(0 , 1   , 1718, "PlayerUsedChangeStick"                      )}, // Tips|変身ステッキを使ったことがあるか
            {0x6B7, new EventFlagPlayer(0 , 1   , 1719, "ScanAmiiboInCafe"                           )}, // Tips|喫茶店でAmiibo読み込みを行った
            {0x6B8, new EventFlagPlayer(0 , 1   , 1720, "ScanAmiiboInPhotoStudio"                    )}, // Tips|撮影スタジオでAmiibo読み込みを行った
            {0x6B9, new EventFlagPlayer(0 , 1   , 1721, "RequestedAlpRemake"                         )}, // Tips|カイゾーにリメイクを依頼した
            {0x6BA, new EventFlagPlayer(0 , 1   , 1722, "RequestedAlpUniqueRemake"                   )}, // Tips|カイゾーにカイゾーにしかできないリメイクを依頼した
            {0x6BB, new EventFlagPlayer(0 , 1   , 1723, "AlreadyCheckedFirstTips1"                   )}, // 初回用固定Tips1を見た
            {0x6BC, new EventFlagPlayer(0 , 1   , 1724, "AlreadyCheckedFirstTips2"                   )}, // 初回用固定Tips2を見た
            {0x6BD, new EventFlagPlayer(0 , 1   , 1725, "AlreadyCheckedOneRoomFirstTips1"            )}, // OneRoom権利獲得後初回固定Tips1を見た
            {0x6BE, new EventFlagPlayer(0 , 1   , 1726, "SloFirstTalkCommune"                        )}, // レイジ｜コミューン島で初対面会話した？
            {0x6BF, new EventFlagPlayer(0 , 5   , 1727, "SalmonCookingRecipeCount"                   )}, // DIY｜レシピ１つ覚えた後、サケを釣り上げた回数をカウント
            {0x6C0, new EventFlagPlayer(0 , 1   , 1728, "StandByCallByRcoNpcHouseCoodinate"          )}, // 電話デモ|たぬきちNPC家エディット導入入電するか？
            {0x6C1, new EventFlagPlayer(0 , 1   , 1729, "RcoCoordinateUnlockWithPhoneCall"           )}, // たぬきち|NPC家エディット解禁電話聞いたか？
            {0x6C2, new EventFlagPlayer(0 , 3   , 1730, "SloVegetableCount"                          )}, // レイジ｜野菜の苗を買い物した回数
            {0x6C3, new EventFlagPlayer(0 , 1   , 1731, "SloBuyVegetableToday"                       )}, // レイジ｜今日野菜の買い物したか
            {0x6C4, new EventFlagPlayer(0 , 1   , 1732, "SloBuyToday"                                )}, // レイジ｜今日レイジから買い物したか？
            {0x6C6, new EventFlagPlayer(0 , 1   , 1734, "WHEREAREN_IsSnsShareCanceled"               )}, // OneRoom｜デイリー表示される掲載後のSNSShareをキャンセルしたか？
            {0x6C8, new EventFlagPlayer(0 , 1   , 1736, "OtgTipsUnlockGardenEdit"                    )}, // Tips|2件目庭（季節変更、時間帯変更、庭エディット解禁）
            {0x6C9, new EventFlagPlayer(0 , 1   , 1737, "OtgTipsComplete1stOrder"                    )}, // Tips|1件目完了（オーディオ家具解禁）
            {0x6CA, new EventFlagPlayer(0 , 1   , 1738, "RcoBuildMovingPurchase_v200"                )}, // たぬきち｜v2.0.0で何らかの移設費用支払った？
            {0x6CB, new EventFlagPlayer(0 , 1   , 1739, "SendLetterBuildMovingPricedown"             )}, // たぬきち｜移設費用値下げの手紙送った？
            {0x6CC, new EventFlagPlayer(0 , 1   , 1740, "ReturnMyHomeMoving8000PMoving"              )}, // たぬきち｜Pだけ引越しで返金されたマイホーム移設費用は8000ベル？
            {0x6CD, new EventFlagPlayer(0 , 1   , 1741, "OtgTipsUnlockWorkingTable"                  )}, // Tips|6件目完了（2FDIY作業台解禁）
            {0x6CE, new EventFlagPlayer(0 , 1   , 1742, "WHEREAREN_UnlockMessageBottleAfter"         )}, // Tips|ウェアラン諸島でメッセージボトル解禁されてから1成長処理経過
            {0x6CF, new EventFlagPlayer(0 , 1   , 1743, "OtgTipsCompleteSchoolBuild"                 )}, // Tips|学校完成（キャストUI、施設リフォーム解禁）
            {0x6D0, new EventFlagPlayer(0 , 1   , 1744, "OtgTipsCompleteSloSchoolEvent"              )}, // Tips|レイジの授業完了（交配花の一部解禁）
            {0x6D1, new EventFlagPlayer(0 , 1   , 1745, "RcoOfficeBuiltLetter"                       )}, // 案内所完成の案内手紙投函された
            {0x6D2, new EventFlagPlayer(0 , 1   , 1746, "WatchedRcoAnnouceAfter200ver"               )}, // 2.0.0以降verでたぬきち島内放送を見た
            {0x6D3, new EventFlagPlayer(0 , 1   , 1747, "OtgTipsComplete2ndFacilityBuild"            )}, // Tips|カフェ/レストラン少なくともどちらかが完成
            {0x6D4, new EventFlagPlayer(0 , 1   , 1748, "OtgTipsUnlockDIYFtrCatalog"                 )}, // Tips|DIYしたことある家具のカタログ解禁
            {0x6D5, new EventFlagPlayer(0 , 1   , 1749, "ScanAmiiboInTanuport"                       )}, // Tips|タヌポートでAmiibo読み込みを行った
            {0x6D6, new EventFlagPlayer(0 , 1   , 1750, "OtgTipsUnlockHouseShare"                    )}, // Tips|シェアハウス解禁
            {0x6D7, new EventFlagPlayer(0 , 1   , 1751, "OtgTipsCompleteCafeBuild"                   )}, // Tips|カフェ完成
            {0x6D8, new EventFlagPlayer(0 , 1   , 1752, "OtgTipsCompleteRestaulantBuild"             )}, // Tips|レストラン完成
            {0x6D9, new EventFlagPlayer(0 , 1   , 1753, "OtgTipsCompleteHospitalBuild"               )}, // Tips|病院完成
            {0x6DA, new EventFlagPlayer(0 , 1   , 1754, "OtgTipsCompleteBoutiqueBuild"               )}, // Tips|アパレルショップ完成
            {0x6DB, new EventFlagPlayer(0 , 1   , 1755, "OtgTipsCompleteHospitalDonation"            )}, // Tips|病院の募金が完了した
            {0x6DC, new EventFlagPlayer(0 , 1   , 1756, "OtgTipsBuildEitherCafeRestaulant"           )}, // Tips|カフェ/レストランどちらかが未完成
            {0x6DD, new EventFlagPlayer(0 , 1   , 1757, "WHEREAREN_SeqAvailableAmiiboDone"           )}, // Tips|amiibo読取機解禁イベントを見た？
            {0x6DE, new EventFlagPlayer(0 , 2   , 1758, "BocFirstMail"                               )}, // ウリ｜商店が建ったときの手紙を出したか？
            {0x6DF, new EventFlagPlayer(0 , 1   , 1759, "OtgTipsExplainManCatalog"                   )}, // Tips|ナッティーカタログ解禁説明聞いた？
            {0x6E0, new EventFlagPlayer(0 , 1   , 1760, "OtgTipsUnlockATM"                           )}, // Tips|事務所ATM解禁した？
            {0x6E1, new EventFlagPlayer(0 , 1   , 1761, "CommuneATMChkToday"                         )}, // コミューン｜今日ATMをチェックした？
            {0x6E2, new EventFlagPlayer(0 , 1   , 1762, "SpnCommuneATMNoticeDone"                    )}, // パニエル｜ATMについて喋った？
            {0x6E3, new EventFlagPlayer(0 , 1   , 1763, "RcoTalkAboutNpcHouseEditOfficeBuild"        )}, // たぬきち｜Pだけ引越し後案内所完成したら、NPC家コーデの解禁告知するか？
            {0x6E4, new EventFlagPlayer(0 , 1   , 1764, "RcoPMovingUnlockNpcEditWithPhoneCall"       )}, // たぬきち｜入電は聞いたがNPC家コーデを解禁せずにPだけ引越しした
            {0x6E5, new EventFlagPlayer(0 , 1   , 1765, "WHERWAREN_NoticeAbout_ResortPlannerRevisit" )}, // OneRoom｜訪問機能の説明ダイアログを見た？
            {0x6E6, new EventFlagPlayer(0 , 1   , 1766, "PublicAnnoucement_EvNotice_Carnival"        )}, // 島内放送｜カーニバルの予告を聞いたか？
            {0x6E7, new EventFlagPlayer(0 , 1   , 1767, "WHEREAREN_OtgVisitThisIsland"               )}, // 今住んでる島でOneRoomの解禁イベントを見た
            {0x6E8, new EventFlagPlayer(0 , 1   , 1768, "DocUnlockSpnOtgDirectRoute"                 )}, // ロドリー｜直行便解禁会話見た？
            {0x6E9, new EventFlagPlayer(0 , 1   , 1769, "UnlockCatalogPokiBag"                       )}, // カタログ｜ポキ袋をスタジオやOneRoomのカタログで解禁
            {0x6EA, new EventFlagPlayer(0 , 1   , 1770, "PAnnounceFishingEvNotice_Jan"               )}, // 島内放送｜釣り大会の予告を聞いたか（１月）
            {0x6EB, new EventFlagPlayer(0 , 1   , 1771, "PAnnounceFishingEvNotice_Apr"               )}, // 島内放送｜釣り大会の予告を聞いたか（４月）
            {0x6EC, new EventFlagPlayer(0 , 1   , 1772, "PAnnounceFishingEvNotice_Jul"               )}, // 島内放送｜釣り大会の予告を聞いたか（７月）
            {0x6ED, new EventFlagPlayer(0 , 1   , 1773, "PAnnounceFishingEvNotice_Oct"               )}, // 島内放送｜釣り大会の予告を聞いたか（１０月）
            {0x6EE, new EventFlagPlayer(0 , 1   , 1774, "PAnnounceInsectEvNotice_1"                  )}, // 島内放送｜ムシとり大会の予告を聞いたか①
            {0x6EF, new EventFlagPlayer(0 , 1   , 1775, "PAnnounceInsectEvNotice_2"                  )}, // 島内放送｜ムシとり大会の予告を聞いたか②
            {0x6F0, new EventFlagPlayer(0 , 1   , 1776, "PAnnounceInsectEvNotice_3"                  )}, // 島内放送｜ムシとり大会の予告を聞いたか③
            {0x6F1, new EventFlagPlayer(0 , 1   , 1777, "PAnnounceInsectEvNotice_4"                  )}, // 島内放送｜ムシとり大会の予告を聞いたか④
            {0x6F2, new EventFlagPlayer(0 , 1   , 1778, "PAnnounceFireWorksEvNotice"                 )}, // 島内放送｜花火大会の予告を聞いたか
            {0x6F3, new EventFlagPlayer(0 , 1   , 1779, "PAnnounceCountdownEvNotice"                 )}, // 島内放送｜大晦日の予告を聞いたか
            {0x6F4, new EventFlagPlayer(0 , 1   , 1780, "StandByPhoneCallMayDayTour"                 )}, // 電話デモ|メーデー告知の入電するか？
            {0x6F7, new EventFlagPlayer(0 , 1   , 1783, "DrinkCoffeeToday"                           )}, // 喫茶ハトの巣｜今日コーヒーを飲んだか（実績用）
            {0x6F8, new EventFlagPlayer(0 , 1   , 1784, "RcoTipsPurchaseBoxUsed"                     )}, // Tips|買取BOX使ったことある？
            {0x6F9, new EventFlagPlayer(0 , 1   , 1785, "SloExplainbush"                             )}, // レイジ｜低木について個別に説明するか？
            {0x6FA, new EventFlagPlayer(0 , 1   , 1786, "SloRecommendbush"                           )}, // レイジ｜コミューン島今週のおすすめの低木を伝えたか
            {0x6FB, new EventFlagPlayer(0 , 2   , 1787, "PMovingTmpDustCloth"                        )}, // プレイヤーだけ引越し｜まごころ雑巾をP引越し時に一時的に使えなくするためのtmpフラグ
            {0x6FC, new EventFlagPlayer(0 , 1   , 1788, "RcoTipsRcoMachineLoginBonus"                )}, // Tips|タヌポートログボのTips出す？
        };

        private const string Unknown = "???";

        public static string GetName(ushort index, short count, IReadOnlyDictionary<string, string> str)
        {
            var dict = List;
            if (dict.TryGetValue(index, out var val))
            {
                string name = val.Name;
                if (str.TryGetValue(name, out var translated))
                    name = translated;
                return $"{index:00} - {name} = {count}";
            }
            return $"{index:00} - {Unknown} = {count}";
        }

        public static string GetName(ushort index, short count)
        {
            var dict = List;
            if (dict.TryGetValue(index, out var val))
                return $"{index:00} - {val.Name} = {count}";
            return $"{index:00} - {Unknown} = {count}";
        }
    }
}
